// FILE: ./assets/js/utilities/VersionDataLibs.js
function VersionDataLibs(templateManager, eventAggregator, requestDataSourceEngine, ZHPromise){
    var self = this;
    
    self.showErrorMessage = function(error) {
        var message = error;
        if(typeof error === 'object') {
            if(error.message) {
                message = error.message;
            } else if(error.data && error.data.error){
                message = error.data.error;
            }
        }

        if(!message) {
            message = 'Ocorreu um erro inesperado. Entre em contato com o administrador do sistema.';
        } else if(message.indexOf('Exception: Exception: ') != -1) {
            message = message.replace('Exception: Exception: ', '');
        }

        ScreenService.showMessage(message, 'error');
    };

    self.buildVersion = function () {
        var deferred = ZHPromise.defer();
        if(!templateManager.versionData) {
            templateManager.versionData = true;
            var filter = [ {
                name: 'CURRENT_MODULE',
                operator: '=',
                value: 'cadCtb'
            } ];
            return requestDataSourceEngine.getDataSource('cadCtb#/lib_getVersionInfo', filter)
            .then(function (response) {
                templateManager.versionData = response.dataset.versionInfo;
                templateManager.versionData.dependencies.changeCurrentVersion = function(newVersion) {
                    templateManager.versionData.dependencies.current = templateManager.versionData.dependencies[newVersion];
                };
            })
            .catch(function(){
                deferred.reject(self.showErrorMessage);
            });
        }else{
            deferred.resolve();
        }
        return deferred.promise;
    };
    
    /*Esta função foi temporariamente criada para corrigir erros na geração do
    reporte em ambiente de produção para corrigir erros de incompatibilidade 
    entre o framework e a libs. Devendo posteriormente ser retirada.*/
    eventAggregator.subscribe("AboutOnClick", this.buildVersion);

    eventAggregator.subscribe("beforeProjectStartup", function() {
        templateManager.updateVersionData = self.buildVersion;
    });
}
Configuration(function(ContextRegister) {
    ContextRegister.register("VersionDataLibs", VersionDataLibs);
});

// FILE: ./assets/js/repositories/Ger06100_Conta_Contabil_Repository.js
var Ger06100_Conta_Contabil_Repository = function(restEngine){

    this.verificaExclusao = function(Row){
          return restEngine.post('cadCtb#/verificaExclusao', {
               "requestType": "Row",
               "row": Row
          }); 
    };
    
    this.salvarContaContabil = function(row){
          return restEngine.post('cadCtb#/salvarContaContabil', {
               "requestType": "Row",
               "row": row
          }); 
    };
    
    this.salvarSubContas = function(row){
          return restEngine.post('cadCtb#/salvarSubContas', {
               "requestType": "Row",
               "row": row
          }); 
    };
    
    this.deletarSubContas = function(row){
          return restEngine.post('cadCtb#/deletarSubContas', {
               "requestType": "Row",
               "row": row
          }); 
    };
    
    this.verificaContaNivelAnterior = function(filter){
          return restEngine.post('cadCtb#/verificaContaNivelAnterior', {
               "requestType": "FilterData",
               "filter": filter
          }); 
    };
     
     this.salvarCadastramentoAutomatico = function(row){
          return restEngine.post('cadCtb#/salvarCadastramentoAutomatico', {
               "requestType": "Row",
               "row": row
          }); 
    };
    
    this.retornaMaiorConta = function(row){
          return restEngine.post('cadCtb#/retornaMaiorConta', {
               "requestType": "Row",
               "row": row
          }); 
    };
    
};


Configuration(function(ContextRegister) {
     ContextRegister.register('Ger06100_Conta_Contabil_Repository', Ger06100_Conta_Contabil_Repository);
});

// FILE: ./assets/js/repositories/Ger09400_ParametroContabil_Repository.js
var Ger09400_ParametroContabil_Repository = function(restEngine){
    
    this.cadastrarAutomaticamente = function(row){
        return restEngine.post('cadCtb#/parametroContabil/cadastroAutomatico',{
            "requestType": "Row",
            "row": row
        });
    };    
    
};

Configuration(function(ContextRegister){
    ContextRegister.register('Ger09400_ParametroContabil_Repository', Ger09400_ParametroContabil_Repository);
});

// FILE: ./assets/js/repositories/Ger17700_Rendimentos_Socios_Repository.js
var Ger17700_Rendimentos_Socios_Repository = function(restEngine){

};


Configuration(function(ContextRegister) {
     ContextRegister.register('Ger17700_Rendimentos_Socios_Repository', Ger17700_Rendimentos_Socios_Repository);
});

// FILE: ./assets/js/services/Ger06100_Conta_Contabil_Service.js
var Ger06100_Conta_Contabil_Service = function(Ger06100_Conta_Contabil_Repository) {

	//verifica se a data atual for maior que data final da conta contabil (Conta Expirada). Retorna true caso esteja tudo certo.
	this.validaDataContaContabil = function (row, nomeData){
		var dataFinal = row[nomeData];
		var dataAtual = moment();
		if(dataFinal){
			var data  = moment(dataFinal,'DD/MM/YYYY');
			if(dataAtual.isAfter(data))
				return false;
			else
				return true;
		}else{
			return true;
		}	
	};
   
	this.verificaExclusao = function (row){
		return Ger06100_Conta_Contabil_Repository.verificaExclusao(row);
	};
	
	this.salvarContaContabil = function (row){
		return Ger06100_Conta_Contabil_Repository.salvarContaContabil(row);
	};
	
	this.salvarSubContas = function (row){
		return Ger06100_Conta_Contabil_Repository.salvarSubContas(row);
	};
	
	this.deletarSubContas = function (row){
		return Ger06100_Conta_Contabil_Repository.deletarSubContas(row);
	};
	
	this.salvarCadastramentoAutomatico = function (row){
		return Ger06100_Conta_Contabil_Repository.salvarCadastramentoAutomatico(row);
	};
	
	this.retornaMaiorConta = function (row){
		return Ger06100_Conta_Contabil_Repository.retornaMaiorConta(row);
	};
	
	this.verificaContaNivelAnterior = function (row){
		var fiter = [
			{
				"name":"CDCONTCTBL",
				"operator":"=",
				"value":row.CDCONTANTE
			}
		];
		return Ger06100_Conta_Contabil_Repository.verificaContaNivelAnterior(fiter);
	};
	
	/*
		A função ira validar de o campo foi preenchido corretamente de acodor do a mascara
		A variável mascara é um array contendo os niveis e o tamanho de caractres de cada nivel.
	*/
	this.validaPreenchimentonivel = function (cdcontctbl, mascara){
		// array que terá o tamanho referente a cada nível da conta.
		var arrayNivel = [];
		var tamanho = cdcontctbl.length;
		
		mascara.forEach(function(nivel) {
		    arrayNivel.push(nivel.caracteres);
		});
		if( arrayNivel.indexOf( String(tamanho) ) == -1 )
			return false;
		else
			return true;
		
	};
	
	//retorna o nivel da Conta Contábil
	this.retornaNivelConta = function (cdcontctbl, mascara){
		var cdnvcontctbl = '';
		var tamanho = cdcontctbl.length;
		mascara.forEach(function(nivel) {
			if(nivel.caracteres === String(tamanho))
				cdnvcontctbl =  nivel.nivel;
		});
		return cdnvcontctbl;
	};
	
	//retorna a conta pai  da Conta Contábil
	this.retornaContaPai = function (cdcontctbl,nivel, mascara){
		var cdcontante              = null;
		var caracteresNivelAnterior =''; 
		if(nivel>1){
			mascara.forEach(function(nivelAtual) {
				if( parseFloat( nivelAtual.nivel ) === parseFloat(nivel)-1 )
					caracteresNivelAnterior =  nivelAtual.caracteres;
			});
			cdcontante = cdcontctbl.substr(0, caracteresNivelAnterior);
			return cdcontante;
		}else
			return cdcontante;
	};
	
	this.verificaValores = function (row, mascara){
		if(row.IDCONTCCUS ==='R')
			row.CDCONTCTBLANALI ='';
		
		if(row.CDCONTCTBLANALI)
			row.CDCONTCTBLANALI =  row.CDCONTCTBLANALI.replace(/[^0-9]/g,'');
		
		// Utilizado para mostrar o valor 'Não tem' para o usuario caso ele seja null  
		if(row.IDTIPOCOME ===' ')
			row.IDTIPOCOME = null;
		
		
		if( parseFloat(row.CDNVCONTCTBL) === mascara.length)
			row.IDTIPOCONT = 'A';
		else
			row.IDTIPOCONT = 'S';
			
		row.CDCONTCTBL =  row.CDCONTCTBL.replace(/[^0-9]/g,'');
		
	};

	this.validaIntervaloContas = function (contaInicial, contaFinal){
		if( parseFloat ( contaInicial.replace(/[^0-9]/g,'') ) > parseFloat ( contaFinal.replace(/[^0-9]/g,'') ) )
			return false;
		else
			return true;
	};
	
};

Configuration(function(ContextRegister){
    ContextRegister.register('Ger06100_Conta_Contabil_Service', Ger06100_Conta_Contabil_Service);
});

// FILE: ./assets/js/services/Ger09400_ParametroContabil_Service.js
var Ger09400_ParametroContabil_Service  = function(Ger09400_ParametroContabil_Repository){
    
    this.buildDataOfDataSource = function(banco){
        var aux = [];
        var aux2 = [];
        banco.forEach(function(row){
            var obj = new Object({});
            var obj2 = new Object({});
            obj.CDEMPRESA = row.CDEMPRESA;
            obj.NMEMPRESA = row.NMEMPRESA;
            obj.DTINICCONT = moment(row.DTINICCONT, 'DD/MM/YYYY').format('DD/MM/YYYY');
            obj.DTFINACONT = moment(row.DTFINACONT, 'DD/MM/YYYY').format('DD/MM/YYYY');
            obj.DTINICLANC = moment(row.DTINICLANC, 'DD/MM/YYYY').format('DD/MM/YYYY');
            obj.DTFINALANC = moment(row.DTFINALANC, 'DD/MM/YYYY').format('DD/MM/YYYY');
            obj.DTINIINTCONTDFE = moment(row.DTINIINTCONTDFE, 'DD/MM/YYYY').format('DD/MM/YYYY');
            obj.DTFININTCONTDFE = moment(row.DTFININTCONTDFE, 'DD/MM/YYYY').format('DD/MM/YYYY');
            obj.DTINIINTCONTDFS = moment(row.DTINIINTCONTDFS, 'DD/MM/YYYY').format('DD/MM/YYYY');
            obj.DTFININTCONTDFS = moment(row.DTFININTCONTDFS, 'DD/MM/YYYY').format('DD/MM/YYYY');
            obj.DTINICCTBL = moment(row.DTINICCTBL, 'DD/MM/YYYY').format('DD/MM/YYYY');
            obj.DTFINACCTBL = moment(row.DTFINACCTBL, 'DD/MM/YYYY').format('DD/MM/YYYY');
            obj.DTINIINTCONTGPA = moment(row.DTINIINTCONTGPA, 'DD/MM/YYYY').format('DD/MM/YYYY');
            obj.DTFININTCONTGPA = moment(row.DTFININTCONTGPA, 'DD/MM/YYYY').format('DD/MM/YYYY');
            obj.DTINIINTCONTFIS = row.DTINIINTCONTFIS ? moment(row.DTINIINTCONTFIS, 'DD/MM/YYYY').format('DD/MM/YYYY') : null;
            obj.DTFININTCONTFIS = row.DTFININTCONTFIS ? moment(row.DTFININTCONTFIS, 'DD/MM/YYYY').format('DD/MM/YYYY') : null;
            obj.DTINIINTCONTVEXT = row.DTINIINTCONTVEXT ? moment(row.DTINIINTCONTVEXT, 'DD/MM/YYYY').format('DD/MM/YYYY') : null;
            obj.DTFININTCONTVEXT = row.DTFININTCONTVEXT ? moment(row.DTFININTCONTVEXT, 'DD/MM/YYYY').format('DD/MM/YYYY') : null;
            obj.NRORG = row.NRORG;
            obj.__is_new = false;
            aux.push(obj);
            obj2.CDEMPRESA = row.CDEMPRESA;
            obj2.IDCONTGERE = row.IDCONTGERE;
            obj2.IDCONTCOME = row.IDCONTCOME;
            obj2.IDUTCUSTESTCONT = row.IDUTCUSTESTCONT;
            obj2.IDSUGRAT = row.IDSUGRAT;
            obj2.IDUTSALDOSOC = row.IDUTSALDOSOC;
            obj2.__is_new = false;
            obj2.IDMSMCONTADBCR = row.IDMSMCONTADBCR;
            obj2.IDCONSVNDDFS = row.IDCONSVNDDFS;
            obj2.IDDESPTRIBDIFAL = row.IDDESPTRIBDIFAL;
            obj2.IDRETESTSETOR = row.IDRETESTSETOR;
            obj2.IDCONSDTMOVIRETEST = row.IDCONSDTMOVIRETEST;
            obj2.IDCTBSINTETICO = row.IDCTBSINTETICO;
            obj2.IDGERESTLANCONT = row.IDGERESTLANCONT;
            obj2.IDCONTAJUDTCOMP = row.IDCONTAJUDTCOMP;
            aux2.push(obj2);
        });

        var back = [aux, aux2];
        return back;
    };
    
    this.saveParametroContabil = function (row){
        return Ger09400_ParametroContabil_Repository.saveParametroContabil(row);
    };
    
    this.cadastrarAutomaticamente = function(row){
        return Ger09400_ParametroContabil_Repository.cadastrarAutomaticamente(row);
    };

    this.comparDate = function(dataInicial, dataFinal){
        var dataIni = moment(dataInicial, 'DD/MM/YYYY');
        var dateFin = moment(dataFinal, 'DD/MM/YYYY');
        if(dataIni.isAfter(dateFin)){
            return true;
        } else {
            return false;
        }
    };
    
    this.comparDateAfter = function(dataInicial, dataFinal){
        var dataIni = moment(dataInicial, 'DD/MM/YYYY').startOf('month');
        var dateFin = moment(dataFinal, 'DD/MM/YYYY').startOf('month');
        if(dataIni.isAfter(dateFin)){
            return true;
        } else {
            return false;
        }
    };
    
    this.comparDateBefore = function(dataInicial, dataFinal){
        var dataIni = moment(dataInicial, 'DD/MM/YYYY').startOf('month');
        var dateFin = moment(dataFinal, 'DD/MM/YYYY').startOf('month');
        if(dataIni.isBefore(dateFin)){
            return true;
        } else {
            return false;
        }
    };

    this.intraPeriodoConta = function(date, dataInicial, dataFinal){
        var dateIni = moment(dataInicial, 'DD/MM/YYYY');
        var data = moment(date, 'DD/MM/YYYY');
        var dateFin = moment(dataFinal, 'DD/MM/YYYY').endOf('month');
        if(!data.isSame(dateIni) && !data.isSame(dateFin) && !data.isBetween(dateIni, dateFin)){
            return true;
        } else {
            return false;
        }
    };
};
Configuration(function(ContextRegister){
    ContextRegister.register('Ger09400_ParametroContabil_Service', Ger09400_ParametroContabil_Service);
});

// FILE: ./assets/js/services/Ger17700_Rendimentos_Socios_Service.js
 var Ger17700_Rendimentos_Socios_Service = function(Endereco, Ger17700_Rendimentos_Socios_Repository, ZHPromise){

};

Configuration(function(ContextRegister) {
     ContextRegister.register('Ger17700_Rendimentos_Socios_Service', Ger17700_Rendimentos_Socios_Service);
});

// FILE: ./assets/js/controllers/BlocoOregistroDeAbertura_cotroller.js
function BlocoOregistroDeAbertura_cotroller(General, ScreenService, templateManager) {

  	var self = this;
  	
  	/**
     * Atualiza Formulário
     */
    self.atualizaForm = function(widget){
		widget.currentRow = widget.dataSource.data[0]?widget.dataSource.data[0]:{};
		templateManager.updateTemplate();
		// widgetReg0000.reload();
	};
	
	self.verificaEmpresa = function(widget){
		var row = widget.getParent().currentRow;
		if(row.CDEMPRESA){
			widget.getAction('edit').readOnly = false;
			widget.activate();
			// widget.reload();
		}else{
			widget.getAction('edit').readOnly = true;
		}
	}; 
	
}

/* global Configuration */
Configuration(function (ContextRegister) {
	ContextRegister.register('BlocoOregistroDeAbertura_cotroller', BlocoOregistroDeAbertura_cotroller);
});


// FILE: ./assets/js/controllers/BlocoPLucroPresumido_Controller.js
function BlocoPLucroPresumido_Controller(General, ScreenService, templateManager) {

  	var self = this;
  	
  	self.ativaRegistroP130 = function() {
		templateManager.container.getWidget('ger18100_registro_p130_receitas_incentivadas').activate();
	};
  	
	self.verificaRegistro = function() { 
	    var widgetBlocoP = templateManager.container.getWidget();
	    var widgetActivate = templateManager.container.getActiveWidget();
	    
	    if((widgetBlocoP.getField('NMEMPRESA').value()) && (widgetBlocoP.getField('DTANO').value())){
		       if(widgetBlocoP.getField('DTANO').value().toString().length == 4){
		          widgetActivate.dataSourceFilter.forEach(function(dataSourceFilter){
		              switch(dataSourceFilter.name){
		                  case 'P_CDEMPRESA': dataSourceFilter.value = widgetBlocoP.getField('CDEMPRESA').value();
		                      break;
		                  case 'P_ANO': dataSourceFilter.value = widgetBlocoP.getField('DTANO').value();
		                      break;
		              }
		        	widgetBlocoP.widgets.forEach(function(widget){
						widget.getAction('new').readOnly = false;
						widget.floatingControl.refreshAction = true;
					});
					widgetBlocoP.reload();
		          });
		          widgetActivate.reload();
	    	} else if((widgetBlocoP.getField('DTANO').value().toString().length > 4) || (widgetBlocoP.getField('DTANO').value().toString().length < 4)){
	    		ScreenService.showMessage('O ano deve ter 4 digitos.');	
	    		widgetBlocoP.getField('DTANO').clearValue();
	    		
	        	widgetBlocoP.widgets.forEach(function(widget){
					widget.getAction('new').readOnly = false;
					widget.floatingControl.refreshAction = true;
				});
				widgetBlocoP.reload();
	    	}
		} else {
			widgetBlocoP.widgets.forEach(function(widget){
				/*widget.dataSourceFilter = [
					{
                        "name": "P_CDEMPRESA",
                        "operator": "=",
                        "value": ""
                    },
                    {
                        "name": "P_ANO",
                        "operator": "=",
                        "value": ""
                    }		
				];*/
				widget.dataSource.data = [];
				widget.getAction('new').readOnly = true;
				widget.floatingControl.refreshAction = false;
				widgetBlocoP.reload();
			});
		}
		
	};
	
	self.isNumber = function(widget){
   		var n = widget.currentRow.DTANO;
   		if(n == null){
   			n = 1;
   		}
   		n = n.toString();
   		n = n.replace(/\./g,'');
		if(!(!isNaN(parseFloat(n)) && isFinite(n)) || n.length < 4){
			widget.currentRow.DTANO = n.replace(/./g, '');
			// ScreenService.showMessage("Campo Ano obrigatório!");
		}
   };
	
}

/* global Configuration */
Configuration(function (ContextRegister) {
	ContextRegister.register('BlocoPLucroPresumido_Controller', BlocoPLucroPresumido_Controller);
});


// FILE: ./assets/js/controllers/ContaContabilGrupoProdutoFilialController.js
var ContaContabilGrupoProdutoFilialController = function(General ,ScreenService, templateManager,ZhFilterPreferences){
  
 
 
 this.saveGrupo = function() {
 	var widget = templateManager.container.getWidget('widget_CCTGRUPPRODFIL');
 	widget.currentRow.CDFILIAL = widget.appliedFilter.FILTER_ROW.CDFILIAL;
 	General.saveCrud(widget);
	};    
  
    	
 this.cadastrarAutomatico = function(widget) {
	var widgetCadAutomatico = templateManager.container.getWidget('cadAutomaticoPopup');
        widgetCadAutomatico.currentRow.NMFILIAL = '';
		ScreenService.openPopup(widgetCadAutomatico);
	
	};
	
	this.cadastroAutomaticoFilial = function(){
     	
     	var widget = templateManager.container.getWidget('cadAutomaticoPopup');
     	if(widget.isValid()){
     		General.callRestEngine('cadCtb#/cadastroAutomaticoFilial', 'Row', widget.currentRow).then(function(){
     			
         		ScreenService.showMessage("Cadastro realizado com sucesso.","success");
    			ScreenService.closePopup();
        	});
        }
     };
  

  
};
Configuration(function (ContextRegister){
    ContextRegister.register('ContaContabilGrupoProdutoFilialController', ContaContabilGrupoProdutoFilialController);
});


// FILE: ./assets/js/controllers/ControleDeValoresAjustesPeriodoBaseFuturo_Controller.js
function ControleDeValoresAjustesPeriodoBaseFuturo_Controller(ScreenService, General, templateManager, ZhFilterPreferences) {

  	var self = this;
  	
    this.habilitaCamposLancamentos = function(widget) {
        
        ScreenService.notificationMessage('habilitaCamposLancamentos ::: Begin', 'alert', 7000, '');

        if(widget.currentRow.NMCONTCTBL == ""){
            widget.getField('DTLANCCONT').readOnly = true;
            
            widget.currentRow.DTLANCCONT = "";
            
            widget.getField('NRLANCCONT').readOnly = true;
            widget.currentRow.NRLANCCONT = "";
        }else{
            widget.getField('DTLANCCONT').readOnly = false;
            widget.getField('NRLANCCONT').readOnly = false;
            
            if(widget.currentRow.DTLANCCONT == ""){
            widget.getField('NRLANCCONT').readOnly = true;
            widget.currentRow.NRLANCCONT = "";  
            }else{
                widget.getField('NRLANCCONT').readOnly = false;
                
            }
        }
    };
    
    /* self.newRowRegistro = function(widget){
        // Comentando: Funciona no View mas Nao funciona no EDIT nem no NEWROW
        General.newRow(widget);
        widget.widgets.forEach(function (wid){
            wid.enabled = false;
        });
    }; */
    
    /** 
     * Reconstruindo a função para fazer o inverso conforme nova logica do metodo.
     * Essa função ativa os widgets 'filhos' tornando todos na tela o metodo [validaWidgetEcf]
     * abaixo escolhe quais deles devem permanecer ativos após a escolha do relacionamento.
     */
    self.newRowRegistro = function(widget){
        
        ScreenService.notificationMessage('newRowRegistro ::: Begin', 'alert', 7000, '');
        
        General.newRow(widget);
        widget.widgets.forEach(function (wid){
            wid.enabled = true;
            wid.isVisible = true;
        });
    };

    self.verificaDependentes = function(widget){
        
        ScreenService.notificationMessage('verificaDependentes ::: Begin', 'alert', 7000, '');
        
        /*if (widget.widgets[1].widgets[1].getField('NMCONTCTBL').value() != '' ||    widget.widgets[1].widgets[0].getField('NMCONTCTBL'),value() != '' ){
            ScreenService.showMessage("Não foi possível excluir lançamento pois há dependentes");
        }else{*/
            General.deleteCrud(widget);
        //}
    };
    
    /* self.editarRegistro = function(widget){
        General.edit(widget);
        // Comentando: Funciona no View mas Nao funciona no EDIT nem no NEWROW
        widget.widgets.forEach(function (wid){
             wid.enabled = false;
        });
    }; */
    
    /** 
     * Reconstruindo a função para fazer o inverso conforme nova logica do metodo.
     * Essa função ativa os widgets 'filhos' tornando todos na tela o metodo [validaWidgetEcf]
     * abaixo escolhe quais deles devem permanecer ativos após a escolha do relacionamento.
     */
    self.editarRegistro = function(widget){
        
        ScreenService.notificationMessage('editarRegistro ::: Begin', 'alert', 7000, '');

        General.edit(widget);
        widget.widgets.forEach(function (wid){
             wid.enabled = true;
             wid.isVisible = true;
        });
    };
    
    /* Alterando nome da funçao  para editarNovoRegistro visto que ela não salva
    self.salvaNovo = function(widget){
        
        ScreenService.notificationMessage('salvaNovo ::: Begin', 'alert', 7000, '');
        
        if(widget.getField('NMCONTCTBL') != ''){
           General.edit(widget); 
        }else{
            widget.newRow();
        }
    }; */
    
    /**
     * Alterando nome da função e editando (Nome Antigo salvaNovo)
     */
    self.editarNovoRegistro = function(widget){
        
        ScreenService.notificationMessage('editarNovoRegistro ::: Begin', 'alert', 7000, '');
        
        if(widget.getField('NMCONTCTBL') != ''){
           General.edit(widget); 
        }else{
            widget.newRow();
        }
    };

    self.saveRegistro = function(widget){
        
        ScreenService.notificationMessage('saveRegistro ::: Begin', 'alert', 7000, '');
        
  	    widget.isValid();
  	    widget.currentRow.CDEMPRESA = widget.appliedFilter.FILTER_ROW.CDEMPRESA;
        widget.currentRow.NMEMPRESA = widget.appliedFilter.FILTER_ROW.NMEMPRESA;
        widget.currentRow.IDTRIBUTO = widget.appliedFilter.FILTER_ROW.IDTRIBUTO;
        widget.currentRow.DTLANCAMENT = widget.appliedFilter.FILTER_ROW.DTLANCAMENT.end;
        
        if(!widget.currentRow.VRLANCAMENT){
			ScreenService.showMessage("Preencha os campos obrigatórios");
			return false;
		}if(!widget.currentRow.DSHISTLANC){
			ScreenService.showMessage("Preencha os campos obrigatórios");
			return false;
		}if(!widget.currentRow.IDRELACAO){
			ScreenService.showMessage("Preencha os campos obrigatórios");
			return false;
		}if(!widget.currentRow.DSLANCAMENT){
			ScreenService.showMessage("Preencha os campos obrigatórios");
			return false;
		}
		
        


  	    General.callRestEngine("/registro_ajuste/saveRegistro", "Row", widget.currentRow).then(function(sucess) {
  	        ScreenService.goBack();
  	        widget.widgets.forEach(function (wid){
                wid.enabled = true;
            });
            widget.reload();
            ScreenService.successNotification('Registro salvo com sucesso.');
  	    }, function(error){
  	        ScreenService.showMessage(error.dataset.error);
  	    });
  	};
  	
  	self.saveLancamentos = function(widget){
  	    
  	    ScreenService.notificationMessage('saveLancamentos ::: Begin', 'alert', 7000, '');
  	    
  	    widget.isValid();
  	    var widgetLanc = templateManager.container.getWidget('widgetLançamentos');
        widget.currentRow.CDEMPRESA = widgetLanc.currentRow.CDEMPRESA;
        widget.currentRow.CDCONTCTBL = widget.currentRow.CDCONTCTBL;
        widget.currentRow.NRSEQLALURB = widgetLanc.currentRow.NRSEQLALURB;
        widget.currentRow.NRSEQLALURA = widgetLanc.currentRow.NRSEQLALURA;
        widget.currentRow.DTLANCAMENT  = widgetLanc.currentRow.DTLANCAMENT;
        widget.currentRow.CDLANCAMENT  = widgetLanc.currentRow.CDLANCAMENT;
        widget.currentRow.IDTIPOLANC  = widgetLanc.currentRow.IDTIPOLANC;
        
        if(widget.currentRow.CDCONTCTBL != ""){
            if(widget.currentRow.DTLANCCONT != ""){
                if(widget.currentRow.NRLANCCONT != ""){
              	    General.callRestEngine("/registro_ajuste/saveLancamentos", "Row", widget.currentRow).then(function(sucess) {
              	        ScreenService.closeSwipe();
              	        widget.widgets.forEach(function (wid){
                            wid.enabled = true;
                        });
                        widget.reload();
                        ScreenService.successNotification('Registro salvo com sucesso.');
              	    }, function(error){
              	        ScreenService.showMessage(error.dataset.error);
              	    });
                }else{
                    ScreenService.showMessage('Não há registro no campo "Número" em Lançamentos Contábeis Envolvidos');
                }
            }
        }
        
  	};
  	
  	self.saveParteB = function(widget){
  	    
  	    ScreenService.notificationMessage('saveParteB ::: Begin', 'alert', 7000, '');
  	    
  	    if(widget.isValid()) {
  	        var widgetLanc = templateManager.container.getWidget('widgetLançamentos');
            widget.currentRow.CDEMPRESA = widgetLanc.currentRow.CDEMPRESA;
            widget.currentRow.CDCONTCTBL = widget.currentRow.CDCONTCTBL;
            widget.currentRow.NRSEQLALURA = widget.getParent().getParent().currentRow.NRSEQLALURA;
            // widget.currentRow.NRSEQLALURB = widget.getParent().currentRow.NRSEQLALURB;
            widget.currentRow.IDRELACAO = widgetLanc.currentRow.IDRELACAO;
            widget.currentRow.IDTRIBUTO = widgetLanc.appliedFilter.FILTER_ROW.IDTRIBUTO;
            widget.currentRow.DSHISTLANC = widgetLanc.currentRow.DSHISTLANC;
            widget.currentRow.VRLANCAMENT = widgetLanc.currentRow.VRLANCAMENT;
            widget.currentRow.DTLANCAMENT  = widgetLanc.currentRow.DTLANCAMENT;
            widget.currentRow.CDLANCAMENT  = widgetLanc.currentRow.CDLANCAMENT;
            
            if(widget.getField('NMCONTCTBL').value() == ''){
                widget.currentRow.CDCONTCTBL = '';
            }
            
      	    General.callRestEngine("/registro_ajuste/saveParteB", "Row", widget.currentRow).then(function(sucess) {

                ScreenService.successNotification('Registro salvo com sucesso.');
                widget.list();
                widget.reload();
      	    }, function(error){
      	        ScreenService.showMessage(error.dataset.error);
      	    
      	    });
  	    }
  	    
  	};
  	
  /*	self.atualizaForm = function(widget) {
  		
  		ScreenService.notificationMessage('atualizaForm ::: A', 'alert', 7000, '');
  		
         widget.currentRow = widget.dataSource.data[0]?widget.dataSource.data[0]:{};
        templateManager.updateTemplate(); 
    }; */
    
  	self.atualizaFormContaB = function(widget) {
  		
  		ScreenService.notificationMessage('atualizaFormContaB ::: Begin', 'alert', 7000, '');
  		
        widget.currentRow = widget.dataSource.data[0]?widget.dataSource.data[0]:{};
        templateManager.updateTemplate();
    };
    
  	self.atualizaFormContas = function(widget) {
  		
  		ScreenService.notificationMessage('atualizaFormContas ::: Begin', 'alert', 7000, '');
  		
        widget.currentRow = widget.dataSource.data[1]?widget.dataSource.data[1]:{};
        templateManager.updateTemplate();
    };
  	
  	self.desabilitaCampos = function(widget){
  	    
  	    ScreenService.notificationMessage('desabilitaCampos ::: Begin', 'alert', 7000, '');
  	    
  	    widget.getField('DTLANCCONT').readOnly = true;
        widget.getField('NRLANCCONT').readOnly = true;
  	};
  	
  	// Comentando: Funciona no View mas Nao funciona no EDIT nem no NEWROW
  	/* self.desabilitaWidget = function(widget, valor){
  	    if(valor == false){
  	        widget.enabled = false;
  	    }else{
  	        widget.enabled = true;
  	    }
  	}; */
    
  	self.deleteLancamentos = function(widget){ 
  	    
  	   ScreenService.notificationMessage('deleteLancamentos ::: Begin', 'alert', 7000, '');
  	    
  	   ScreenService.confirmMessage('CONFIRM_EXCLUSAO_LAN', "question", function () {
      	    var widgetLanc = templateManager.container.getWidget('widgetLançamentos');
            widget.currentRow.CDEMPRESA = widgetLanc.currentRow.CDEMPRESA;
            widget.currentRow.CDCONTCTBL = widget.currentRow.CDCONTCTBL;
            widget.currentRow.NRSEQLALURA = widgetLanc.currentRow.NRSEQLALURA;
            widget.currentRow.DTLANCAMENT  = widgetLanc.currentRow.DTLANCAMENT;
            widget.currentRow.CDLANCAMENT  = widgetLanc.currentRow.CDLANCAMENT;
            widget.currentRow.IDTIPOLANC  = widgetLanc.currentRow.IDTIPOLANC;
            
      	    General.callRestEngine("/registro_ajuste/deleteLancamentos", "Row", widget.currentRow).then(function(sucess) {
      	        ScreenService.goBack();
      	        widget.widgets.forEach(function (wid){
                    wid.enabled = true;
                });
                widget.reload();
                ScreenService.showMessage('Registro deletado com sucesso.');
      	    }, function(error){
      	        ScreenService.showMessage(error.dataset.error);
      	    
      	    });
		});
  	};
  	
  	self.deleteRegistro = function(widget){
  	    
  	    ScreenService.notificationMessage('deleteRegistro ::: Begin', 'alert', 7000, '');

  	    General.callRestEngine("/registro_ajuste/deleteRegistro", "Row", widget.currentRow).then(function(sucess) {
  	        if (!(sucess.dataset.response[0])){
  	            General.deleteCrud(widget);
  	        }else{
  	            ScreenService.showMessage("Não foi possível excluir lançamento pois há dependentes");
  	        }
  	    }, function(error){
  	        ScreenService.showMessage(error.dataset.error);
  	    
  	    });
  	};
  	
    /* Comentando as duas funçoes abaixo foram reescritas por estarem "herdando atributos"
  	// passar args.owner.widget.wigets
  	self.validaWidgetEcf = function(widget){
  	    if (widget.getParent().getField('IDRELACAO').value() == "4" || widget.getParent().getField('IDTIPOLANC').value() == 'R'){
  	        widget.isVisible = false; 
  	    }else{
  	        widget.isVisible = true;
  	        if(widget.getParent().getField('IDRELACAO').value() == "1"){           
  	            widget.widgets[1].isVisible = true;
  	            widget.widgets[1].activate();
  	        }else if( widget.getParent().getField('IDRELACAO').value() == "3"){
  	             widget.widgets[1].isVisible = true;
  	        }
  	        else{
  	            widget.widgets[1].isVisible = false;
  	        }
  	        if(widget.getParent().getField('IDRELACAO').value() == "2" || widget.getParent().getField('IDRELACAO').value() == "3"){
  	            widget.widgets[0].isVisible = true;
  	        }else{
  	            widget.widgets[0].isVisible = false;
  	        }
  	    }
  	    
  	};
  	
  	self.ativaFilhas = function(widget){
  	    if(widget.widgets[0].isVisible == false){
  	        widget.widgets[1].activate();
  	    }else{
  	        widget.widgets[0].activate();
  	    }
  	}; */
  	
    self.cancelarFromChildren = function(args) {
        ScreenService.notificationMessage('cancelar ::: Begin', 'alert', 7000, '');
        
        var widgetLanc = templateManager.container.getWidget("widgetLançamentos");
        if(widgetLanc.currentRow.__is_new) {
            widgetLanc.dataSource.data.pop();
        }
        else {
            Util.extend(widgetLanc.currentRow, widgetLanc.backupRow);
        }
        ScreenService.closeSwipe();
    };

	// passar args.owner.widget.wigets
  	self.validaWidgetEcf = function(widget) {
  		
  		
  		ScreenService.notificationMessage('validaWidgetEcf ::: Begin', 'alert', 7000, '');
  		
        var widgetLançamentos = templateManager.container.getWidget("widgetLançamentos");
        
        ScreenService.notificationMessage('validaWidgetEcf ::: Id ' + widgetLançamentos.currentRow.IDRELACAO, 'alert' , 7000, '');
        
        
  	    /* if (widgetLançamentos.currentRow.IDRELACAO == null) {
  	    	
  	    	ScreenService.notificationMessage('validaWidgetEcf ::: relação NULL', 'alert', 7000, '');
  	    	
  	        return;
  	    } */
  	    
  	    (function (){
  	         templateManager.container.getWidget("EcfTabbed").enabled = true;
      	     templateManager.container.getWidget("widgetContaB").enabled = true;
      	     templateManager.container.getWidget("widgetContas").enabled = true;

  	    	 templateManager.container.getWidget("EcfTabbed").isVisible = true;
      	     templateManager.container.getWidget("widgetContaB").isVisible = true;
      	     templateManager.container.getWidget("widgetContas").isVisible = true;
      	     
      	     templateManager.container.getWidget("EcfTabbed").defaultTab = 'widgetContaB';
  	    })();
  	    
  	    
  	    /**
  	     * 4 - Sem Relacionamento
  	     */
  	    if (widgetLançamentos.currentRow.IDRELACAO == "4" || widgetLançamentos.currentRow.IDRELACAO == 'R') {
  	    	
  	    	ScreenService.notificationMessage('validaWidgetEcf ::: Rel-4', 'alert', 7000, '');
  	    	
    		templateManager.container.getWidget("EcfTabbed").enabled = false;
    		// templateManager.container.getWidget("widgetContaB").enabled = false;
    		// templateManager.container.getWidget("widgetContas").enabled = false;

    		// templateManager.container.getWidget("EcfTabbed").isVisible = false;
    		// templateManager.container.getWidget("widgetContaB").isVisible = false;
    		// templateManager.container.getWidget("widgetContas").isVisible = false;
    		
    		
            
    		return;
  	    }
  	    else
  	    {
  	            ScreenService.notificationMessage('validaWidgetEcf ::: ComRel', 'alert', 7000, '');
  	        


                /**
                 *  1 - Conta Parte B
                 */
      	        if(widgetLançamentos.currentRow.IDRELACAO == "1") {
      	        	
      	        	
      	        	ScreenService.notificationMessage('validaWidgetEcf ::: Rel-1', 'alert', 7000, '');

  	    	        // templateManager.container.getWidget("EcfTabbed").enabled = true;
      	            // templateManager.container.getWidget("widgetContaB").enabled = true;
      	            templateManager.container.getWidget("widgetContas").enabled = false;

  	    	        // templateManager.container.getWidget("EcfTabbed").isVisible = true;
      	            // templateManager.container.getWidget("widgetContaB").isVisible = true;
      	            // templateManager.container.getWidget("widgetContas").isVisible = false;
                    
                    
      	        }
      	        
                /**
                 *  2 - Conta Contabil
                 */
      	        else if(widgetLançamentos.currentRow.IDRELACAO == "2") {
      	        	
      	        	ScreenService.notificationMessage('validaWidgetEcf ::: Rel-2', 'alert', 7000, '');
      	        	
      	            // templateManager.container.getWidget("EcfTabbed").enabled = true;
      	            templateManager.container.getWidget("widgetContaB").enabled = false;
      	            // templateManager.container.getWidget("widgetContas").enabled = true;
                    
  	    	        // templateManager.container.getWidget("EcfTabbed").isVisible = true;
      	            // templateManager.container.getWidget("widgetContaB").isVisible = false;
      	            // templateManager.container.getWidget("widgetContas").isVisible = true;
                    
                    // templateManager.container.getWidget("widgetContas").templateToView;
    	            // templateManager.container.getWidget("widgetContas").view();
    	            // templateManager.container.getWidget("widgetContas").list();
    	            
    	            templateManager.container.getWidget("EcfTabbed").defaultTab = 'widgetContas';
      	        }
      	        
                /**
                 *  3 - Conta Parte B e Conta Contábil
                 */
      	        else if(widgetLançamentos.currentRow.IDRELACAO == "3") {
      	        	
      	        	ScreenService.notificationMessage('validaWidgetEcf ::: Rel-3', 'alert', 7000, '');

                    //////// NO NEED DO NOTHING
                    
                    
                    // templateManager.container.getWidget("EcfTabbed").enabled = true;
      	            // templateManager.container.getWidget("widgetContaB").enabled = true;
      	            // templateManager.container.getWidget("widgetContas").enabled = true;

  	    	        // templateManager.container.getWidget("EcfTabbed").isVisible = true;
      	            // templateManager.container.getWidget("widgetContaB").isVisible = true;
      	            // templateManager.container.getWidget("widgetContas").isVisible = true;


      	            /* // templateManager.container.getWidget("widgetContas").enabled = true;
      	            // templateManager.container.getWidget("widgetContaB").enabled = true;
                    
      	            templateManager.container.getWidget("widgetContas").isVisible = true;
      	            templateManager.container.getWidget("widgetContaB").isVisible = true;*/
      	        }
      	        
      	        else {
      	        	ScreenService.notificationMessage('validaWidgetEcf ::: NPE CONTROL', 'alert', 7000, '');
      	            // do nothing
      	        }

      	        /* templateManager.container.getWidget("widgetLançamentos").reload();      	        
      	        templateManager.container.getWidget("EcfTabbed").reload();
    		    templateManager.container.getWidget("widgetContas").reload();
    		    templateManager.container.getWidget("widgetContaB").reload(); */
      	        
      	        return;
  	    }
  	};
  	
  	self.ativaFilhas = function(widget){
  	    
  	    ScreenService.notificationMessage('ativaFilhas ::: Begin Nulling', 'alert', 7000, '');
  	    
  	    // ScreenService.notificationMessages().clear();
  	    
  	    
  	    
  	    /* if(widget.widgets[0].isVisible == false){
  	        widget.widgets[1].activate();
  	    }else{
  	        widget.widgets[0].activate();
  	    } */
  	};
  	
  	self.ajusteFiltro = function(widget, preference,args){
  	    
  	    ScreenService.notificationMessage('ajusteFiltro ::: Begin', 'alert', 7000, '');
  	    
  	    args.e.preventDefault();
  	    var filterRow = preference.FILTER_ROW;
  	    var filtro= [
            {
                "name":"P_DTINICIAL",
                "operator":"=",
                "value": filterRow.DTLANCAMENT ? filterRow.DTLANCAMENT.start : null
            },
            {
                "name":"P_DTFINAL",
                "operator":"=",
                "value": filterRow.DTLANCAMENT ? filterRow.DTLANCAMENT.end : null
            },
            {
                "name":"P_IDTRIBUTO",
                "operator":"=",
                "value": filterRow.IDTRIBUTO ? filterRow.IDTRIBUTO : null
            },
            {
                "name":"P_CDEMPRESA",
                "operator":"=",
                "value": filterRow.CDEMPRESA ? filterRow.CDEMPRESA : null
            }
        ];
        if(filterRow.IDTRIBUTO == "I"){    
            widget.getField('DSLANCAMENT').dataSource.name = 'cadCtb#/crud/m300a_lalura';
            widget.getField('DSLANCAMENT').reload();
        } else if(filterRow.IDTRIBUTO == "C"){
            widget.getField('DSLANCAMENT').dataSource.name = 'cadCtb#/crud/m350a_lacs';
            widget.getField('DSLANCAMENT');
            widget.getField('DSLANCAMENT').reload();
        }
        widget.dataSourceFilter = filtro;
        widget.reload();
  	};
  	
  	self.abreImportacao = function() {
  	    
  	    ScreenService.notificationMessage('abreImportacao ::: Begin', 'alert', 7000, '');
  	    
        var widgetImportacao = templateManager.container.getWidget('importacaoLalurLacs');
        
        widgetImportacao.currentRow = {};
        widgetImportacao.currentRow.__is_new = true;
        
        ScreenService.openPopup(widgetImportacao).then(function(){
			widgetImportacao.templateToForm = "widget/tabbedWidget.html";
			widgetImportacao.templateToView = "widget/tabbedWidget.html";
			widgetImportacao.formTemplate = "widget/tabbedWidget.html";
		});
    };
    
    self.ajusteAdd = function (widget){

        ScreenService.notificationMessage('ajusteAdd ::: Begin', 'alert', 7000, '');        

        templateManager.container.getActiveWidget().currentRow.CDEMPRESA = templateManager.container.getWidget('widgetLançamentos').currentRow.CDEMPRESA;
        widget.newRow();
        
        
    };
    
    self.setDataSetWidgetEcf = function (widget){
        
        ScreenService.notificationMessage('setDataSetWidgetEcf ::: Begin', 'alert', 7000, '');

      /* var widgetLançamentos = templateManager.container.getWidget("widgetLançamentos");  
      var widgetContas = templateManager.container.getWidget("widgetContas");
      
      widgetContas.dataSourceFilter.forEach(function (filter){
         if(filter.name == 'P_NRSEQLALURA'){
             filter.value = widgetLançamentos.currentRow.NRSEQLALURA;
         } 
      });
      widgetContas.reload(); */
      
      
      /* var widgetContaB = templateManager.container.getWidget("widgetContaB");
      widgetContaB.dataSourceFilter.forEach(function (filter){
         if(filter.name == 'P_NRSEQLALURA'){
             filter.value = widgetLançamentos.currentRow.NRSEQLALURA;
         } 
      });
      widgetContaB.reload(); */
      
    };
    
    self.validaHistorico = function (widget){
        
        ScreenService.notificationMessage('validaHistorico ::: Begin', 'alert', 7000, '');
        
        var widgetLanc = templateManager.container.getWidget('widgetLançamentos');
        if(widget.currentRow.DTLANCCONT){
            widget.currentRow.CDEMPRESA = widgetLanc.currentRow.CDEMPRESA;
            widget.currentRow.CDCONTCTBL = widget.currentRow.CDCONTCTBL;
            General.callRestEngine("/registro_ajuste/validaHistorico", "Row", widget.currentRow).then(function(response) {
      	         widget.getField('NRLANCCONT').dataSource.data = response.dataset.historicoCtbl;
      	    });
        }
    };
    
	this.cancelarContaB = function(widget){
		
    	ScreenService.notificationMessage('cancelarContaB ::: Begin', 'alert', 7000, '');
		
		widget.template = widget.templateToView;
		widget.view();
	};
	
	this.reloadContaB = function(widget){
		
	/*	ScreenService.notificationMessage('reloadContaB ::: Begin', 'alert', 7000, '');
		
        widget.reload();
        templateManager.container.getWidget("widgetContaB").reload(); */
	};
	
	this.reloadContas = function(widget){
		
		/* ScreenService.notificationMessage('reloadContas ::: Begin', 'alert', 7000, '');
		
        widget.reload();
        templateManager.container.getWidget("widgetContas").reload(); */
	};
	
	this.apagaCamposLancamentoContabeis = function(widget){
	    
	    ScreenService.notificationMessage('apagaCamposLancamentoContabeis ::: Begin', 'alert', 7000, '');
	    
	    widget.currentRow.NRLANCCONT = "";
	    widget.currentRow.DTLANCCONT = "";
	};
    
}

/* global Configuration */
Configuration(function (ContextRegister) {
	ContextRegister.register('ControleDeValoresAjustesPeriodoBaseFuturo_Controller', ControleDeValoresAjustesPeriodoBaseFuturo_Controller);
});

// FILE: ./assets/js/controllers/Ctb10300_GruposDeContasCorrelatas_Controller.js
function Ctb10300_GruposDeContasCorrelatas_Controller(General, ScreenService, templateManager) {

	this.geraCodigoGrupo = function(widget) {
		widget.newRow(); 
		
		General.callRestEngine('cadCtb#/crud/grupocontacorre_max', 'FilterData').then(function (result) {
			var grupocontacorre = result.dataset.grupocontacorre_max[0];
			
			if(result.dataset.grupocontacorre_max.length > 0){
				var cdgrupo = ('000000000' + (parseInt(grupocontacorre.CDGRUPO) + 1)).slice(-10);
				widget.getField('CDGRUPO').value(cdgrupo);
			}else widget.getField('CDGRUPO').value('0000000001');
		}).catch(function(erro){
            ScreenService.showMessage(erro.data.error);
        });
	};
    
    /**
     * Confirmar Adição
     */
    this.confirmaAdicionar = function(){
        var widget = templateManager.container.getWidget('ctb10300_grupos_de_contas_correlatas_grid');

        widget.getField('DSGRUPO').focused = true;

    };
}

Configuration(function (ContextRegister) {
	ContextRegister.register('Ctb10300_GruposDeContasCorrelatas_Controller', Ctb10300_GruposDeContasCorrelatas_Controller);
});

// FILE: ./assets/js/controllers/Ctb27200_Registro_Ajuste_Periodo_Base_Controller.js
function Ctb27200_Registro_Ajuste_Periodo_Base_Controller(ScreenService, General, templateManager, ZhFilterPreferences, localStorageEngine) {

  	var self = this;
  	
  	
    self.setContctblMask = function() {
       General.callRestEngine("cadCtb#/crud/paramgeral", "FilterData", []).then(function(response) {
            var paramgeral = response.dataset.paramgeral[0];
            localStorageEngine.setLocalVar('CDPICTCCTB', paramgeral.CDPICTCCTB);
       });
    };
    
    self.IDTRIBUTOOnChange = function(field) {
        var widgetLancamentos = templateManager.container.getWidget('widgetLancamentos');
        var widgetLancamentos_Tabbed = templateManager.container.getWidget('widgetLancamentos_Tabbed');   
        if(field.widget.name == 'widgetLancamentos_Tabbed'){
            widgetLancamentos.currentRow[field.name] = widgetLancamentos_Tabbed.currentRow[field.name];
            if (widgetLancamentos.appliedFilter){
                widgetLancamentos.appliedFilter.FILTER_ROW[field.name] = widgetLancamentos.currentRow[field.name];    
                //ZhFilterPreferences.saveFilters(widgetLancamentos.appliedFilter.FILTER_ROW);
                ZhFilterPreferences.applyFilter(widgetLancamentos, widgetLancamentos.appliedFilter, true);
                widgetLancamentos.reload();
            } 
        }else{
            widgetLancamentos_Tabbed.currentRow[field.name] = field.widget.currentRow[field.name];
        }
        
    };
    
    this.habilitaCamposLancamentos = function(widget) {

        widget.currentRow.CDEMPRESA = templateManager.container.getWidget('widgetLancamentos').appliedFilter.FILTER_ROW.CDEMPRESA;
        if(templateManager.container.getWidget('widgetContas').currentRow.NMCONTCTBL == ""){
            
            /* Essa condicional era utilizada antes de separar os campos
               label: "Com conta na Parte B" e label: Relacionamento das Contas Envolvidas na parte A
               esses dois grupos de campos estavam na mesma tela a codicional nao foi removida pra facilitar
               a compreensão que envolveu algumas validaçoes feitas no inicio da tela pela pessoa
               que mecheu na tela anteriormente
            */
            
            // Comentando Apos Separar widget.getField('DTLANCCONT').readOnly = true;
            // widget.currentRow.DTLANCCONT = "";

            // Comentando Apos Separar widget.getField('NRLANCCONT').readOnly = true;
            // widget.currentRow.NRLANCCONT = "";
            
        }
        else
        {
            // widget.getField('DTLANCCONT').readOnly = false;
            templateManager.container.getWidget('widgetLancContabeisEnvolvidos').getField('DTLANCCONT').readOnly = false;
            
            // widget.getField('NRLANCCONT').readOnly = false;
            templateManager.container.getWidget('widgetLancContabeisEnvolvidos').getField('NRLANCCONT').readOnly = false;
            
            if (templateManager.container.getWidget('widgetLancContabeisEnvolvidos').currentRow.DTLANCCONT == "") {

                // Comentando Apos Separar widget.getField('NRLANCCONT').readOnly = true;
                templateManager.container.getWidget('widgetLancContabeisEnvolvidos').getField('NRLANCCONT').readOnly = true;
                
            }
            else
            {
                // widget.getField('NRLANCCONT').readOnly = false;
                templateManager.container.getWidget('widgetLancContabeisEnvolvidos').getField('NRLANCCONT').readOnly = false;
            }
        }
        
        
    };
    

  	/**
  	 * Calling Ask for automatic entry confirmation
  	 */
  	self.askLancamentosAutomaticos = function(row){
        
  	    var widgetContas = templateManager.container.getWidget('widgetContas');
  	    var widgetCadAuto = templateManager.container.getWidget('cadastramentoAutomatico');
        
  	    // widget.isValid();
        if(widgetContas.currentRow.NMCONTCTBL != "") {
            
          	ScreenService.confirmMessage('Deseja cadastrar os Lançamentos Contabeis automáticamente?', "question", function () {
                
                ScreenService.openPopup(widgetCadAuto).then(function(){
                    
                    widgetCadAuto.currentRow.CDEMPRESA = templateManager.container.getWidget('widgetLancamentos').appliedFilter.FILTER_ROW.CDEMPRESA;
                    widgetCadAuto.currentRow.NMEMPRESA = templateManager.container.getWidget('widgetLancamentos').appliedFilter.FILTER_ROW.NMEMPRESA;
                    
                    widgetCadAuto.currentRow.CDCONTCTBL = templateManager.container.getWidget('widgetContas').currentRow.CDCONTCTBL;
                    widgetCadAuto.currentRow.NMCONTCTBL = templateManager.container.getWidget('widgetContas').currentRow.NMCONTCTBL;
                
                    widgetCadAuto.currentRow.DTINICIAL  = templateManager.container.getWidget('widgetLancamentos').appliedFilter.FILTER_ROW.DTLANCAMENT.start;
                    widgetCadAuto.currentRow.DTFINAL    = templateManager.container.getWidget('widgetLancamentos').appliedFilter.FILTER_ROW.DTLANCAMENT.end;
                    widgetCadAuto.currentRow.NRSEQCONTLALURA  = row.NRSEQCONTLALURA;
                });
            });
        }
	};
    
	/** Funçao para limpar os campos do grupo LançamentosContabeis envolvidos
	 *  no widgetContas dentro de detalhesECF
	 *  geralmente chamada FieldOnChange em Contas Contabeis -> Nome ser alterado;
	 */
	this.apagaCamposLancamentoContabeis = function(widget){
        
        widget.currentRow.DTLANCCONT = "";
        widget.currentRow.NRLANCCONT = "";
        widget.currentRow.VRLANCAMENT = "";
        widget.currentRow.DSHISTLANC = "";
	};
	
	
	/** 
	 * nao faço a minima ideia do sentido(motivo) dessa função
	 */
    self.validaHistorico = function (widget){

        var widgetLanc = templateManager.container.getWidget('widgetLancamentos');
        if(widget.currentRow.DTLANCCONT){
            
            widget.currentRow.CDEMPRESA = widgetLanc.currentRow.CDEMPRESA;
            widget.currentRow.CDCONTCTBL = templateManager.container.getWidget('widgetContas').currentRow.CDCONTCTBL;
            
            General.callRestEngine("/registro_ajuste/validaHistorico", "Row", widget.currentRow).then(function(response) {
      	         widget.getField('NRLANCCONT').dataSource.data = response.dataset.historicoCtbl;
      	    });
        }
    };
    
    /** 
     * Reconstruindo a função para fazer o inverso conforme nova logica do metodo.
     * Essa função ativa os widgets 'filhos' tornando todos na tela o metodo [validaWidgetEcf]
     * abaixo escolhe quais deles devem permanecer ativos após a escolha do relacionamento.
     */
    self.newRowRegistro = function(widget) {
        
        widget.currentRow.CDEMPRESA = widget.appliedFilter.FILTER_ROW.CDEMPRESA;
        
        General.widgetNewRow(widget);
        widget.widgets.forEach(function (wid){
            wid.enabled = false;
            wid.isVisible = true; // !Important
        });
    };
    
    self.enableButton = function(widget){
        
        var widget2 = templateManager.container.getWidget('tabbedwidget');
        var value = widget2.getField('IDTRIBUTO').value();
        var widget3 = templateManager.container.getWidget('widgetLancamentos');
        
        if(value == 'C' || value == 'I'){
            widget3.getAction('addAction').readOnly = false;
        }
        
        widget3.getAction('addAction').reload();
        widget2.getAction('addAction').reload();
        templateManager.updateTemplate();
    };
    

    self.verificaDependentes = function(widget){
        
        // Esse Comentatio é somente para desenvolvimento no fim antes de liberar toda a tela funcional muito provavelmente
        // tera que descomentar e usar o metodo com os checks atuais
        /*if (widget.widgets[1].widgets[1].getField('NMCONTCTBL').value() != '' ||    widget.widgets[1].widgets[0].getField('NMCONTCTBL'),value() != '' ){
            ScreenService.showMessage("Não foi possível excluir lançamento pois há dependentes");
        }else{*/
            General.deleteCrud(widget);
        //}
    };
    
    /** 
     * Reconstruindo a função para fazer o inverso conforme nova logica do metodo.
     * Essa função ativa os widgets 'filhos' tornando todos na tela o metodo [validaWidgetEcf]
     * abaixo escolhe quais deles devem permanecer ativos após a escolha do relacionamento.
     */
    self.editarRegistro = function(widget){
        
        General.edit(widget);
        
        // este Comentario deve ser avaliado na etapa de validaçao da tarefa
        // 
        /* widget.widgets.forEach(function (wid){
             wid.enabled = true;
             wid.isVisible = true;
        }); */
        
    };

    /**
     * Alterando nome da função e editando (Nome Antigo salvaNovo)
     */
    self.editarNovoRegistro = function(widget) {
        if(widget.getField('NMCONTCTBL') != ''){
           General.edit(widget); 
        }else{
            widget.newRow();
        }
    };


    /**
     * Reescrevendo a função com base nas validações 
     * 
     */
    self.saveRegistro = function(widget){
        var value = templateManager.container.getWidget('widgetLancamentos_Tabbed').getField('IDTRIBUTO').value();
        
  	    widget.isValid();
  	    widget.currentRow.CDEMPRESA = widget.appliedFilter.FILTER_ROW.CDEMPRESA;
        widget.currentRow.NMEMPRESA = widget.appliedFilter.FILTER_ROW.NMEMPRESA;
        widget.currentRow.IDTRIBUTO = value;
        widget.currentRow.DTLANCAMENT = widget.appliedFilter.FILTER_ROW.DTLANCAMENT.end;
        
        
        
        if(!widget.currentRow.VRLANCAMENT){
			widget.currentRow.VRLANCAMENT = 0;
		}
		if(!widget.currentRow.DSHISTLANC){
			ScreenService.showMessage("Preencha os campos obrigatórios");
			return false;
		}if(!widget.currentRow.IDRELACAO){
			ScreenService.showMessage("Preencha os campos obrigatórios");
			return false;
		}if(!widget.currentRow.DSLANCAMENT){
			ScreenService.showMessage("Preencha os campos obrigatórios");
			return false;
		}
		
  	    General.callRestEngine("/registro_ajuste/saveRegistro", "Row", widget.currentRow).then(function(sucess) {
  	        ScreenService.goBack();
  	        widget.widgets.forEach(function (wid){
                wid.enabled = true;
            });
            widget.reload();
            ScreenService.successNotification('Registro salvo com sucesso.');
  	    }, function(error){
  	        ScreenService.showMessage(error.dataset.error);
  	    });
  	};
    
  	self.saveLancamentos = function(widget){

  	    widget.isValid();
  	    var widgetLanc = templateManager.container.getWidget('widgetLancamentos');
  	    
        widget.currentRow.CDEMPRESA = widgetLanc.currentRow.CDEMPRESA;
        widget.currentRow.CDCONTCTBL = templateManager.container.getWidget('widgetContas').currentRow.CDCONTCTBL;
        widget.currentRow.NRSEQLALURB = widgetLanc.currentRow.NRSEQLALURB;
        widget.currentRow.NRSEQLALURA = widgetLanc.currentRow.NRSEQLALURA;
        widget.currentRow.DTLANCAMENT  = widgetLanc.currentRow.DTLANCAMENT;
        widget.currentRow.CDLANCAMENT  = widgetLanc.currentRow.CDLANCAMENT;
        widget.currentRow.IDTIPOLANC  = widgetLanc.currentRow.IDTIPOLANC;
        
        if(widget.currentRow.CDCONTCTBL != ""){
            
            // A condicional que esta checando a data e outras faziam parte dos widgets
            // label: "Com Conta na parte B" e label: "Relacionamento das contas envolvidas na parte A"
            // quando eles estavam juntos no mesmo field group
            // Antes Seperar
            if(widget.currentRow.DTLANCCONT != "")
            {
                
                if(widget.currentRow.NRLANCCONT != ""){
                    
              	    General.callRestEngine("/registro_ajuste/saveLancamentos", "Row", widget.currentRow).then(function(sucess) {
              	        ScreenService.closeSwipe();
              	        widget.widgets.forEach(function (wid){
                            wid.enabled = true;
                        });
                        widget.reload();
                        ScreenService.successNotification('Registro salvo com sucesso.');
                        templateManager.container.getWidget('widgetLancContabeisEnvolvidos').enabled = true;
                        self.askLancamentosAutomaticos(sucess.dataset.newRow || []);
              	    }, function(error){
              	        ScreenService.showMessage(error.dataset.error);
              	    });
                }else{
                    ScreenService.showMessage('Não há registro no campo "Número" em Lançamentos Contábeis Envolvidos');
                }
            }
            else
            {
                ScreenService.showMessage('Data nao foi preenchida!');
            }
        }
  	};
 
     
   self.onChangeTributo = function(){
        var widget = templateManager.container.getWidget('tabbedwidget');
        var idtributo = widget.currentRow.IDTRIBUTO;
        var widgetGrid = templateManager.container.getWidget('widgetLancamentos');
        
        widgetGrid.dataSourceFilter.forEach(function (filtro) {
            switch(filtro.name){
                case 'IDTRIBUTO': filtro.value = idtributo;
                    break;
            }
        });

       widgetGrid.reload();
    };
  	
  	
  	self.saveParteB = function(widget){
  	    
  	    if(widget.isValid()) {
  	        var widgetLanc = templateManager.container.getWidget('widgetLancamentos');
            widget.getField('NMCONTCTBL').readOnly = true;
            widget.currentRow.CDEMPRESA = widgetLanc.currentRow.CDEMPRESA;
            widget.currentRow.CDCONTCTBL = widget.currentRow.CDCONTCTBL;
            widget.currentRow.NRSEQLALURA = widget.getParent().getParent().currentRow.NRSEQLALURA;
            // widget.currentRow.NRSEQLALURB = widget.getParent().currentRow.NRSEQLALURB;
            widget.currentRow.IDRELACAO = widgetLanc.currentRow.IDRELACAO;
            widget.currentRow.IDTRIBUTO = widgetLanc.getField('IDTRIBUTO').value();
            widget.currentRow.DSHISTLANC = widgetLanc.currentRow.DSHISTLANC;
            widget.currentRow.VRLANCAMENT = widgetLanc.currentRow.VRLANCAMENT;
            widget.currentRow.DTLANCAMENT  = widgetLanc.currentRow.DTLANCAMENT;
            widget.currentRow.CDLANCAMENT  = widgetLanc.currentRow.CDLANCAMENT;
            
            if(widget.getField('NMCONTCTBL').value() == ''){
                widget.currentRow.CDCONTCTBL = '';
            }
            
      	    General.callRestEngine("/registro_ajuste/saveParteB", "Row", widget.currentRow).then(function(sucess) {
                ScreenService.successNotification('Registro salvo com sucesso.');
                widgetLanc.enabled = widgetLanc.enabledBkp;
                templateManager.container.getWidget('widgetContas').enabled = templateManager.container.getWidget('widgetContas').enabledBkp;
                widget.list();
                widget.reload().then(function(sucess) {
                    widget.view();
                });
      	    }, function(error){
      	        ScreenService.showMessage(error.dataset.error);
      	    });
  	    }
  	};
  	
    /**
     * Atualiza Formulário NEW
     */
    self.atualizaForm = function(widget_name) {
        var widget = templateManager.container.getWidget(widget_name);
        widget.currentRow = widget.dataSource.data[0] ? widget.dataSource.data[0] : {};
        templateManager.updateTemplate();
    };

	this.cancelarContaB = function(widget){
		widget.template = widget.templateToView;
		widget.view();
	};

  	self.deleteLancamentos = function(widget){ 
  	   ScreenService.confirmMessage('CONFIRM_EXCLUSAO_LAN', "question", function () {
      	    var widgetLanc = templateManager.container.getWidget('widgetLancamentos');
            widget.currentRow.CDEMPRESA = widgetLanc.currentRow.CDEMPRESA;
            widget.currentRow.CDCONTCTBL = widget.currentRow.CDCONTCTBL;
            widget.currentRow.NRSEQLALURA = widgetLanc.currentRow.NRSEQLALURA;
            widget.currentRow.DTLANCAMENT  = widgetLanc.currentRow.DTLANCAMENT;
            widget.currentRow.CDLANCAMENT  = widgetLanc.currentRow.CDLANCAMENT;
            widget.currentRow.IDTIPOLANC  = widgetLanc.currentRow.IDTIPOLANC;
            
      	    General.callRestEngine("/registro_ajuste/deleteLancamentos", "Row", widget.currentRow).then(function(sucess) {
      	        ScreenService.goBack();
      	        widget.widgets.forEach(function (wid){
                    wid.enabled = true;
                });
                widget.reload();
                ScreenService.showMessage('Registro deletado com sucesso.');
      	    }, function(error){
      	        ScreenService.showMessage(error.dataset.error);
      	    
      	    });
		});
  	};
  	
  	self.deleteRegistro = function(widget){
  	    General.callRestEngine("/registro_ajuste/deleteRegistro", "Row", widget.currentRow).then(function(sucess) {
  	        if (!(sucess.dataset.response[0])){
  	            General.deleteCrud(widget);
  	        }else{
  	            ScreenService.showMessage("Não foi possível excluir lançamento pois há dependentes");
  	        }
  	    }, function(error){
  	        ScreenService.showMessage(error.dataset.error);
  	    });
  	};
  	
  	/**
  	 * Ativa os widgets
  	 */
  	self.ativaFilhas = function(){
  	    // Usando o loop foreach deu problema em pegar os netos (filhos dos filhos)
  	    
        templateManager.container.getWidget("EcfTabbed").enabled = true;
        templateManager.container.getWidget("widgetContaB").enabled = true;
        templateManager.container.getWidget("widgetContas").enabled = true;
        
        templateManager.container.getWidget("EcfTabbed").isVisible = true;
        templateManager.container.getWidget("widgetContaB").isVisible = true;
        templateManager.container.getWidget("widgetContas").isVisible = true;
  	};
  	
  	
  	/**
  	 * Desativa os widgets
  	 */
  	self.desativaFilhas = function(){
        // Usando o loop foreach problema em pegar os netos (filhos dos filhos)
        
        templateManager.container.getWidget("EcfTabbed").enabled = false;
        templateManager.container.getWidget("widgetContaB").enabled = false;
        templateManager.container.getWidget("widgetContas").enabled = false;
        
        templateManager.container.getWidget("EcfTabbed").isVisible = true;
        templateManager.container.getWidget("widgetContaB").isVisible = true;
        templateManager.container.getWidget("widgetContas").isVisible = true;
  	};
  	
  	/**
  	 *  Cancela a newRow no widget master vindo de qualquer widget
  	 */
    self.cancelarFromChildren = function(args) {
        var widgetLanc = templateManager.container.getWidget("widgetLancamentos");
        if(widgetLanc.currentRow.__is_new) {
            widgetLanc.dataSource.data.pop();
        }
        else {
            Util.extend(widgetLanc.currentRow, widgetLanc.backupRow);
        }
        ScreenService.closeSwipe();
    };

	// passar args.owner.widget.wigets
  	self.validaWidgetEcf = function(widget) {
  		
        var widgetLancamentos = templateManager.container.getWidget("widgetLancamentos");
        self.desativaFilhas();

  	    // *** 4 - Sem Relacionamento
  	    if (widgetLancamentos.currentRow.IDRELACAO == "4" || widgetLancamentos.currentRow.IDTIPOLANC == 'R') {
  	        
  	    	self.desativaFilhas();
  	    	widgetLancamentos.getField('VRLANCAMENT').readOnly = false;
    		return;
  	    }
  	    else
  	    {
                // ***  1 - Conta Parte B
      	        if(widgetLancamentos.currentRow.IDRELACAO == "1") {

                    self.ativaFilhas();
      	            templateManager.container.getWidget("widgetContas").enabled = false;
                    templateManager.container.getWidget("EcfTabbed").defaultTab = 'widgetContaB';
                    widgetLancamentos.getField('VRLANCAMENT').readOnly = false;
                    return;
      	        }
      	        
                // *** 2 - Conta Contabil
      	        else if(widgetLancamentos.currentRow.IDRELACAO == "2") {
      	        	
      	        	self.ativaFilhas();
      	            templateManager.container.getWidget("widgetContaB").enabled = false;
    	            templateManager.container.getWidget("EcfTabbed").defaultTab = 'widgetContas';
    	            widgetLancamentos.getField('VRLANCAMENT').readOnly = true;
    	            widgetLancamentos.getField('VRLANCAMENT').value(0);
    		
    	            return;
      	        }
      	        
                // *** 3 - Conta Parte B e Conta Contábil
      	        else if(widgetLancamentos.currentRow.IDRELACAO == "3") {
                    
                    self.ativaFilhas();
      	            templateManager.container.getWidget("EcfTabbed").defaultTab = 'widgetContaB';
      	            widgetLancamentos.getField('VRLANCAMENT').readOnly = true;
    	            widgetLancamentos.getField('VRLANCAMENT').value(0);
      	            return;
      	        }
      	        //  NPE CONTROLL !!!
      	        else { return; }
  	    }
  	};
    
  	self.ajusteFiltro = function(widget, preference,args){
  	    args.e.preventDefault();
  	    var filterRow = preference.FILTER_ROW;
  	    var filtro= [
            {
                "name":"P_DTINICIAL",
                "operator":"=",
                "value": filterRow.DTLANCAMENT ? filterRow.DTLANCAMENT.start : null
            },
            {
                "name":"P_DTFINAL",
                "operator":"=",
                "value": filterRow.DTLANCAMENT ? filterRow.DTLANCAMENT.end : null
            },
            {
                "name":"P_IDTRIBUTO",
                "operator":"=",
                "value": filterRow.IDTRIBUTO ? filterRow.IDTRIBUTO : null
            },
            {
                "name":"P_CDEMPRESA",
                "operator":"=",
                "value": filterRow.CDEMPRESA ? filterRow.CDEMPRESA : null
            }
        ];
        if(filterRow.IDTRIBUTO == "I"){    
            widget.getField('DSLANCAMENT').dataSource.name = 'cadCtb#/crud/m300a_lalura';
            widget.getField('DSLANCAMENT').reload();
        } else if(filterRow.IDTRIBUTO == "C"){
            widget.getField('DSLANCAMENT').dataSource.name = 'cadCtb#/crud/m350a_lacs';
            widget.getField('DSLANCAMENT');
            widget.getField('DSLANCAMENT').reload();
        }
        widget.dataSourceFilter = filtro;
        widget.reload();
  	};
  	
  	self.abreImportacao = function() {
        var widgetImportacao = templateManager.container.getWidget('importacaoLalurLacs');
        widgetImportacao.currentRow = {};
        widgetImportacao.currentRow.__is_new = true;
        
        ScreenService.openPopup(widgetImportacao).then(function(){
			widgetImportacao.templateToForm = "widget/tabbedWidget.html";
			widgetImportacao.templateToView = "widget/tabbedWidget.html";
			widgetImportacao.formTemplate = "widget/tabbedWidget.html";
		});
    };
    
    self.contasAdd = function (widget){
        var widgetLancamentos = templateManager.container.getWidget('widgetLancamentos');
        widget.currentRow.CDEMPRESA = widgetLancamentos.currentRow.CDEMPRESA;
        
        widgetLancamentos.enabledBkp = widgetLancamentos.enabled;
        templateManager.container.getWidget('widgetContas').enabledBkp = templateManager.container.getWidget('widgetContas').enabled;
        widgetLancamentos.enabled = false;
        templateManager.container.getWidget('widgetContas').enabled = false;

        //widget.newRow();
        widget.edit();
        
        widget.getField('NMCONTCTBL').readOnly = false;
		/* OPEN SWIPE var widgetAdicionar = templateManager.container.getWidget('widgetContasAdicionar');
		ScreenService.openSwipe(widgetAdicionar).then(function(){
			// General.widgetNewRow(widget);
			// widget.newRow();
        }); */
    };
    
    self.ajusteAdd = function (widget){
        templateManager.container.getActiveWidget().currentRow.CDEMPRESA = templateManager.container.getWidget('widgetLancamentos').currentRow.CDEMPRESA;
        widget.newRow();
        
		/* OPEN SWIPE var widgetAdicionar = templateManager.container.getWidget('widgetContasAdicionar');
		ScreenService.openSwipe(widgetAdicionar).then(function(){
			// General.widgetNewRow(widget);
			// widget.newRow();
        }); */
    };

    /**  importaçao*/
     this.salvarImportacaoTabelas = function (widget){
        
        if(widget.isValid()){
            General.callRestEngine("/salvarImportacaoTabelas", "Row", widget.currentRow).then(function(sucess) {
      	        ScreenService.closePopup();
                ScreenService.successNotification('Registros importados com sucesso.');
      	    }, function(error){
      	        ScreenService.showMessage(error.dataset.error);
      	    });
        }
    }; 
    this.cancelaParteB = function (args){
        templateManager.container.getWidget('widgetLancamentos').enabled = templateManager.container.getWidget('widgetLancamentos').enabledBkp;
        templateManager.container.getWidget('widgetContas').enabled = templateManager.container.getWidget('widgetContas').enabledBkp;
      	General.backOrCancel(args);
    };
  	self.desabilitaWidget = function(widget, valor){
          widget.enabled = valor;
  	};
  	
	self.widgetContaBOnEnter = function(widget){
	    if(widget.getMode() != 'edit'){
    	    widget.list();
            widget.reload().then(function(data){
                widget.activate();
                widget.currentRow = widget.dataSource.data[0] ? widget.dataSource.data[0] : {};
                widget.view();       
            });    
	    }
	    templateManager.container.getWidget('widgetContas').enabledBkp = templateManager.container.getWidget('widgetContas').enabled;
  	};
  	
  	this.insertLancContasAuto = function (widget){
        if(widget.isValid()){
            General.callRestEngine("/insertLancContasAuto", "Row", widget.currentRow).then(function(response) {
      	        ScreenService.showMessage('Lançamentos cadastrados com sucesso.');
                ScreenService.closePopup();
                templateManager.container.getWidget('widgetContas').reload();
                templateManager.container.getWidget('widgetLancContabeisEnvolvidos').enabled = true;
      	    });
        }
    };
    
  	self.deleteLancContabeisEnvolvidos = function(widget){
  	    General.callRestEngine("/deleteLancContabeisEnvolvidos", "Row", widget.currentRow).then(function(sucess) {
            ScreenService.closeSwipe();
            widget.reload().then(templateManager.updateTemplate);
            templateManager.container.getWidget('widgetContas').reload().then(templateManager.updateTemplate);
            templateManager.container.getWidget('widgetLancamentos').reload().then(templateManager.updateTemplate);
            ScreenService.showMessage('Registro deletado com sucesso.');
  	    }, function(error){
  	        ScreenService.showMessage(error.dataset.error);
  	    });
  	};
    
}

/* global Configuration */
Configuration(function (ContextRegister) {
	ContextRegister.register('Ctb27200_Registro_Ajuste_Periodo_Base_Controller', Ctb27200_Registro_Ajuste_Periodo_Base_Controller);
});

// FILE: ./assets/js/controllers/Ctb32100_TermoDeAberturaEencerramento_Controller.js
var Ctb32100_TermoDeAberturaEencerramento_Controller = function(ScreenService, General) {
    var self = this;
    
    self.verificaNumLivro = function(widget){
        var pagInicial = parseInt(widget.currentRow.NRINICPAG); 
        var pagFinal = parseInt(widget.currentRow.NRFINAPAG);
        if(pagInicial > pagFinal){
            ScreenService.showMessage("Operação inválida! Número Pág. Inicial maior que Número Pág. Final.");
        }else{
            General.saveCrud(widget);
        }
    };
    
    

};

Configuration(function(ContextRegister) {
    ContextRegister.register('Ctb32100_TermoDeAberturaEencerramento_Controller', Ctb32100_TermoDeAberturaEencerramento_Controller);
});

// FILE: ./assets/js/controllers/Ctb63100_ParametrizacaoImportacaoAlterdata_Controller.js
var Ctb63100_ParametrizacaoImportacaoAlterdata_Controller = function(ScreenService, templateManager, ZHPromise, General) {

    this.geraCodigoParamImportacao = function(widget) {
		widget.newRow();
		
		General.callRestEngine('cadCtb#/crud/paramalterdata_max', 'FilterData').then(function (result) {
			var paramalterdata = result.dataset.paramalterdata_max[0];
			
			if(result.dataset.paramalterdata_max.length > 0){ 
				var cdparam = ('00000' + (parseInt(paramalterdata.CDPARAM) + 1)).slice(-5);
				widget.getField('CDPARAM').value(cdparam);
			}else widget.getField('CDPARAM').value('00001');
		}).catch(function(erro){
            ScreenService.showMessage(erro.data.error);
        });
  	};

};

Configuration(function(ContextRegister){
    ContextRegister.register('Ctb63100_ParametrizacaoImportacaoAlterdata_Controller', Ctb63100_ParametrizacaoImportacaoAlterdata_Controller);
});

// FILE: ./assets/js/controllers/Ctb92100_GruposParaAnaliseDeIndicadores_Controller.js
var Ctb92100_GruposParaAnaliseDeIndicadores_Controller  = function(templateManager, ScreenService, General, ZHPromise, Ger09400_ParametroContabil_Service, ZhUtil){
    
    var widget;
    var widgetfilha;
    
    var self = this;
    
    self.changeGridFilhaMode = function(){
        widgetfilha = templateManager.container.getWidget('ctb92100_grupos_para_analise_de_indicadores_gridFilha');
        if (widgetfilha.getParent().mode != 'edit')
            widgetfilha.view();
    };
     
    self.saveContaAnalise = function(widget){
        widget.currentRow.CDGRUPO = widget.getParent().currentRow.CDGRUPO;
        General.saveCrud(widget);
    };
    
    self.moveRow = function(args) {
        args.owner.widgets[0].reload();
    };
};
Configuration(function(ContextRegister){
    ContextRegister.register('Ctb92100_GruposParaAnaliseDeIndicadores_Controller', Ctb92100_GruposParaAnaliseDeIndicadores_Controller);
});

// FILE: ./assets/js/controllers/Ctb92200_PadraoRateiAjustesApuracao.js
var Ctb92200_PadraoRateiAjustesApuracao  = function(templateManager, ScreenService, General, ZHPromise, Ger09400_ParametroContabil_Service, ZhUtil){
    
    var self = this;
    
    //seta na session o modo padrao 
    self.abreTelaModoPadrao = function(){
        sessionStorage.setItem('CritCalc', false);
        ScreenService.openWindow('ctb92200_padrao_rateio_ajustes_apuracao');
    };
    
    
    
    //Abre a tela no modo padrão ou no modo "Critério de Cálculo"
    self.carregaModoTela = function(container){
        if (sessionStorage.getItem('CritCalc') === 'true'){
            container.label = 'Critério de Cálculo';
            var ncm_entradaWidget = container.getWidget('ncm_entrada');
            var ncm_saidaWidget = container.getWidget('ncm_saida');
            var ajustes_apuracaoWidget = container.getWidget('ajustes_apuracao');
            ajustes_apuracaoWidget.dataSourceFilter.forEach(function(filter){
                if(filter.name =='IDTPRATEIO'){
                    filter.value = 'F';
                }
            });
            ajustes_apuracaoWidget.getField('IDRATEIOPADRAO').dataSource.data[2].description = "Saída e Entrada";
            ajustes_apuracaoWidget.getField('IDORIGVALOR').isVisible = false;
            ajustes_apuracaoWidget.getField('IDORIGVALOR').showOnList = false;
            ncm_entradaWidget.isVisible = true;
            ncm_saidaWidget.isVisible = true;
        }
    };
    
    self.descarregaModoTela = function(container){
        sessionStorage.setItem('CritCalc', false);
    };

    self.changeVisibilidadePorCriterioRateio = function(widget){
        switch(widget.currentRow.IDRATEIOPADRAO){
            case 'ENT':
                templateManager.container.getWidget('entradas').isVisible = true;
                templateManager.container.getWidget('saidas').isVisible = false;
                break;
            case 'SAI':
                templateManager.container.getWidget('entradas').isVisible = false;
                templateManager.container.getWidget('saidas').isVisible = true;
                break;
            case 'SME':
                templateManager.container.getWidget('entradas').isVisible = true; 
                templateManager.container.getWidget('saidas').isVisible = true;
                break;
        }
    };

    this.controlaTipoParticipante = function(widget){
        var IDParticipante = widget.currentRow.IDTPPART;
        var cdparticipante = widget.currentRow.CDPARTICIPANTE;
        if(IDParticipante == 'L'){
            widget.getField('NRINSJURFORN').isVisible = false;
            widget.getField('NRINSJURCLIE').isVisible = false;
            widget.getField('NMFILIAL').isVisible = true;
            cdparticipante = widget.currentRow.CDFILIAL;
        }else if (IDParticipante == 'F') {
            widget.getField('NRINSJURCLIE').isVisible = false;
            widget.getField('NMFILIAL').isVisible = false;
            widget.getField('NRINSJURFORN').isVisible = true;
            cdparticipante = widget.currentRow.NRINSJURFORN;
        }else {
            widget.getField('NRINSJURFORN').isVisible = false;
            widget.getField('NMFILIAL').isVisible = false;
            widget.getField('NRINSJURCLIE').isVisible = true;
            cdparticipante = widget.currentRow.NRINSJURCLIE;
        }
	};
	
	this.participante = function(widget){
	    var IDParticipante = widget.currentRow.IDTPPART;
        
        if(IDParticipante == 'L'){
            widget.currentRow.CDPARTICIPANTE = widget.currentRow.CDFILIAL;
            General.saveCrud( widget);
            
        }else if (IDParticipante == 'F') {
            widget.currentRow.CDPARTICIPANTE = widget.currentRow.NRINSJURFORN;
            General.saveCrud( widget );
        }else {
            widget.currentRow.CDPARTICIPANTE = widget.currentRow.NRINSJURCLIE;
            General.saveCrud( widget );
        }
	    
	};
	
	this.salvarAjusteApur = function(widget){
	    widget.currentRow.IDTPRATEIO = sessionStorage.getItem('CritCalc') === 'true' ? "F" : "N";
        General.callRestEngine("cadCtb#/salvarAjusteApur", "DataSet", [widget.currentRow]).then(function(sucess) {
            widget.view();
            widget.currentRow = sucess.dataset.row[0];
            widget.currentRow.__is_new = false;
            widget.reload().then(function(){
                General.changeWidgetAcessibility(widget.widgets, true);    
                templateManager.updateTemplate();
            });
        }, function(error){
        	ScreenService.showMessage(error.data.error);
        });
	};
};
Configuration(function(ContextRegister){
    ContextRegister.register('Ctb92200_PadraoRateiAjustesApuracao', Ctb92200_PadraoRateiAjustesApuracao);
});

// FILE: ./assets/js/controllers/Ctb94000_atualizacao_custo_producao_Controller.js
var Ctb94000_atualizacao_custo_producao_Controller  = function(templateManager, ScreenService, General, localStorageEngine){
    
    var self = this;
    
    self.setContctblMask = function() {
       General.callRestEngine("cadCtb#/crud/paramgeral", "FilterData", []).then(function(response) {
            var paramgeral = response.dataset.paramgeral[0];
            localStorageEngine.setLocalVar('CDPICTCCTB', paramgeral.CDPICTCCTB);
       });
    };
    self.atualizarCusto = function(action){
        var atualizaCustoTabbed = templateManager.container.getWidget('atualizaCustoTabbed');
        var alteraCustoForm = templateManager.container.getWidget('alteraCustoForm');
        if(atualizaCustoTabbed.isValid()){
            alteraCustoForm.isVisible = true;
            alteraCustoForm.currentRow.tipoOperacao = 'A';
            alteraCustoForm.label = action.label;
            ScreenService.openPopup(alteraCustoForm);
        }else{
            ScreenService.showMessage("Preencha os campos obrigatórios");
        }
    };
    
    self.cancelarCusto = function(action){
        var alteraCustoForm = templateManager.container.getWidget('alteraCustoForm');
        alteraCustoForm.isVisible = true;
        alteraCustoForm.currentRow.tipoOperacao = 'C';
        alteraCustoForm.label = action.label;
        ScreenService.openPopup(alteraCustoForm);
    };
	
	this.confirmAlteraCustoForm = function(widget){
	    var atualizaCustoTabbed = templateManager.container.getWidget('atualizaCustoTabbed');
        var alteraCustoForm = templateManager.container.getWidget('alteraCustoForm');
        //var contctblGrid = templateManager.container.getWidget('contctblGrid');
	    atualizaCustoTabbed.currentRow.DTLANC = alteraCustoForm.currentRow.DTLANC;
	    
	    if(alteraCustoForm.isValid()){
	        var route = alteraCustoForm.currentRow.tipoOperacao == 'A' ? "cadCtb#/atualizaCustoProd": "cadCtb#/cancelaCustoProd";

    	    General.callRestEngine(route, "Row", atualizaCustoTabbed.currentRow).then(function(sucess) {
               ScreenService.showMessage('Operação realizada com sucesso.');
            }, function(error){
            	ScreenService.showMessage(error.data.error);
            });    
	    }
	};
};
Configuration(function(ContextRegister){
    ContextRegister.register('Ctb94000_atualizacao_custo_producao_Controller', Ctb94000_atualizacao_custo_producao_Controller);
});

// FILE: ./assets/js/controllers/Ger02900_ParametrosContabilizacao_Controller.js
var Ger02900_ParametrosContabilizacao_Controller = function(ScreenService, templateManager, ZHPromise, General) {

    var self = this;
    var windowCurrentlyOpen = false;
    var contctblMask = "";
    var produtoFields = [
        "CDPRODINI",
        "NMPRODINI",
        "CDPRODFIM",
        "NMPRODFIM",
        "CDCTBLENTRPF",
        "NMCTBLENTRPF",
        "CDCTBLSAIDPF",
        "NMCTBLSAIDPF",
        "CDCTBLPRODPF",
        "NMCTBLPRODPF",
        "CDCTBLCPROPF",
        "NMCTBLCPROPF",
        "CDCTBLPRACPF",
        "NMCTBLPRACPF",
        "CDCTBLAJUSPF",
        "NMCTBLAJUSPF",
        "CDCTBLIMPLPF",
        "NMCTBLIMPLPF"
    ];
    var unidadeFields = {
        "NMFILIALORIG": null,
        "T_CDFILIALDEST": 'T',
        "IDCTBLENTRPF": 'R',
        "IDCTBLSAIDPF": 'R',
        "IDCTBLPRODPF": 'R',
        "IDCTBLCPROPF": 'R',
        "IDCTBLPRACPF": 'R',
        "IDCTBLAJUSPF": 'R',
        "IDCTBLIMPLPF": 'R',
        "CDFILIALDEST": []
    };

    self.applyDefaultIdentrsaidop = function(widget) {
        if (!widget.currentRow.IDENTRSAIDOP) {
            widget.currentRow.IDENTRSAIDOP = 'E';
        }
    };

    var cadastramentoProdutoIsValid = function(widget) {
        var isValid = false;
        var currentRow = widget.currentRow;
        if (widget.isValid()) {
            if (currentRow.IDTIPOCAD == 'P') {
                if (currentRow.CDPRODFIM >= currentRow.CDPRODINI) {
                    isValid = true;
                }
                else {
                    ScreenService.showMessage("O produto final deve ser maior que o produto inicial.");
                }
            }
            else {
                isValid = true;
            }
        }
        return isValid;
    };

    var callCadastroProduto = function(widget) {
        General.callRestEngine("cadCtb#/parametros_contabilizacao_cadastraproduto", "Row", widget.currentRow).then(function() {
            self.closeCadastramentoProduto().then(function() {
                ScreenService.showMessage("Replicação de parâmetros feita com sucesso.");
            });
        }).catch(function(error) {
            var errorMessage = 'Timeout';
            if (error.data) {
                errorMessage = error.data.error;
            }
            ScreenService.showMessage(errorMessage);
        });
    };

    self.changeWidgetFormMode = function(widget) {
        widget.edit();
    };

    self.checkFormData = function(widgetParent) {
        var deferred = ZHPromise.defer();
        var widgetsTabbed = ["dtContabilizacaoTabbed", "cpPadraoTabbed", "cpPadraoEmpresaTabbed", "cpPadraoUnidadeTabbed"];
        var validation = true;
        
        if(widgetsTabbed.indexOf(widgetParent.name) > -1){
            var widget = widgetParent.widgets[0];
            
            if(widget.dataSource.name == "cadCtb#/paramempresa_contctbl")
                widget.dataSourceFilter[0].value = widgetParent.currentRow.CDEMPRESA;
            else if(widget.dataSource.name == "cadCtb#/paramfilial_contctbl")
                widget.dataSourceFilter[0].value = widgetParent.currentRow.CDFILIAL;
            
            General.callRestEngine(widget.dataSource.name, "FilterData", widget.dataSourceFilter).then(function(data) {
                
                if(widget.dataSource.name == "cadCtb#/crud/paramctbl")
                    data = data.dataset.paramctbl;
                else if(widget.dataSource.name == "cadCtb#/paramctbl_contctbl")
                    data = data.dataset.paramctbl_contctbl;
                else if(widget.dataSource.name == "cadCtb#/paramempresa_contctbl")
                    data = data.dataset.paramempresa_contctbl;
                else if(widget.dataSource.name == "cadCtb#/paramfilial_contctbl")
                    data = data.dataset.paramfilial_contctbl;
                else if(widget.dataSource.name == "cadCtb#/crud/paramctbldate")
                    data = data.dataset.paramctbldate;
                
                
                if (Array.isArray(data) && data[0]) {
                    widget.currentRow = data[0];
                    widget.backupRow = Util.clone(widget.currentRow);
                    widget.template = widget.templateToView;
                    widget.mode = "view";
                }
                else {
                    if(widgetParent.name != "dtContabilizacaoTabbed"){
                        validation = false;
                        deferred.reject("Não há registro de parametrização cadastrado.");
                        widget.template = widget.templateToForm;
                        widget.mode = "form";
                    }
                }
            });
        }
        
        if(validation)
            deferred.resolve(validation);
            
        return deferred.promise;
    };

    self.checkReloadDependentWidget = function(currentWidget) {
        var childWidget = templateManager.container.getWidget(currentWidget.dependentWidgetName);
        childWidget.dataSourceFilter.forEach(function(filter){
            filter.value = currentWidget.currentRow[filter.name];
        });
        var toReload = currentWidget.widgetDependentFields.every(function(fieldValue) {
            return !!currentWidget.currentRow[fieldValue];
        });
        if (toReload) {
            childWidget.list();
            childWidget.reload();
            
            var widgetsTabbed = ["cpPadraoEmpresa", "cpPadraoUnidade"];
            if(widgetsTabbed.indexOf(childWidget.name) > -1)
                childWidget.view();
                
            self.checkFormData(childWidget.getParent());
        }
        else {
            if (childWidget.templateToView) {
                childWidget.template = childWidget.templateToView;
            }
            childWidget.dataSource.data = [];
            childWidget.currentRow = {};
        }
    };

    self.checkReloadDependentField = function(field) {
        if (field.toReload !== false) {
            field.reload();
            field.toReload = false;
        }
    };

    self.clearDescriptionFieldValue = function(field) {
        if (!field.value()) {
            field.widget.currentRow[field.descriptionField] = null;
        }
        self.setFieldform(field);
    };
    
    self.setFieldform = function(field) {
        if (field.value()) {
            field.widget.currentRow[field.descriptionField.split('_')[0]] = field.widget.currentRow[field.descriptionField];
        }else{
            field.widget.currentRow[field.descriptionField.split('_')[0]] = null;
        }
    };

    self.closeCadastramentoProduto = function() {
        return ScreenService.goBack().then(function() {
            templateManager.container.getWidget('estProdutoUnidade').activate();
        });
    };

    self.closeCadastramentoTitulo = function() {
        return ScreenService.goBack().then(function() {
            templateManager.container.getWidget('finUnidadeTabbed').activate();
        });
    };

    self.closeSwipe = function(widget) {
        var deferred = ZHPromise.defer();
        var mainWidget = templateManager.container.getWidget("mainWidget");
        widget.deactivate();
        windowCurrentlyOpen = false;
        ScreenService.closeSwipe(0).then(function() {
            mainWidget.activate();
            deferred.resolve();
        });
        return deferred.promise;
    };

    self.getContctblMask = function() {
        return contctblMask;
    };

    self.mainWidgetAfterMoveRow = function(widget) {
        var windowToOpen = widget.currentRow.WINDOW;
        if (windowToOpen) {
            var widgetOpened = templateManager.container.getWidget(windowToOpen);
            self.checkFormData(widgetOpened).then(function () {
                if (windowCurrentlyOpen && windowCurrentlyOpen != windowToOpen) {
                    self.closeSwipe(templateManager.container.getWidget(windowCurrentlyOpen)).then(function() {
                        ScreenService.openSwipe(widgetOpened);
                        windowCurrentlyOpen = windowToOpen;
                    });
                }
                else {
                    ScreenService.openSwipe(widgetOpened);
                    windowCurrentlyOpen = windowToOpen;
                }
            }).catch(function(erro){
                if (erro){
                    ScreenService.showMessage(erro);
                }
            });
        }
        else {
            widget.currentRow._opened = !widget.currentRow._opened;
        }
    };

    self.openCadastramentoProduto = function() {
        if (General.getFieldValue('CDFILIAL', 'estProdutoUnidadeTabbed')) {
            ScreenService.openSwipe(templateManager.container.getWidget("cadastramentoProdutoTabbed"));
        }
        else {
            ScreenService.showMessage("É necessário filtrar por uma unidade.");
        }
    };

    self.openCadastramentoTitulo = function() {
        ScreenService.openSwipe(templateManager.container.getWidget("cadastramentoTituloTabbed"));
    };

    self.saveCadastramentoProduto = function(widget) {
        if (cadastramentoProdutoIsValid(widget)) {
            if (widget.currentRow.IDTIPOCAD == 'P') {
                var emptyContas = !produtoFields.some(function(fieldName) {
                    return fieldName.indexOf("CDCTBL") !== -1 && !!widget.currentRow[fieldName];
                });
                widget.currentRow.CDFILIALPROD = General.getFieldValue('CDFILIAL', 'estProdutoUnidadeTabbed');
                if (emptyContas) {
                    ScreenService.confirmMessage('CONFIRM_APAGAR').then(function() {
                        callCadastroProduto(widget);
                    }); 
                }
                else {
                    callCadastroProduto(widget);
                }
            }
            else {
                callCadastroProduto(widget);
            }
        }
    };

    self.saveCadastramentoTitulo = function(widget) {
        if (widget.isValid()) {
            General.callRestEngine("cadCtb#/parametros_contabilizacao_cadastratitulo", "Row", widget.currentRow).then(function() {
                self.closeCadastramentoTitulo().then(function() {
                    ScreenService.showMessage("Replicação de parâmetros feita com sucesso.");
                });
            }).catch(function(error) {
                var errorMessage = 'Timeout';
                if (error.data) {
                    errorMessage = error.data.error;
                }
                ScreenService.showMessage(errorMessage);
            });
        }
    };

    self.setContctblMask = function() {
       General.callRestEngine("cadCtb#/crud/paramgeral", "FilterData", []).then(function(response) {
            var paramgeral = response.dataset.paramgeral[0];
            contctblMask = paramgeral.CDPICTCCTB;
       });
    };

    self.showDatasourceLoadingError = function(data, widget) {
        widget.dataSource.data = [];
        var errorMessage = 'Timeout';
        if (data && data.error) {
            errorMessage = data.error;
        }
        ScreenService.showMessage(errorMessage);
    };

    self.toggleDependentFieldsReadOnly = function(parentField) {
        var widget = parentField.widget;
        var dependentFields = parentField.dependentFields || [];
        var readOnly = !parentField.value();
        dependentFields.forEach(function(fieldName) {
            var dependentField = widget.getField(fieldName);
            dependentField.readOnly = readOnly;
            dependentField.toReload = true;
            dependentField.setValue(null);
        });
    };

    self.toggleReplicacaoAlteracao = function(acaoField) {
        var contaField = acaoField.widget.getField("CD" + acaoField.name.substring(2));
        contaField.readOnly = acaoField.value() == 'R';
        contaField.setValue(null);
        contaField.widget.currentRow["CD" + acaoField.name.substring(2)] = null;
    };

    self.toggleUnidadeDestinoReadonly = function(widget) {
        var unidadeDestinoField = widget.getField('CDFILIALDEST');
        unidadeDestinoField.readOnly = !(widget.currentRow.CDFILIALORIG && widget.currentRow.T_CDFILIALDEST == 'L');
        unidadeDestinoField.validations = unidadeDestinoField.readOnly ? {} : {required: true};
        unidadeDestinoField.setValue([]);
    };

    self.toggleTipoCadastroProduto = function(widget) {
        var produtoIsSelected = widget.currentRow.IDTIPOCAD == 'P';
        Object.keys(unidadeFields).forEach(function(fieldName) {
            var field = widget.getField(fieldName);
            field.readOnly = produtoIsSelected;
            field.setValue(unidadeFields[fieldName]);
        });
        widget.currentRow.CDFILIALORIG = null;
        widget.getField("CDFILIALDEST").readOnly = true;
        produtoFields.forEach(function(fieldName) {
            var field = widget.getField(fieldName);
            field.readOnly = !produtoIsSelected || field.name.indexOf('NM') !== -1;
            field.setValue(null);
        });

        widget.currentRow.NMFILIALDEST = [];
        widget.getField("CDPRODINI").validations = produtoIsSelected ? {required: true} : {};
        widget.getField("CDPRODFIM").validations = produtoIsSelected ? {required: true} : {};
        widget.getField("NMFILIALORIG").validations = !produtoIsSelected ? {required: true} : {};
        widget.getField("T_CDFILIALDEST").validations = !produtoIsSelected ? {required: true} : {};
        widget.getField("CDFILIALDEST").validations = {};
    };
    
    self.modeInForm = function(widget){
        widget.template = "widget/form-view.html";
        widget.view();
        templateManager.updateTemplate();
    };
    
    self.modeInFormEdit = function(widget){
        widget.template = "widget/form.html";
        widget.edit();
        templateManager.updateTemplate();
    };
    
    self.cancelInForm = function(widget) {
        Util.extend(widget.currentRow, widget.backupRow);
        self.modeInForm(widget);
    };
    
    self.editInForm = function(widget) {
        if((!widget.currentRow.NRPARAMCTBL) && (widget.name == 'dtContabilizacao')){
            widget.currentRow.NRPARAMCTBL = '1';
            widget.currentRow.NRORG = getLocalVar('NRORG');
            widget.currentRow.__is_new = true;
        }else{
            widget.currentRow.__is_new = false;
        }
        General.widgetEdit(widget);
        self.modeInFormEdit(widget);
    };
    
    self.saveInForm = function(widget) {
        General.widgetSave(widget).then(function(){
            self.modeInForm(widget);
        });
    };
    
    self.enableActionsView = function(widget, field_name, enable) {

        var childWidget = templateManager.container.getWidget(widget.dependentWidgetName);

        if(!widget.getField(field_name).value())
            enable = false;
        
        childWidget.actions.forEach(function(action){
            if(action.showAsAction == 'view')
                action.isVisible = enable;
        });

    };
    
    this.reload = function(widget){
           templateManager = templateManager.container.getWidget('fisAjusteTipo'); //Ele pega com o templateManager
           templateManager.reload(); //e recarrega ele
      
    };
    
    this.reloadCodigo = function(widget){
            templateManager = templateManager.container.getWidget('fisAjusteCodigo'); //Ele pega com o templateManager
            templateManager.reload(); //e recarrega ele
    };
    
    this.salvarFisAjusteCodigo = function(widget){
        if (!widget.isValid()){
            ScreenService.showMessage("Preencha os campos obrigatórios!");
        }else {
            self.salvarFisAjuste(widget);
        }
    };
    
    self.salvarFisAjuste = function(widget){
        General.saveCrud(widget);
    };
    
    self.newRowFisAjuste = function(widget){
        widget.newRow();
    };
};

Configuration(function(ContextRegister){
    ContextRegister.register('Ger02900_ParametrosContabilizacao_Controller', Ger02900_ParametrosContabilizacao_Controller);
});

// FILE: ./assets/js/controllers/Ger03500_ParametrosCentroDeCusto_Controller.js
var ger03500_ParametrosCentroDeCusto_Controller  = function(templateManager, ScreenService, General, ZhFilterPreferences, ZHPromise){
    
    var self = this;
    
    /**
     * Abre Filtro
     */
    self.openFilter = function(widget){
        ZhFilterPreferences.setOriginalFilter(widget.id);
        ZhFilterPreferences.openFilterWidget(widget);
    };
    
    /**
     * Ativa Widget
     */
    self.activeWidget = function(widget_name){
        var widget = templateManager.container.getWidget(widget_name);
        widget.activate();
    };
    
    /**
     * Recarrega Widget
     */
    self.reloadWidget = function(widget_name){
        var widget = templateManager.container.getWidget(widget_name);
        widget.reload();
    };
    
    /**
     * Recarrega Widget
     */
    self.disableEditRateio = function(widget_name){
        var widget = templateManager.container.getWidget(widget_name);
        
        widget.editing = false;
        widget.getAction('finish').isVisible = false;
        General.changeWidgetAcessibility([widget.getParent()], true);
    };
    
    /**
     * Novo Rateio
     */
    self.newRateio = function(widget){
        widget.newRow();
        var valorTotal = 0;
            
        widget.dataSource.data.forEach(function(data){
            if(data.VRPERATEIO != "")
                valorTotal +=  parseFloat(data.VRPERATEIO);
        });
        
        widget.currentRow.VRPERATEIO = (100 - valorTotal).toFixed(2);
    };
    
    /**
     * Cancela Rateio
     */
    self.cancelRateio = function(args){
        General.backOrCancel(args);
    };
    
    /**
     * Cancela Rateio
     */
    self.backRateio = function(widget){
        ScreenService.goBack();
        
        widget.editing = false;
        widget.getAction('finish').isVisible = false;
        General.changeWidgetAcessibility([widget.getParent()], true);
    };
    
    /**
     * Salvar Rateio
     */
    self.saveRateio = function(args){
        var widget = args.owner.widget;
        ScreenService.goBack();
        
        widget.editing = true;
        widget.getAction('finish').isVisible = true;
        General.changeWidgetAcessibility([widget.getParent()], false);
    };
    
    /**
     * Cancela Rateio
     */
    self.deleteRateio = function(args){
        var widget = args.owner.widget;
        
        ScreenService.confirmMessage('Deseja realmente excluir?', 'question', function () {
            if (!widget.currentRow.__createdLocal) {
                var index = widget.currentRow.__index;
                widget.dataSource.data.splice(index, 1);
                
                ScreenService.goBack();
            }else{
                General.backOrCancel(args);   
            }
            
            var length = widget.dataSource.data.length;
            
            if(length == 0){
                var route   = "cadCtb#/excluiRateioCentroDeCusto";
                var dataset = [
                    [widget.name], 
                    widget.getParent().currentRow
                ];
                
                General.callRestEngine(route, 'DataSet', dataset).then(function(){
                    widget.editing = false;
                    widget.getAction('finish').isVisible = false;
                    General.changeWidgetAcessibility([widget.getParent()], true);
                })
                .catch(function(erro){
                    ScreenService.showMessage(erro.data.error);
                });
            }else{
                widget.editing = true;
                widget.getAction('finish').isVisible = true;
                General.changeWidgetAcessibility([widget.getParent()], false);
            }
            
            ScreenService.showMessage('Registro excluído com sucesso.', 'checked');
        });
    };
    
    
    
    /**
     * Finaliza Rateio
     */
    self.finishRateio = function(widget){
        self.validateRateio(widget).then(function(){
            self.validateValueRateio(widget).then(function(){
                var route   = "cadCtb#/geraRateioCentroDeCusto";
                var dataset = [
                    [widget.name], 
                    widget.getParent().currentRow,
                    widget.dataSource.data
                ];
                
                General.callRestEngine(route, 'DataSet', dataset).then(function(){
                    ScreenService.showMessage('Registro(s) cadastrado(s) com sucesso.');
                    
                    // Desabilita Edição
                    widget.editing = false;
                    widget.getAction('finish').isVisible = false;
                    General.changeWidgetAcessibility([widget.getParent()], true);
                }).catch(function(erro){
                    ScreenService.showMessage(erro.data.error);
                });
            }).catch(function(){
                ScreenService.showMessage('Operação bloqueada. Somatório dos percentual do rateio devem totalizar 100%.');
            });
        }).catch(function(){
            ScreenService.showMessage('Operação bloqueada. Mesmo centro de custo informado mais de uma vez.');
        });
        
       
    };
    
    /**
     * Valida Rateio
     */
    self.validateRateio = function(widget){
        var deferred = ZHPromise.defer();
        var centrocusto = [];
        var repetido    = false;
        
        widget.dataSource.data.forEach(function(data){
            if(centrocusto.includes(data.CDCENTCUST))
                repetido = true;
            centrocusto.push(data.CDCENTCUST);
        });
        
        if(!repetido)
             deferred.resolve();
        else deferred.reject();
        
        return deferred.promise;
    };
    
    /**
     * Valida Valor Rateio
     */
    self.validateValueRateio = function(widget){
        var deferred = ZHPromise.defer();
        var vrperateiotot = 0;
        
        widget.dataSource.data.forEach(function(data){
            vrperateiotot += self.formatFloat(data.VRPERATEIO);
        });
        
        if(vrperateiotot == 100)
             deferred.resolve();
        else deferred.reject();
        
        return deferred.promise;
    };
    
    /**
     * Formata Valor Decimal
     */
    self.formatFloat = function(value){
        value = parseFloat(value.replace(',','.'));
        return value;
    };
    
    /**
     * Abre Cadastramento Automático
     */
    self.openCadastramentoAutomaticoProduto = function(widget){
        var widgetCadastramentoAutomaticoForm = templateManager.container.getWidget('CadastramentoAutomaticoProdutoForm');
        ScreenService.openPopup(widgetCadastramentoAutomaticoForm);
        widgetCadastramentoAutomaticoForm.isVisible = true;
        widgetCadastramentoAutomaticoForm.getField('CDCCUSTENTR').setValue('');
        widgetCadastramentoAutomaticoForm.getField('CDCCUSTSAID').setValue('');
        widgetCadastramentoAutomaticoForm.getField('NMCCUSTENTR').setValue('');
        widgetCadastramentoAutomaticoForm.getField('NMCCUSTSAID').setValue('');
        widgetCadastramentoAutomaticoForm.getField('NMPRODUTOINI').setValue('');
        widgetCadastramentoAutomaticoForm.getField('NMPRODUTOFIN').setValue('');
    };
    
    /**
     * Abre Cadastramento Automático Produto por Filial
     */
    self.openCadastramentoAutomaticoProdutoPorFilial = function(widget){
        var unidade = widget.appliedFilter?widget.appliedFilter.FILTER_ROW.CDFILIAL:null;
        
        if(unidade) {
            var widgetCadastramentoAutomaticoForm = templateManager.container.getWidget('CadastramentoAutomaticoProdutoPorFilialForm');
            ScreenService.openPopup(widgetCadastramentoAutomaticoForm);
            widgetCadastramentoAutomaticoForm.isVisible = true;
            widgetCadastramentoAutomaticoForm.getField('CDCCUSTENTR').setValue('');
            widgetCadastramentoAutomaticoForm.getField('CDCCUSTSAID').setValue('');
            widgetCadastramentoAutomaticoForm.getField('NMCCUSTENTR').setValue('');
            widgetCadastramentoAutomaticoForm.getField('NMCCUSTSAID').setValue('');
            widgetCadastramentoAutomaticoForm.getField('NMPRODUTOINI').setValue('');
            widgetCadastramentoAutomaticoForm.getField('NMPRODUTOFIN').setValue('');
            widgetCadastramentoAutomaticoForm.getField('CDFILIAL').setValue(widget.appliedFilter.FILTER_ROW.CDFILIAL);
        }else ScreenService.showMessage('Operação bloqueada. Unidade deve ser informada no filtro.');
    };
    
    /**
     * Fecha Cadastramento Automático Produto por Filial
     */
    self.closeCadastramentoAutomatico = function(widget){
        widget.isVisible = false;
        ScreenService.closePopup();
    };
    
    /**
     * Confirma Cadastramento Automático
     */
    self.confirmCadastramentoAutomatico = function(widget){
        if(widget.isValid()){
            var route   = "cadCtb#/geraCadastramentoAutomaticoCentroDeCusto";
            var dataset = [
                [widget.getParent().name], 
                widget.currentRow
            ];
            
            General.callRestEngine(route, 'DataSet', dataset).then(function(){
                ScreenService.showMessage('Cadastramento automático realizado com sucesso.');
                ScreenService.closePopup();
                widget.isVisible = false;
                widget.getParent().reload();
            }).catch(function(erro){
                ScreenService.showMessage(erro.data.error);
            });
        }
    };

};

/* global Configuration */
Configuration(function(ContextRegister){
    ContextRegister.register('Ger03500_ParametrosCentroDeCusto_Controller', ger03500_ParametrosCentroDeCusto_Controller);
});

// FILE: ./assets/js/controllers/Ger06100_Conta_Contabil_Controller.js
var Ger06100_Conta_Contabil_Controller = function(ScreenService, templateManager, General, Ger06100_Conta_Contabil_Service, ZhUtil, MessageService){
    self = this;

    var IDENTIFICADOR  = {
    	"A":"Ativo",
    	"P":"Passivo",
    	"R":"Receita",
    	"D":"Despesa",
    	"C":"Custo",
    	"N":"Não tem"
    };
    var ultimaRowClicada = [];

    this.afterMoveRowContaContabil = function (widget){

        var mascara = getLocalVar('CDPICTCCTB');
    	var widgetSwipe           = templateManager.container.getWidget('swipeContaContabil');
    	var formContaContabil     = templateManager.container.getWidget('formContaContabil');
       	var widgetContaCorrelatas = templateManager.container.getWidget('widgetSubContas');

    	var widgetContaContabil = templateManager.container.getWidget('widgetContaContabil');
        self.ultimaRowClicada = Util.clone(widgetContaContabil.currentRow);

        ScreenService.openSwipe(widgetSwipe);
    	formContaContabil.reload([], false).then(
    	    function (success) {
				// para mostrar 'Não tem' caso o valor do campo seja null
				if(!formContaContabil.currentRow.IDTIPOCOME){
				    formContaContabil.currentRow.IDTIPOCOME =' ';
				}
				controlaWidgetContasCorrelatas(formContaContabil);
			}
		);
    	widgetContaCorrelatas.reload();
    	formContaContabil.getField('CDCONTCTBL').mask.params.mask = mascara;

    };

    this.cancelar = function (widget){
    	var formContaContabil   = templateManager.container.getWidget('formContaContabil');
    	var widgetContaContabil = templateManager.container.getWidget('widgetContaContabil');
    	General.widgetCancelForm(widget);
    	if(widget.currentRow.__is_new){
    		ScreenService.closeSwipe();
    		widgetContaContabil.activate();
    	}
    	controlaWidgetContasCorrelatas(formContaContabil);
    };

    this.voltar = function (widget){
    	var widgetContaContabil = templateManager.container.getWidget('widgetContaContabil');
    	ScreenService.goBack();
    	widgetContaContabil.activate();
    };

    this.calcMask = function(nivel) {
        var mask = getLocalVar('CDPICTCCTB');
        mask = mask.split('.');
        mask = mask.slice(0, parseInt(nivel));
        return mask.join('.');
    };

    this.addContaContabil = function (widget, nivelZero){
        var mascara = getLocalVar('CDPICTCCTB');
        if(mascara){
            var mascarado = '';
            var CDCONTCTBL = '';
            var nivelAtual = 1;
            var finalMascarado = '';
            if(!nivelZero){
                nivelAtual = (self.ultimaRowClicada ? parseInt(self.ultimaRowClicada.CDNVCONTCTBL) : 0)+ 1;
            }

        //Gerando o código novo pra colocar no form
            try{
                var ultimaCDCONTMascarada = _fixMask((self.ultimaRowClicada ? self.ultimaRowClicada.CDCONTCTBL : ''), mascara);
                ultimaCDCONTMascarada = ultimaCDCONTMascarada.slice(0, ultimaCDCONTMascarada.lastIndexOf('.'));
                let itemsNivelAtual = [];
                if(self.ultimaRowClicada){
                    itemsNivelAtual = widget.dataSource.data.filter(item => item.CDNVCONTCTBL == nivelAtual && item.CDCONTANTE == self.ultimaRowClicada.CDCONTCTBL);
                }else{
                    itemsNivelAtual = widget.dataSource.data.filter(item => item.CDNVCONTCTBL == nivelAtual && item.CDCONTCTBL.match(new RegExp('\^'+ultimaCDCONTMascarada+'.*\$')));
                }

                let maiorItemNivelAtual = Math.max.apply(Math, itemsNivelAtual.map(function(o) { return o.CDCONTCTBL; }));
                mascarado = _fixMask(maiorItemNivelAtual.toString() || (self.ultimaRowClicada ? self.ultimaRowClicada.CDCONTCTBL : ''), mascara);
                finalMascarado = mascarado.slice(mascarado.lastIndexOf('.')+1);

                let novoRegistro = parseInt(finalMascarado)+1;

                if(novoRegistro.toString().length > finalMascarado.toString().length) {
                    throw "Ficou maior que a mascara aceita";
                }else{
                    if(mascarado.lastIndexOf('.') != -1){
                        CDCONTCTBL = mascarado.slice(0, mascarado.lastIndexOf('.')) + '.' +General.fill(novoRegistro.toString(), finalMascarado.toString().length, false, '0');
                    }else{
                        CDCONTCTBL = General.fill(novoRegistro.toString(), finalMascarado.toString().length, false, '0');
                    }
                }
            }catch(error){
                finalMascarado = mascarado.slice(mascarado.lastIndexOf('.')+1);
                CDCONTCTBL = mascarado.slice(0, mascarado.lastIndexOf('.')) + '.' +General.fill('0', finalMascarado.toString().length, false, '0');
            }
			General.justInteger('#CDCONTREDU');
			var widgetSwipe       = templateManager.container.getWidget('swipeContaContabil');
	    	var formContaContabil = templateManager.container.getWidget('formContaContabil');
	    	ScreenService.openSwipe(widgetSwipe);

	    	formContaContabil.getField('CDCONTCTBL').mask.params.mask = this.calcMask(nivelAtual);
	    	General.widgetEdit(formContaContabil);

	    	formContaContabil.newRow();

	    	formContaContabil.currentRow = {"CDCONTCTBL":'', "__is_new":true, "IDCONTCCUS":"O",'IDTIPOCOME':" ","IDPADRREL":"N", "IDNATUCONT":"00",'CDRATEIO':'','IDTIPOPESS':null,"CDINDPLACON":null,'CDCTBLINTE':null,'CDCONTPLANREFE':null,'CDCONTCTBLANALI':null,'CDCONTREFEAUX':null,'CDCONTREFEPRE':null};
	    	widget.descriptionOrder = '';
	    	formContaContabil.getField('CDCONTCTBL').setValue(CDCONTCTBL);
	    	this.controlaCamposNivelConta(formContaContabil);
		}else{
			MessageService.showMessageByCode("MSG_MASCARA");
		}

    };

    this.editarContaContabil = function (widget){
    	General.widgetEdit(widget);
    	General.justInteger('#CDCONTREDU');
    	this.controlaCamposNivelConta(widget);
    };

    this.deletarContaContabil = function (widget){
		var nivelMascara  = General.getLevelByMask('CDPICTCCTB',1);
		if (parseFloat(widget.currentRow.CDNVCONTCTBL) === nivelMascara.length ){
    		this.delete(widget);
		}
    	else{
    		Ger06100_Conta_Contabil_Service.verificaExclusao(widget.currentRow).then(
    			function(success) {
                	var dataSet = success.dataset.contctbl;
                	if(dataSet.length ===0){
                	   this.delete(widget);
                	}else{
                		MessageService.showMessageByCode("MSG_EXLUIR");
                	}
            	}.bind(this),
            	function(callback){
                	if(callback.data){
                		ScreenService.showMessage(callback.data.error);
                	}
            	}
            );
    	}
	};

    this.carregarDataSource = function(args){
        var widget = args.owner;
        if(widget.dataSource.data.length >0)
        	widget.currentRow = widget.dataSource.data[0];
        else
        	widget.currentRow = {"__is_new":true};

    };

    this.verificaDataField = function (field, msg){
       	field.reload().then(
    	    function (success) {
				if(field.dataSource.data.length ===0){
				    ScreenService.showMessage(msg);
				}
			}
		);
    };

    this.controlaCampoContaVertical = function (field){
    	var widget = field.widget;
    	var campoContaVertical = widget.getField('CDCONTCTBLANALI');
    	if(field.value()==='R')
    		campoContaVertical.readOnly = true;
    	else
    		campoContaVertical.readOnly = false;
    };

    //Realiza o controle de campos que são habilidatos apenas quando a conta for de nível completo
    this.controlaCamposNivelConta = function (widget){

    	var campos        = ['IDCONTCCUS','IDTIPOCOME','IDPADRREL','CDCONTPLANREFE','CDCONTREFEPRE','CDCONTREFEAUX','CDCONTREFEIMUISEN'];
    	var nivelMascara  = General.getLevelByMask('CDPICTCCTB',1);
    	var readOnly      = true;
    	var contaVertical = widget.getField('CDCONTCTBLANALI');

    	if (parseFloat(widget.currentRow.CDNVCONTCTBL) === nivelMascara.length )
    		readOnly = false;
    	campos.forEach(function(campo) {
		    widget.getField(campo).readOnly = readOnly;
		});


		if(widget.currentRow.CDNVCONTCTBL){
			if(parseFloat(widget.currentRow.CDNVCONTCTBL) > 1 && widget.currentRow.IDCONTCCUS !=='R')
				contaVertical.readOnly = false;
			else
				contaVertical.readOnly = true;
		}
		else{
			contaVertical.readOnly = true;
		}

    };

	// controla status de Tabbes de Sub contas correlatas de acordo com as condições definidas
	var controlaWidgetContasCorrelatas = function (widget){
		var widgetContaCorrelatas = templateManager.container.getWidget('widgetSubContas');
		var nivelMascara          = General.getLevelByMask('CDPICTCCTB',1);
			if (parseFloat(widget.currentRow.CDNVCONTCTBL) === nivelMascara.length )
    			widgetContaCorrelatas.enabled = true;
			else
				widgetContaCorrelatas.enabled = false;
	};

	this.validaDataContaContabil = function (field, campoData){
		if(field.value()){
			var widget = field.widget;
			var resul =  Ger06100_Conta_Contabil_Service.validaDataContaContabil(widget.currentRow, campoData);
			// caso a data não passe na validação
			if(!resul){
	    	    MessageService.confirmMessageByCode("CONFIRM_VALIDADE", {},
                	{'icon': 'question',
                	'success': function (success) {},
                	'fail' : function (error) {
    						field.value('');
    					}
            	    }
            	);
			}
		}
	};

	this.delete = function (widget){
		var widgetContaContabil = templateManager.container.getWidget('widgetContaContabil');
	    MessageService.confirmMessageByCode("CONFIRM_DELETE", {},
        	{'icon': 'question',
        	'success': function (success) {
					widget.removeRow().then(
        				function () {
        					ScreenService.closeSwipe().then(function () {
        						widgetContaContabil.activate();
        						widgetContaContabil.reload();
        						//ScreenService.showMessage('Deletado com sucesso.');

        					});
        				},
        				function (error) {
        					if (error.data && error.data.error.indexOf('ORA-02292') !== -1) {
        						ScreenService.showMessage('Exclusão não permitida! O registro possui registros filhos.');
        					} else {
        						ScreenService.showMessage(error.data.error);
        					}

        				}
        			);
				}
    	    }
    	);
	};

	var salvarContaContabil = function (widget){
		var nivelMascara        = General.getLevelByMask('CDPICTCCTB',1);
		var widgetContaContabil = templateManager.container.getWidget('widgetContaContabil');
		var formContaContabil   = templateManager.container.getWidget('formContaContabil');
		var tipoConta           = widget.currentRow.IDTIPOCOME;
		widget.currentRow.IDGRUPOCONTA = 'N';
		Ger06100_Conta_Contabil_Service.verificaValores(widget.currentRow, nivelMascara);
		Ger06100_Conta_Contabil_Service.salvarContaContabil(widget.currentRow).then(
			function(success) {
            	controlaWidgetContasCorrelatas(formContaContabil);
            	if (widget.currentRow.__is_new) {
					widget.template = widget.templateToView;
					widget.view();
					ScreenService.closeSwipe();
					widgetContaContabil.activate();
					widgetContaContabil.reload();
				} else {
					if(!widget.currentRow.IDTIPOCOME){
						widget.currentRow.IDTIPOCOME = ' ';
					}
					widget.activate();
					widget.template = widget.templateToView;
					widget.view();
				}
        	}.bind(this),
        	function(callback){
            	widget.getField('CDCONTCTBL').element.focus();
            	widget.currentRow.IDTIPOCOME = tipoConta;
            	if(callback.data){
            		ScreenService.showMessage(callback.data.error);
            	}
        	}
        );
	};

	this.salvarSubContas = function (widget){
		var widgetPai = templateManager.container.getWidget('widgetContaContabil');
		if(widget.isValid()){
			if(widget.currentRow.__is_new){
				widget.currentRow.CDCONTCTBL = widgetPai.currentRow.CDCONTCTBL;
			}
			widget.currentRow.CDCONTACORRE =widget.currentRow.CDCONTACORRE.replace(/[^0-9]/g,'');
			Ger06100_Conta_Contabil_Service.salvarSubContas(widget.currentRow).then(
    			function(success) {
                	widget.activate();
					if (widget.currentRow.__is_new) {
						widget.list(true);
						ScreenService.goBack();
						widget.reload();
					} else {
						widget.computeDescriptionOrder();
						widget.view();
					}
            	}.bind(this),
            	function(callback){
                	if(callback.data){
                		ScreenService.showMessage(callback.data.error);
                	}
            	}
            );
		}
	};

	this.deletarSubContas = function (widget){

	    MessageService.confirmMessageByCode("CONFIRM_DELETE", {},
        	{'icon': 'question',
        	'success': function (success) {
					Ger06100_Conta_Contabil_Service.deletarSubContas(widget.currentRow).then(
            			function(success) {
                        	ScreenService.closeSwipe().then(function () {
        						widget.activate();
        					});
        					widget.reload();
        					ScreenService.showMessage('Deletado com sucesso.');
                    	},
                    	function(error){
                        	if (error.data && error.data.error.indexOf('ORA-02292') !== -1) {
        						ScreenService.showMessage('Exclusão não permitida! O registro possui registros filhos.');
        					} else {
        						ScreenService.showMessage(error.data.error);
        					}
                    	}
                    );
				}
    	    }
    	);
	};

	/*
	Valida se o nível está preenchido corretamente.
	Valida se existe conta com nivel anterior cadastrado;
	*/
	this.validacoesSalvarContaContabil = function (widget){
		if(widget.isValid()){
			var cdcontctbl   = widget.getField('CDCONTCTBL').value().replace(/[^0-9]/g,'');
			var nivelMascara = General.getLevelByMask('CDPICTCCTB',1);
			if(Ger06100_Conta_Contabil_Service.validaPreenchimentonivel(cdcontctbl, nivelMascara)){
				widget.currentRow.CDNVCONTCTBL = Ger06100_Conta_Contabil_Service.retornaNivelConta(cdcontctbl, nivelMascara);
				widget.currentRow.CDCONTANTE   = Ger06100_Conta_Contabil_Service.retornaContaPai(cdcontctbl, widget.currentRow.CDNVCONTCTBL, nivelMascara);
				salvarContaContabil(widget);
			}else{
				MessageService.showMessageByCode("MSG_PRENCHIMENTONIVEL");
			}
		}
	};

	/* Função que retorna o nivel da conta e a conta PAI.
	Valida se o nível está preenchido corretamente.
	Valida se existe conta com nivel anterior cadastrado;
	*/
	this.propriedadesContaContabil = function (field){
		var widget = field.widget;
		if(field.value()){
			var cdcontctbl     = field.value();
			var nivelMascara   = General.getLevelByMask('CDPICTCCTB',1);
			cdcontctbl         = cdcontctbl.replace(/[^0-9]/g,'');
			var resultadoNivel = Ger06100_Conta_Contabil_Service.validaPreenchimentonivel(cdcontctbl, nivelMascara);

			if(resultadoNivel){
				widget.currentRow.CDNVCONTCTBL = Ger06100_Conta_Contabil_Service.retornaNivelConta(cdcontctbl, nivelMascara);
				widget.currentRow.CDCONTANTE   = Ger06100_Conta_Contabil_Service.retornaContaPai(cdcontctbl, widget.currentRow.CDNVCONTCTBL, nivelMascara);
				//Contas de Nível 1 não possuem PAI
				if( parseFloat (widget.currentRow.CDNVCONTCTBL) > 1){
					Ger06100_Conta_Contabil_Service.verificaContaNivelAnterior(widget.currentRow).then(
	 	    			function(success) {
		                	var contasNivelAnterior = success.dataset.contctbl;
		                	if(contasNivelAnterior.length>0){
		                		this.controlaCamposNivelConta(widget);
		                		widget.currentRow.CDCONTREDU = widget.currentRow.CDCONTCTBL.replace(/[^0-9]/g,'');
		                	}
		                	else{
		                		MessageService.showMessageByCode("MSG_NIVELANTERIOR");
		                		widget.currentRow.CDCONTANTE   = null;
								widget.currentRow.CDNVCONTCTBL = null;
		                		this.controlaCamposNivelConta(widget);
		                	}
		            	}.bind(this),
		            	function(callback){
		                	if(callback.data){
		                		ScreenService.showMessage(callback.data.error);
		                		this.controlaCamposNivelConta(widget);
		                	}
		            	}
		            );
				}
				else{
					this.controlaCamposNivelConta(widget);
					widget.currentRow.CDCONTREDU = widget.currentRow.CDCONTCTBL;
				}

			}else{
				MessageService.showMessageByCode("MSG_PRENCHIMENTONIVEL");
				widget.currentRow.CDCONTANTE   = null;
				widget.currentRow.CDNVCONTCTBL = null;
				this.controlaCamposNivelConta(widget);
			}
		}else{
			widget.currentRow.CDCONTANTE   = null;
			widget.currentRow.CDNVCONTCTBL = null;
		}
	};

	this.validacoesCadastramentoAutomatico = function (widget){
		if(widget.isValid()){
			switch(widget.currentRow.TIPOCADASTRO) {
			    case '1':
			        if( Ger06100_Conta_Contabil_Service.validaIntervaloContas(widget.currentRow.P_CONTAINICIAL,widget.currentRow.P_CONTAFINAL) ){
			        	MessageService.confirmMessageByCode("CONFIRM_PARAMETRO_CADASTRO", { "IDENTIFICADOR": IDENTIFICADOR[widget.currentRow.P_IDPADRREL]},
			        	{'icon': 'question',
			        	'success': function (success) {
								widget.currentRow.P_CONTAINICIAL = widget.currentRow.P_CONTAINICIAL.replace(/[^0-9]/g,'');
								widget.currentRow.P_CONTAFINAL   = widget.currentRow.P_CONTAFINAL.replace(/[^0-9]/g,'');
								salvarCadastramentoAutomatico(widget);
							}
			        	});
			        }else{
			        	MessageService.showMessageByCode("MSG_INTERVALOCONTA");
			        }
			        break;
			    case '2':
			        if( Ger06100_Conta_Contabil_Service.validaIntervaloContas(widget.currentRow.P_CONTAINICIAL,widget.currentRow.P_CONTAFINAL) ){
			           	MessageService.confirmMessageByCode("CONFIRM_CADASTRO", {},
			        	{'icon': 'question',
			        	'success': function (success) {
								widget.currentRow.P_CONTAINICIAL = widget.currentRow.P_CONTAINICIAL.replace(/[^0-9]/g,'');
								widget.currentRow.P_CONTAFINAL   = widget.currentRow.P_CONTAFINAL.replace(/[^0-9]/g,'');
								salvarCadastramentoAutomatico(widget);
							}
			        	});
			        }else{
			        	MessageService.showMessageByCode("MSG_INTERVALOCONTA");
			        }
			        break;
			    case '3':
			    	MessageService.confirmMessageByCode("CONFIRM_PARAMETRO_CONTA", {"PARAMETRO":widget.currentRow.P_CONTANTIGA, "PARAM":widget.currentRow.P_CONTNOVA},
			        	{'icon': 'question',
			        	'success': function (success) {
							    salvarCadastramentoAutomatico(widget);
						    }
			        	});
			    	break;
			}
		}
	};

	var salvarCadastramentoAutomatico = function (widget){
		var widgetContaContabil = templateManager.container.getWidget('widgetContaContabil');
		if(widget.isValid()){
			Ger06100_Conta_Contabil_Service.salvarCadastramentoAutomatico(widget.currentRow).then(
				function(success) {
	            	ScreenService.closePopup();
	            	widgetContaContabil.activate();
	            	widgetContaContabil.reload();
	            	MessageService.showMessageByCode("MSG_SUCESSOCADASTRO");

	        	}.bind(this),
	        	function(callback){
	            	if(callback.data){
	            		ScreenService.showMessage(callback.data.error);
	            	}
	        	}
	        );
		}
	};

	this.controlaCamposCadastramentoAutomatico = function (widget){
		var camposTipo1 = ['P_CONTAINICIAL','P_CONTAFINAL','P_IDPADRREL'];
		var camposTipo2 = ['P_CONTAINICIAL','P_CONTAFINAL','P_CONTABASE'];
		var camposTipo3 = ['P_CONTANTIGA','P_CONTNOVA','TIPOCONTA'];
		var campoAntigo = widget.getField('P_CONTANTIGA');
		var campoNovo   = widget.getField('P_CONTNOVA');

		this.limpaCampo();

		switch( widget.getField('TIPOCADASTRO').value() ) {
		    case '1':
		        this.statusField(camposTipo2,widget, false);
		        this.statusField(camposTipo3,widget, false);
		        this.statusField(camposTipo1,widget, true);
		        break;
		    case '2':
		        this.statusField(camposTipo1,widget, false);
		        this.statusField(camposTipo3,widget, false);
		        this.statusField(camposTipo2,widget, true);
		        break;
       	    case '3':
		        widget.currentRow.TIPOCONTA='ECD';
		        campoAntigo.dataSource.name ='ctb#/crud/contrefe';
				campoNovo.dataSource.name   ='ctb#/crud/contrefe';
		        this.statusField(camposTipo1,widget, false);
		        this.statusField(camposTipo2,widget, false);
		        this.statusField(camposTipo3,widget, true);
		        break;
		}
		widget.reload();
	};

	this.statusField = function  (nomesFileds, widget, visibilidade){
		nomesFileds.forEach(function(nome) {
		    widget.getField(nome).isVisible = visibilidade;
		    if(visibilidade)
		    	 widget.getField(nome).validations.required = true;
			else
				delete (widget.getField(nome).validations.require);

		});

	};

	this.controlaTipoContaReferencial = function(field){
		var widget = field.widget;
		var campoAntigo = widget.getField('P_CONTANTIGA');
		var campoNovo   = widget.getField('P_CONTNOVA');
		if(field.value()==='ECD'){
			campoAntigo.dataSource.name ='cadCtb#/crud/contrefe';
			campoNovo.dataSource.name   ='cadCtb#/crud/contrefe';
		}
		else if(field.value()==='AUX'){
			campoAntigo.dataSource.name ='cadCtb#/crud/contrefeaux_contacontabil';
			campoNovo.dataSource.name   ='cadCtb#/crud/contrefeaux_contacontabil';
		}
		widget.currentRow.P_CONTANTIGA = '';
		widget.currentRow.P_CONTNOVA   = '';
	};

	this.restauraPadrao = function(widget){
		var widgetcadastramentoAutomatico = templateManager.container.getWidget('cadastramentoAutomatico');

		widgetcadastramentoAutomatico.currentRow.TIPOCADASTRO = '1';
		this.controlaCamposCadastramentoAutomatico(widgetcadastramentoAutomatico);
	};

	this.limpaCampo = function(){
		var widget = templateManager.container.getWidget('cadastramentoAutomatico');
		widget.fields.forEach(function(data){
			if(data.name != 'TIPOCADASTRO')
				data.value('');
		});
	};

	/**
     * Confirmar Adição
     */
    this.confirmaAdicionar = function(){
        var widget = templateManager.container.getWidget('formContaContabil');

        widget.getField('CDCONTCTBL').focused = true;

    };


};

Configuration(function(ContextRegister) {
     ContextRegister.register('Ger06100_Conta_Contabil_Controller', Ger06100_Conta_Contabil_Controller);
});

// FILE: ./assets/js/controllers/Ger06300_CentroDeCusto_Controller.js
function Ger06300_CentroDeCusto_Controller(General, ScreenService, templateManager, ZHPromise) {
	
	var self = this;

	var hasDuplicateKeys = function(widget) {
		var codFilial = widget.currentRow.CDFILIAL;
		var codCentCust = widget.currentRow.CDCENTCUST;
		var arr = widget.dataSource.data.filter(function(data) {
			return ((data.CDCENTCUST === codCentCust) && (data.CDFILIAL === codFilial));
		});
		return (arr.length > 1);
	};
	
	this.saveCentroDeCusto = function(widget) {
		
		if(widget.isValid()){
			widget.saveRow().then(function() {
				if (widget.currentRow.__is_new) {
					widget.list(true);
					ScreenService.goBack();
					widget.reload();
				} else {
					widget.view();
				}
				var unidadeWidget = templateManager.container.getWidget('centroCustoUnidade');
				if (typeof unidadeWidget.dataSource.data !== "undefined") {
					var matchingRows = unidadeWidget.dataSource.data.filter(function(row) {
				  	return (row.CDCENTCUST == widget.currentRow.CDCENTCUST);
					});
				if (matchingRows.length > 0) {
					unidadeWidget.reload();
				}
				unidadeWidget.getField("NMCENTCUST").reload();
			}

			},function(callback){
					if(callback.data){
						ScreenService.showMessage(callback.data.error);
					}
			});
		}

	};

	this.saveCentroDeCustoUnidade = function(widget) {
		var unidadeFiltro = templateManager.container.getWidget('unidadeTabbed').getField('NMFILIAL').value();
		var unidadeWidget = templateManager.container.getWidget('centroCustoUnidade').getField('NMFILIAL').value();

		if (widget.isValid()) {
			if (widget.currentRow.__is_new) {
				if (!hasDuplicateKeys(widget)) {
					widget.saveRow(widget).then(function(success) {
						widget.list(true);
						ScreenService.goBack();
						
						widget.reload();
					}, function(callback) {
							if(callback.data){
								ScreenService.showMessage(callback.data.error);
							}
					});
				}else {
					ScreenService.showMessage("Centro de Custo já cadastrado para a unidade selecionada.");
				}
			}else{
				widget.saveRow(widget).then(function(success) {
					widget.view();
					if(unidadeFiltro!==unidadeWidget){
						widget.reload();
					}
					//verifyAndChangeUnidade(widget);
				}, function(callback) {
						if(callback.data){
							ScreenService.showMessage(callback.data.error);
						}
				});
			}
		}
	};

	this.setDefaultUnidade = function(childWidget) {
		var widget = childWidget.parent;
		childWidget.currentRow.CDFILIAL = widget.currentRow.CDFILIAL;
		childWidget.currentRow.NMFILIAL = widget.currentRow.NMFILIAL;
	};

	this.updateGridFilter = function(widget) {
		var childWidget = templateManager.container.getWidget("centroCustoUnidade");
		childWidget.dataSourceFilter[0].value = widget.currentRow.CDFILIAL;
		childWidget.reload();
	};
	
	this.setDefaultValueCentroCustoPadrao = function(args){
		var centroCustoPadrao = templateManager.container.getWidget('centroCustoUnidade').getField('CENTCUSTPADRAO');
		centroCustoPadrao.value('S');
	};
	
	self.adicionaCentroCusto = function(widget){
		var unidadeWidget = templateManager.container.getWidget('unidadeTabbed');
		if(unidadeWidget.isValid()){
			widget.newRow();
		}else{
			ScreenService.showMessage("Operação bloqueada. Informe a Unidade para adicionar Centro de Custo.");
		}
	};
	
	self.cadastrarAutomatico = function(widget) {
		var widgetCadAutomatico = templateManager.container.getWidget('cadAutomaticoPopup');
		widgetCadAutomatico.currentRow.NMFILIAL = '';
		widgetCadAutomatico.currentRow.NMCENTCUST = '';
		//if(widgetCadAutomatico.isValid()){
			ScreenService.openPopup(widgetCadAutomatico);
		//}else{
			//ScreenService.showMessage("Não.");
		//}
	};
	 
	self.questionCadastramentoAutomatico = function(widget){
        if(widget.currentRow.IDOPERACAO === 'S'){
            ScreenService.confirmMessage('CONFIRM_SUBSTITUIR', 'question', function () {
                self.geraCadastramentoAutomatico();
            });
        } else if(widget.currentRow.IDOPERACAO === 'I'){
            self.geraCadastramentoAutomatico();
        }
    };
    
    self.geraCadastramentoAutomatico = function(){
        var widgetPrincipal = templateManager.container.getWidget('centroCusto');
        var widgetSecundaria = templateManager.container.getWidget('centroCustoUnidade');
        var CadastramentoAutomatico = templateManager.container.getWidget('cadAutomaticoPopup');
        CadastramentoAutomatico.currentRow.NRORG = getLocalVar('NRORG');
        CadastramentoAutomatico.currentRow.CDOPERADOR = getLocalVar('CDOPERADOR');
        CadastramentoAutomatico.currentRow.DATA = moment().format('DD/MM/YYYY');
        General.callRestEngine('cadCtb#/cadastroAutomaticoCentroCusto',
        'Row', 
        CadastramentoAutomatico.currentRow).then(
           function(success){
                ScreenService.closePopup();
                ScreenService.showMessage('Cadastro realizado com sucesso.');
                templateManager.container.getWidget('cadAutomaticoPopup').isVisible = false;
                CadastramentoAutomatico.currentRow = {};
                widgetPrincipal.reload();
                widgetSecundaria.reload();
           }, function(error){
               ScreenService.showMessage(error.dataset.error);
           });
    };
    
    self.adicionar = function(){    	
    	var widget= templateManager.container.getWidget('centroCusto');
    	self.geraCodigo().then(function(cdcentcust_new){
		  widget.currentRow.CDCENTCUST = cdcentcust_new;
	});
    };
    
    
    self.geraCodigo = function (){
		
 		var deferred = ZHPromise.defer();
 		
 	General.callRestEngine('cadCtb#/crud/centcust', 'FilterData', []).then(function(centcust){
			var filiais = centcust.dataset.centcust;
			
			var CDCENTCUST = [];
			filiais.forEach(function(filial){
				CDCENTCUST.push(filial.CDCENTCUST);
			});
			
			var CDCENTCUST_new = '';
			
			while(CDCENTCUST.includes(CDCENTCUST_new) || !CDCENTCUST_new){
 				CDCENTCUST_new = Math.random().toString(36).substring(2, 6).toUpperCase();
			}
			
			deferred.resolve(CDCENTCUST_new);
		});
		
		return deferred.promise;		
	};
	
	
	
}

Configuration(function (ContextRegister) {
	ContextRegister.register('Ger06300_CentroDeCusto_Controller', Ger06300_CentroDeCusto_Controller);
});

// FILE: ./assets/js/controllers/Ger09400_ParametroContabil_Controller.js
var Ger09400_ParametroContabil_Controller  = function(templateManager, ScreenService, General, ZHPromise, Ger09400_ParametroContabil_Service, ZhUtil){
    
    var widget;
    var widgetfilha;
    
    var self = this;
     
    var messages = {
        EMPRESA_DESTINO_CADASTRADA: 'Empresa destino do codigo V1 já cadastrada no banco',
        EMPRESA_ORIGEM_NAO_CADASTRADA: 'Empresa origem do codigo V1 não cadastrada no banco',
        DATA_PARAMETRO: 'Data do período de integração Doc. Fiscais Entrada deve estar dentro do período contábil.',
        DATA_INICIAL: 'Data do período de integração V1 deve ser menor do que a final.',
        DATA_INICIAL_FINAL: 'Data do período de integração V1 deve estar dentro do período contábil.',
        PARAMETRO_DATA: 'Data do período de integração V1 deve estar dentro do período contábil.',
        PARAMETRO_INICIAL: 'Data do período de integração V1 deve ser maior do que a inicial.',
        PARAMETRO_FINAL: 'Data do período de integração V1 deve estar dentro do período contábil.',
    };
    
    var contctblMask;
    var cdpargeral;
    
    function getErrorMessage(messageCode, dbColumnRelated)
    {
        var errorMessage;
        if(messageCode in messages){
            switch(messageCode){
                case "EMPRESA_DESTINO_CADASTRADA":
                case "EMPRESA_ORIGEM_NAO_CADASTRADA":
                    errorMessage = messages[messageCode].replace('V1', dbColumnRelated);
                    break;
                default:
                    errorMessage = messages[messageCode];
            }
        }
        else{
            errorMessage = messageCode;
	    }
        return errorMessage;
    }
    
    function getDataErrorMessage(messageCode, dbColumnRelated)
    {
        var errorMessage;
        if(messageCode in messages){
            switch(messageCode){
                case "DATA_PARAMETRO":
                case "DATA_INICIAL":
                case "DATA_INICIAL_FINAL":
                case "PARAMETRO_DATA":
                case "PARAMETRO_INICIAL":
                case "PARAMETRO_FINAL":
                    errorMessage = messages[messageCode].replace('V1', dbColumnRelated);
                    break;
                default:
                    errorMessage = messages[messageCode];
            }
        }
        else{
            errorMessage = messageCode;
	    }
        return errorMessage;
    }
    
    function requestSuccess()
    {
        return function(response){
            var messageCode = 'REQUEST_SUCCESS';
            ScreenService.showMessage( getErrorMessage(messageCode), 'SUCCESS');
            ScreenService.closePopup();
            templateManager.container.getActiveWidget().reload();
            templateManager.container.getWidget('cadastramentoAutomatico').fields.filter(function(field){
                return (field.fieldGroup != 'geral');
            }).forEach(function(field){
                field.readOnly = true;
                if (field.template === 'field/select-native.html')
                    field.value('N');
                else 
                    field.setValue('');
            });
        };
    }
    
    function requestError()
    {
        return function(response){
            var errorMessage = 'Timeout';
			if (response.data){
			   var error = response.data.error;
			   var data = response.data;
			   if(data.dataset)
			       if(data.dataset.empresaCadastrada)
			           if(data.dataset.empresaCadastrada.CDEMPRESA)
    			        errorMessage = getErrorMessage(error, data.dataset.empresaCadastrada.CDEMPRESA);
			   else{
			    errorMessage = getErrorMessage(error);
			   }
			}
            ScreenService.showMessage(errorMessage);
        };
    }

    self.setCampos = function()
    {
        widget = templateManager.container.getWidget('ger09400_parametro_contabil_grid');
        widgetfilha = templateManager.container.getWidget('ger09400_parametro_contabil_gridFilha');
        var banco = widget.dataSource.data;
        var result = Ger09400_ParametroContabil_Service.buildDataOfDataSource(banco);
        widgetfilha.dataSource.data = result[1];
        widget.dataSource.data = result[0];
        widget.activate();
    };

    self.setFormAndDates = function(currentRow, newRow){
        if(!currentRow.__is_new){
            self.setReadOnly(false, templateManager.container.getWidget('ger09400_parametro_contabil_grid'));
            for (var i = widgetfilha.dataSource.data.length - 1; i >= 0; i--) {
                if(widgetfilha.dataSource.data[i].CDEMPRESA == currentRow.CDEMPRESA){
                    for (var j = widgetfilha.fields.length - 1; j >= 0; j--) {
                        var fieldName = widgetfilha.fields[j].name;
                        widgetfilha.getField(fieldName).setValue(widgetfilha.dataSource.data[i][fieldName]);
                    }
                    for (var index = widget.dataSource.data.length - 1; index >= 0; index--) {
                        if(widget.dataSource.data[i].CDEMPRESA == currentRow.CDEMPRESA){
                            widget.getField('DTINIINTCONTDFE').minDate = widget.currentRow.DTINICCONT;
                            widget.getField('DTINIINTCONTDFE').maxDate = widget.currentRow.DTFININTCONTDFE;
                            widget.getField('DTINIINTCONTDFS').minDate = widget.currentRow.DTINICCONT;
                            widget.getField('DTINIINTCONTDFS').maxDate = widget.currentRow.DTFININTCONTDFS;
                            widget.getField('DTINICCTBL').minDate = widget.currentRow.DTINICCONT;
                            widget.getField('DTINICCTBL').maxDate = widget.currentRow.DTFINACCTBL;
                            widget.getField('DTINIINTCONTGPA').minDate = widget.currentRow.DTINICCONT;
                            widget.getField('DTINIINTCONTGPA').maxDate = widget.currentRow.DTFININTCONTGPA;
                            widget.getField('DTINIINTCONTFIS').minDate = widget.currentRow.DTINICCONT;
                            widget.getField('DTINIINTCONTFIS').maxDate = widget.currentRow.DTFININTCONTFIS;

                            widget.getField('DTFININTCONTDFE').maxDate = widget.currentRow.DTFINACONT;
                            widget.getField('DTFININTCONTDFE').minDate = widget.currentRow.DTINIINTCONTDFE;
                            widget.getField('DTFININTCONTDFS').maxDate = widget.currentRow.DTFINACONT;
                            widget.getField('DTFININTCONTDFS').minDate = widget.currentRow.DTINIINTCONTDFS;
                            widget.getField('DTFINACCTBL').maxDate = widget.currentRow.DTFINACONT;
                            widget.getField('DTFINACCTBL').minDate = widget.currentRow.DTINICCTBL;
                            widget.getField('DTFININTCONTGPA').maxDate = widget.currentRow.DTFINACONT;
                            widget.getField('DTFININTCONTGPA').minDate = widget.currentRow.DTINIINTCONTGPA;
                            //widget.getField('DTFININTCONTFIS').maxDate = widget.currentRow.DTFINACONT;
                            widget.getField('DTFININTCONTFIS').minDate = widget.currentRow.DTINIINTCONTFIS;

                            index = 0;
                        }
                    }
                    i = 0;
                }
            }
        } else {
            self.setReadOnly(false, newRow);
            newRow.currentRow.IDCONTGERE = 'N';
            newRow.currentRow.IDCONTCOME = 'N';
            newRow.currentRow.IDUTCUSTESTCONT = 'S';
            newRow.currentRow.IDSUGRAT = 'N';
            newRow.currentRow.IDUTSALDOSOC = 'N';
            newRow.currentRow.IDMSMCONTADBCR = 'N';
            newRow.currentRow.IDCONSVNDDFS = 'N';
            newRow.currentRow.IDDESPTRIBDIFAL = 'N';
            newRow.currentRow.IDRETESTSETOR = 'N';
        }
    };

    self.checaData = function(fieldInicial, fieldFinal, fieldMud, valueAntigo, widget)
    {
        if(fieldMud.name == 'DTINICCONT' || fieldMud.name == 'DTFINACONT'){
            if(Ger09400_ParametroContabil_Service.comparDate(fieldInicial.value(), fieldFinal.value())){
                ScreenService.showMessage('A data inicial do Período Contábil deve ser menor que a data final do Período Contábil.');
                fieldMud.setValue(valueAntigo);
            }else if(fieldMud.name == 'DTINICCONT'){
                var minDate = fieldMud.value();
                
                if(minDate)
                    minDate = moment(minDate, 'DD/MM/YYYY').startOf('month').format('DD/MM/YYYY');
                
                widget.fields.filter(function(field){
    				return ((field.fieldGroup == 'integracaoAgent2b' || field.fieldGroup == "periodoLancamento" || field.fieldGroup == "alteracaoPeriodo" || field.fieldGroup == "alteracaoControlesLancamento") && (field.name != 'DTINICCONT'));
                }).forEach(function(field){	
					if(Ger09400_ParametroContabil_Service.comparDateBefore(field.value(), fieldMud.value())){
    				    field.clearValue(widget.getField(field.name));
					}
    				self.setMin(field.name, minDate, widget);
    			});
            } else {
                var maxDate = fieldMud.value();
                
                if(maxDate)
                    maxDate = moment(maxDate, 'DD/MM/YYYY').endOf('month').format('DD/MM/YYYY');
                
    			widget.fields.filter(function(field){
                    return ((field.fieldGroup == 'integracaoAgent2b' || field.fieldGroup == "periodoLancamento" || field.fieldGroup == "alteracaoPeriodo" || field.fieldGroup == "alteracaoControlesLancamento") && (field.name != 'DTFINACONT'));
                }).forEach(function(field){	
					if(Ger09400_ParametroContabil_Service.comparDateAfter(field.value(), fieldMud.value()))
				        field.clearValue(widget.getField(field.name));
				    if(field.name != 'DTFININTCONTFIS'){
				        self.setMax(field.name, maxDate, widget);
				    }
    			});
            }
            self.contabilIsvalid(widget);
        } else if(fieldMud.name == 'DTINICLANC' || fieldMud.name == 'DTFINALANC'){
            if(Ger09400_ParametroContabil_Service.comparDate(fieldInicial.value(), fieldFinal.value())){
                ScreenService.showMessage('A data inicial do Período de Lançamento deve ser menor que a data final do Período de Lançamento.');
                fieldMud.setValue(valueAntigo);
            } else if(fieldMud.name == 'DTFINALANC'){
                if(Ger09400_ParametroContabil_Service.intraPeriodoConta(moment(fieldMud.value(),'DD/MM/YYYY').endOf('month').format('DD/MM/YYYY'), widget.currentRow.DTINICCONT, widget.currentRow.DTFINACONT)){
                    ScreenService.showMessage('A data final do Período de Lançamento deve estar dentro do Período Contábil.');
                    fieldMud.setValue(valueAntigo);
                } else {
                    var date = moment(fieldMud.value() ,'DD/MM/YYYY').endOf('month').format('DD/MM/YYYY');
                    widget.currentRow.DTFINALANC = date;
                }
            } else if(Ger09400_ParametroContabil_Service.intraPeriodoConta(fieldMud.value(), widget.currentRow.DTINICCONT, widget.currentRow.DTFINACONT)) {
                ScreenService.showMessage('O Período de Lançamento deve estar dentro do Período Contábil.');
                fieldMud.setValue(valueAntigo);
            }
        }
    };

    self.contabilIsvalid = function(widget){
        if(widget.getField('DTINICCONT').value() && widget.getField('DTFINACONT').value()){
            self.setReadOnly(false, templateManager.container.getWidget('ger09400_parametro_contabil_grid'));
        }
    };

    self.setReadOnly = function(bolean, widget){
        for (var i = 4; i < widget.fields.length; i++) {
            widget.fields[i].readOnly = bolean;
        }
    };

    self.setMin = function(fieldName, minDate, widget){
        widget.getField(fieldName).minDate = minDate;
    };

    self.setMax  = function(fieldName, maxDate, widget){
         widget.getField(fieldName).maxDate = maxDate;
    };

    self.checkDataInicial  = function(fieldNameIni, fieldNameFin, value, widget){
        if(widget.getField(fieldNameIni).value()){
            var campo = widget.getField(fieldNameIni).label;
            if(Ger09400_ParametroContabil_Service.comparDate(widget.currentRow.DTINICCONT, widget.getField(fieldNameIni).value())){
                var texto = "DATA_PARAMETRO";
                //ScreenService.showMessage(texto,{"PARAMETRO": widget.getField(fieldNameIni).label},{"PARAM": widget.getField('DTINICCONT').label});
                ScreenService.showMessage(getDataErrorMessage(texto, campo));
                widget.getField(fieldNameIni).clearValue(widget.getField(fieldNameIni));
            } else if(widget.getField(fieldNameFin).value()){
                if(Ger09400_ParametroContabil_Service.comparDate(widget.getField(fieldNameIni).value(), widget.getField(fieldNameFin).value())){
                    var mensagem = "DATA_INICIAL";
                    //ScreenService.showMessage(mensagem,{"INICIAL": widget.getField(fieldNameIni).label});
                    ScreenService.showMessage(getDataErrorMessage(mensagem, campo));
                    widget.getField(fieldNameIni).clearValue(widget.getField(fieldNameIni));
                }
            } else if(Ger09400_ParametroContabil_Service.comparDate(widget.getField(fieldNameIni).value(), moment(widget.currentRow.DTFINACONT, 'DD/MM/YYYY').endOf('month').format('DD/MM/YYYY'))){
                    var nota = "DATA_INICIAL_FINAL";
                //ScreenService.showMessage(nota, {"DATA": widget.getField(fieldNameIni).label}, {"FINAL": widget.getField('DTFINACONT').label});
                ScreenService.showMessage(getDataErrorMessage(nota, campo));
                widget.getField(fieldNameIni).clearValue(widget.getField(fieldNameIni));
            }
        }
    };
    
    self.checkDataFinal  = function(fieldNameIni, fieldNameFin, value, widget){
        if(widget.getField(fieldNameFin).value()){    
            var campo = widget.getField(fieldNameIni).label;
            // if(Ger09400_ParametroContabil_Service.comparDate(widget.getField(fieldNameFin).value(), moment(widget.currentRow.DTFINACONT, 'DD/MM/YYYY').endOf('month').format('DD/MM/YYYY'))){
            //     var texto = "PARAMETRO_DATA";
            //     ScreenService.showMessage(texto,{"PARAMETRO":widget.getField(fieldNameFin).label}, {"PARAM":widget.getField('DTFINACONT').label});
            //     //ScreenService.showMessage(getDataErrorMessage(texto, campo));
            //     widget.getField(fieldNameFin).clearValue(widget.getField(fieldNameFin));
            if(widget.getField(fieldNameIni).value()){
                if(Ger09400_ParametroContabil_Service.comparDate(widget.getField(fieldNameIni).value(), widget.getField(fieldNameFin).value())){
                    var mensagem = "PARAMETRO_INICIAL";
                    //ScreenService.showMessage(mensagem, {"INICIAL":widget.getField(fieldNameIni).label});
                    ScreenService.showMessage(getDataErrorMessage(mensagem, campo));
                    widget.getField(fieldNameFin).clearValue(widget.getField(fieldNameFin));
                }
            } else if(Ger09400_ParametroContabil_Service.comparDate(widget.currentRow.DTINICCONT, widget.getField(fieldNameFin).value())){
                var nota = "PARAMETRO_FINAL";
                //ScreenService.showMessage(nota,{"FINAL":widget.getField(fieldNameFin).label},{"INICIAL":widget.getField('DTINICCONT').label});
                ScreenService.showMessage(getDataErrorMessage(nota, campo));
                widget.getField(fieldNameFin).clearValue(widget.getField(fieldNameFin));
            }
        }
    };

    self.newRowParametroContabil = function(widget){
        widgetfilha = templateManager.container.getWidget('ger09400_parametro_contabil_gridFilha');
        widgetfilha.newRow();
        widgetfilha.enable = false;
        widget.newRow();
        widget.getField('NMEMPRESA').showOnForm = true;
        self.desabilitaCampos(widget);
        //self.edit(widget.widgets[0]);
    };

    self.edit = function(widget){
        if(widget.name == "ger09400_parametro_contabil_grid"){ 
            General.edit(widget);
            widget.getField('NMEMPRESA').showOnForm = false;
            widget.widgets.forEach(function (widgetfilha) {
		        widgetfilha.enabled = false;
		    });
		    
		    var minDate = moment(widget.currentRow.DTINICCONT, 'DD/MM/YYYY').startOf('month').format('DD/MM/YYYY');
		    var maxDate = moment(widget.currentRow.DTFINACONT, 'DD/MM/YYYY').endOf('month').format('DD/MM/YYYY');
		    
		    widget.fields.forEach(function(data){

				if(data.fieldGroup == 'integracaoAgent2b' || data.fieldGroup == "periodoLancamento" || data.fieldGroup == "alteracaoPeriodo" || data.fieldGroup == "alteracaoControlesLancamento"){
					self.setMin(data.name, minDate, widget);
					if(!widget.currentRow.DTFININTCONTFIS){
					    self.setMax(data.name, maxDate, widget);
					}
				}
			});
        } else if(widget.name == "ger09400_parametro_contabil_gridFilha"){
            widget.getParent().enabled = false;
            widget.template = widget.templateToForm;
            widget.backupRow = angular.copy(widget.currentRow);
            widget.edit();
            widget.currentRow.__is_new = false;
        }
    };
    
    self.cancelar = function(widget){
        var widgetpai = templateManager.container.getWidget('ger09400_parametro_contabil_grid');
        if (widget.currentRow.__is_new) {
            self.setReadOnly(false, widget);
            widgetpai.getField('NMEMPRESA').showOnForm = false;
            //widget.getParent().template = widget.getParent().templateToView;
            widget.getParent().currentRow = {};
            //widget.list(true);
            widget.dataSource.data.pop();
            widget.currentRow = {};
            widget.getParent().enable = true;
            widget.getParent().enabled = true;
            
            ScreenService.goBack();
        } else if (widget.mode === 'edit') {
            if (widget.name == 'ger09400_parametro_contabil_grid') {
                widget.view();
                widget.widgets.forEach(function (widget) {
			        widget.enabled = true;
		        });
		        
		        widget.fields.forEach(function(data){

    				if(data.fieldGroup == 'integracaoAgent2b' || data.fieldGroup == "periodoLancamento" || data.fieldGroup == "alteracaoPeriodo" || data.fieldGroup == "alteracaoControlesLancamento"){
    					delete data.minDate;
    					delete data.maxDate;
    				}
    			});
		        
                for (var j in widget.backupRow) {
                    widget.currentRow[j] = widget.backupRow[j];
                }
                widget.activate(); 
            } else if(widget.name == 'ger09400_parametro_contabil_gridFilha'){ 
                widget.view();
                widget.getParent().enabled = true;
                for (var i in widget.backupRow) {
                    widget.currentRow[i] = widget.backupRow[i];
                }
                widget.activate();
            } 
        }
    };

    self.salvar = function(widget, widgetfilha){
        if(widget.isValid() && widgetfilha.isValid()){
            widget.currentRow.IDCONTGERE = widgetfilha.currentRow.IDCONTGERE;
            widget.currentRow.IDCONTCOME = widgetfilha.currentRow.IDCONTCOME;
            widget.currentRow.IDUTCUSTESTCONT = widgetfilha.currentRow.IDUTCUSTESTCONT;
            widget.currentRow.IDSUGRAT = widgetfilha.currentRow.IDSUGRAT;
            widget.currentRow.IDUTSALDOSOC = widgetfilha.currentRow.IDUTSALDOSOC;
            widget.currentRow.IDMSMCONTADBCR = widgetfilha.currentRow.IDMSMCONTADBCR;
            widget.currentRow.IDCONSVNDDFS = widgetfilha.currentRow.IDCONSVNDDFS;
            widget.currentRow.IDDESPTRIBDIFAL = widgetfilha.currentRow.IDDESPTRIBDIFAL;
            widget.currentRow.DTINICRELA = widget.currentRow.DTINICCONT;
            widget.currentRow.DTFINARELA = widget.currentRow.DTFINACONT;
            widget.currentRow.IDRETESTSETOR = widgetfilha.currentRow.IDRETESTSETOR;
            widget.currentRow.IDCONSDTMOVIRETEST = widgetfilha.currentRow.IDCONSDTMOVIRETEST;
            
             widget.currentRow.IDCTBSINTETICO = widgetfilha.currentRow.IDCTBSINTETICO;
              widget.currentRow.IDGERESTLANCONT = widgetfilha.currentRow.IDGERESTLANCONT;
              widget.currentRow.IDCONTAJUDTCOMP = widgetfilha.currentRow.IDCONTAJUDTCOMP;
            
            if(widget.currentRow.__is_new){ 
                var filter = [
                    {
                        "name": "CDEMPRESA",
                        "operator": "IN",
                        "value": widget.currentRow.CDEMPRESA
                    }
                ];
                
                General.callRestEngine('cadCtb#/contopectbl_empresa', 'FilterData', filter).then(function (result) {
                    result = result.dataset.contopectbl_empresa;
                    
                    if(result.length == 0){
                        self.saveParametroContabil(widget, widgetfilha);
                    }else {
                        ScreenService.showMessage('Operação bloqueada. A empresa informada já possui cadastro.');
                    }
                });
            }else{
                self.saveParametroContabil(widget, widgetfilha);   
            }
        }else if(widgetfilha.name == 'ger09400_parametro_contabil_gridFilha'){
            ScreenService.showMessage("Preencha os campos obrigatórios da aba Períodos de Lançamentos.");
        }
    };
    
    /*
        Função para salvar os parametros contábeis
    */
    
    self.saveParametroContabil = function(widget, widgetfilha){
        if(widget.isValid() && widgetfilha.isValid()){
        	General.callRestEngine('cadCtb#/parametroContabil/save', 'DataSet', [widget.currentRow]).then(function(response) {
    			if(widget.name == 'ger09400_parametro_contabil_grid'){
    				widget.widgets.forEach(function(wid){
    					wid.enabled = true;
    				});
    				if(widget.enabled == false)
    					widget.enabled = true;
    			}else if (widgetfilha.name == 'ger09400_parametro_contabil_gridFilha')
    				widgetfilha.getParent().enabled = true;
    				
    			ScreenService.showMessage('Registro salvo com sucesso.');
    			ScreenService.closeSwipe();
    			
    			widget.list();
    			widget.activate();
    			widget.reload();
    		}, function(error) {
    			ScreenService.showMessage(error.data.error);
    		});
        }
    };
    
    self.atualizaForm = function(widget) {
        widget.currentRow = widget.dataSource.data[0]?widget.dataSource.data[0]:{};
        templateManager.updateTemplate();
    };
    
    self.recarregaWidget = function(widget) {
        widget.reload();
    };
    
    self.openPopupCadastramentoAutomatico = function(){
        var cadastramentoAutomaticoWidget = templateManager.container.getWidget("cadastramentoAutomatico");
        ScreenService.openPopup(cadastramentoAutomaticoWidget);
        cadastramentoAutomaticoWidget.newRow();
        cadastramentoAutomaticoWidget.fields.filter(function (field){
            return (field.fieldGroup != 'geral');
        }).forEach(function(field){
            field.readOnly = true;
            if(field.name != 'IDALTERAPERIODO' || field.name != 'IDALTERALANCAMENTO' )
                field.validations = {};
        });
    };
    
    self.cadastrarAutomaticamente = function(widget){
        if(widget.isValid()){
            if (widget.currentRow.IDALTERAPERIODO === 'S' || widget.currentRow.IDALTERALANCAMENTO === 'S'){
                validateSaldoPositivo(widget).then(function (){
                    validatelacnamentoPendenteRecalculo(widget).then(function(){
                        Ger09400_ParametroContabil_Service.cadastrarAutomaticamente(widget.currentRow).then(
                            requestSuccess(),
                            requestError()
                        );
                    });
                });
                widget.fields.forEach(function(data){
    				if(data.fieldGroup == "alteracaoPeriodo" || data.fieldGroup == "alteracaoControlesLancamento"){
    					delete data.minDate;
    					delete data.maxDate;
    				}
    			});
            } else {
                ScreenService.showMessage('Para alterar as parametrizações das empresas é necessário selecionar ao menos uma das opções (Períodos ou Controles de Lançamentos).');
            }
        }
    };
    
    self.deleteCrud = function (widget){
        General.deleteCrud(widget).then(function(){
            //widget.getField('NMEMPRESA').reload();
            //templateManager.container.getWidget('cadastramentoAutomatico').getField('NMEMPRESA').reload();
        });
    };

    self.changeReadOnlyOnPopupFieldGroups = function (widget, fieldGroupName, valueField){
        var readOnly;
        if (valueField === 'S') {
            readOnly = false;
        } else {
            readOnly = true;
        }
        
        //MEXI AQUI
        
        widget.fields.filter(function(field){
            return field.fieldGroup === fieldGroupName;
        }).forEach(function(field){
            
            if (readOnly){
                field.readOnly = readOnly;
                field.validations = {};
            } else {
                if(widget.currentRow.DTINICCONT && widget.currentRow.DTFINACONT){
                    field.readOnly = readOnly;
                    field.validations = {required: true};
                }else{
                    if(field.fieldGroup == 'alteracaoControlesLancamento' || (field.name == 'DTINICCONT' || field.name == 'DTFINACONT')){
                        field.readOnly = readOnly;
                        field.validations = {required: true};
                    }else{
                        field.readOnly = !readOnly;
                        field.validations = {};
                    }
                }
            }
        });
        
    };
    
    function validateSaldoPositivo (widget){
        var defer = ZHPromise.defer();
        General.callRestEngine('cadCtb#/parametroContabil/validateSaldoPositivo', 'Row', widget.currentRow).then(function(response){
            var  preenchido;
            var mensagem = '';
            response.dataset.saldo.forEach(function (data){
                if (!Util.isEmptyOrBlank(data)) {
                    preenchido = true;
                    mensagem = mensagem.concat('Empresa '.concat(data[0].CDEMPRESA).concat(' possui lançamentos pendentes de recálculo fiscal desde ').concat(data[0].DTSEMEVOLUCAO).concat('.\r\n'));
                }
            });
            if (!preenchido){
                defer.resolve();
            } else {
                ScreenService.showMessage(mensagem);
                defer.reject();
            }
        }, function(){
            defer.reject();
        });
        return defer.promise;
    }
    
    function validatelacnamentoPendenteRecalculo (widget){
        var defer = ZHPromise.defer();
        General.callRestEngine('cadCtb#/parametroContabil/validateLacnamentoPendenteRecalculo', 'Row', widget.currentRow).then(function(response){
            var  preenchido;
            var mensagem = '';
            response.dataset.lancamento.forEach(function (data){
                if (!Util.isEmptyOrBlank(data)){
                    preenchido = true;
                    mensagem = mensagem.concat('Empresa '.concat(data[0].CDEMPRESA).concat(' possui saldo com data superior à data informada para final do Período Contábil.\r\n'));
                }
            });
            if (!preenchido){
                defer.resolve();
            } else {
                ScreenService.showMessage(mensagem);
                defer.reject();
            }
        }, function(){
            defer.reject();
        });
        return defer.promise;
    }
    
    self.changeGridFilhaMode = function(){
        widgetfilha = templateManager.container.getWidget('ger09400_parametro_contabil_gridFilha');
        if (widgetfilha.getParent().mode != 'edit')
            widgetfilha.view();
    };
    
    self.setCalendarValueOnDtiniccontChange = function(widget){
        widget.fields.filter(function(field){
            return field.template === 'field/calendar.html';
        }).forEach(function(field){
            field.setValue('');
        });
    };
    
    self.verificaData = function(){
       var widget =  templateManager.container.getActiveWidget();  
       //Verifica se o campo de Período Cont. Inicial e Período Cont. Final estão vazios para bloquear os campos do Integração 
       if(widget.getField("DTINICCONT").value() != "" && widget.getField("DTFINACONT").value() != ""){
            widget.getField("DTINICLANC").readOnly      = false;    //Lançamento
            widget.getField("DTINICLANC").validations   = {required: true};
            widget.getField("DTFINALANC").readOnly      = false;    
            widget.getField("DTFINALANC").validations   = {required: true};
            widget.getField("DTINIINTCONTDFE").readOnly = false;    //Doc. Fiscais Entrada
            widget.getField("DTINIINTCONTDFE").validations   = {required: true};
            widget.getField("DTFININTCONTDFE").readOnly = false;
            widget.getField("DTFININTCONTDFE").validations   = {required: true};
            widget.getField("DTINIINTCONTDFS").readOnly = false;    //Doc. Fiscais Saída
            widget.getField("DTINIINTCONTDFS").validations   = {required: true};
            widget.getField("DTFININTCONTDFS").readOnly = false;
            widget.getField("DTFININTCONTDFS").validations   = {required: true};
            widget.getField("DTINICCTBL").readOnly      = false;    //Financeiro
            widget.getField("DTINICCTBL").validations   = {required: true};
            widget.getField("DTFINACCTBL").readOnly     = false;
            widget.getField("DTFINACCTBL").validations   = {required: true};
            widget.getField("DTINIINTCONTFIS").readOnly = false;    //Fiscal
            //widget.getField("DTINIINTCONTFIS").validations   = {required: true};
            widget.getField("DTFININTCONTFIS").readOnly = false;
            //widget.getField("DTFININTCONTFIS").validations   = {required: true};
            widget.getField("DTINIINTCONTGPA").readOnly = false;    //Gestão de Ativos
            widget.getField("DTINIINTCONTGPA").validations   = {required: true};
            widget.getField("DTFININTCONTGPA").readOnly = false;
            widget.getField("DTFININTCONTGPA").validations   = {required: true};
            
            widget.getField("DTINIINTCONTVEXT").readOnly = false;    //Venda Extemporânea
            //widget.getField("DTINIINTCONTVEXT").validations   = {required: true};
            widget.getField("DTFININTCONTVEXT").readOnly = false;
            //widget.getField("DTFININTCONTVEXT").validations   = {required: true};
       }else self.desabilitaCampos(widget);
    };
    
    self.setCampoVazio = function(widget){
        if(widget.getField("DTINICCONT").value() == ""){
            widget.currentRow.DTINIINTCONTDFE = ""; //Doc. Fiscais Entrada
            widget.currentRow.DTINIINTCONTDFS = ""; //Doc. Fiscais Saída
            widget.currentRow.DTINICCTBL = "";      //Financeiro
            widget.currentRow.DTINIINTCONTFIS = ""; //Fiscal
            widget.currentRow.DTINIINTCONTGPA = ""; //Gestão de Ativos
            widget.currentRow.DTINIINTCONTVEXT = ""; //Venda Extemporânea
        }
        if(widget.getField("DTFINACONT").value() == ""){
            widget.currentRow.DTFININTCONTDFE = "";
            widget.currentRow.DTFININTCONTDFS = "";
            widget.currentRow.DTFINACCTBL = "";
            widget.currentRow.DTFININTCONTFIS = "";
            widget.currentRow.DTFININTCONTGPA = "";
            widget.currentRow.DTFININTCONTVEXT = "";
        }
    };
    
    self.desabilitaCampos = function(widget){
        widget.getField("DTINICLANC").readOnly = true;      //Lançamento
        widget.getField("DTINICLANC").validations = {};
        widget.getField("DTFINALANC").readOnly = true;    
        widget.getField("DTFINALANC").validations = {};
        widget.getField("DTINIINTCONTDFE").readOnly = true; //Doc. Fiscais Entrada
        widget.getField("DTINIINTCONTDFE").validations = {};
        widget.getField("DTFININTCONTDFE").readOnly = true;
        widget.getField("DTFININTCONTDFE").validations = {};
        widget.getField("DTINIINTCONTDFS").readOnly = true; //Doc. Fiscais Saída
        widget.getField("DTINIINTCONTDFS").validations = {};
        widget.getField("DTFININTCONTDFS").readOnly = true;
        widget.getField("DTFININTCONTDFS").validations = {};
        widget.getField("DTINICCTBL").readOnly = true;      //Financeiro
        widget.getField("DTINICCTBL").validations = {};
        widget.getField("DTFINACCTBL").readOnly = true;
        widget.getField("DTFINACCTBL").validations = {};
        widget.getField("DTINIINTCONTFIS").readOnly = true; //Fiscal
        widget.getField("DTINIINTCONTFIS").validations = {};
        widget.getField("DTFININTCONTFIS").readOnly = true;
        widget.getField("DTFININTCONTFIS").validations = {};
        widget.getField("DTINIINTCONTGPA").readOnly = true; //Gestão de Ativos
        widget.getField("DTINIINTCONTGPA").validations = {};
        widget.getField("DTFININTCONTGPA").readOnly = true;
        widget.getField("DTFININTCONTGPA").validations = {};
        
        widget.getField("DTINIINTCONTVEXT").readOnly = true; //Venda Extemporânea
        widget.getField("DTINIINTCONTVEXT").validations = {};
        widget.getField("DTFININTCONTVEXT").readOnly = true;
        widget.getField("DTFININTCONTVEXT").validations = {};
    };
    
    self.habilitaPopUpPeriodoControle = function(){
        var widget = templateManager.container.getActiveWidget();
        
        var dataSourceName, alteraPeriodoBoo, altPeriodoValue, altLancamentoBoo, altLancamentoValue;
        
        // Tipo de Operação [Inclusão - I|Alteração - A]
        if(widget.getField('OPERACAOEMP').value() == 'I'){
            dataSourceName = 'cadCtb#/crud/contopectbl_empresa_inc';
            
            alteraPeriodoBoo   = true;  
            altPeriodoValue    = 'S';
            altLancamentoBoo   = true;
            altLancamentoValue = 'S';
        }else{
            dataSourceName = 'cadCtb#/contopectbl_empresa';
            
            alteraPeriodoBoo   = false;  
            altPeriodoValue    = 'N';
            altLancamentoBoo   = false;
            altLancamentoValue = 'N';
        }
        
        widget.getField('NMEMPRESA').dataSource.name = dataSourceName;
        widget.getField('NMEMPRESA').reload();
        
        widget.getField('IDALTERAPERIODO').readOnly = alteraPeriodoBoo;  
        widget.getField('IDALTERAPERIODO').value(altPeriodoValue);
        widget.getField('IDALTERALANCAMENTO').readOnly = altLancamentoBoo; 
        widget.getField('IDALTERALANCAMENTO').value(altLancamentoValue);
        
        self.changeReadOnlyOnPopupFieldGroups(widget, 'alteracaoPeriodo', altPeriodoValue);
        self.changeReadOnlyOnPopupFieldGroups(widget, 'alteracaoControlesLancamento', altLancamentoValue);
    };
    
    self.changeEmpresaOrigem = function(){
        var widget = templateManager.container.getActiveWidget();
        
        var minDate = moment(widget.currentRow.DTINICCONT, 'DD/MM/YYYY').startOf('month').format('DD/MM/YYYY');
		var maxDate = moment(widget.currentRow.DTFINACONT, 'DD/MM/YYYY').endOf('month').format('DD/MM/YYYY');
        
        widget.fields.filter(function(field){
            return (field.fieldGroup == 'alteracaoPeriodo') && (field.name != 'DTINICCONT' && field.name != 'DTFINACONT');
        }).forEach(function(field){
            self.setMin(field.name, minDate, widget);
            if(!widget.currentRow.DTFININTCONTFIS){
			    self.setMax(field.name, maxDate, widget);
			}
        });
        
        var altPeriodoValue    = widget.getField('IDALTERAPERIODO').value();
        var altLancamentoValue = widget.getField('IDALTERALANCAMENTO').value();
        
        self.changeReadOnlyOnPopupFieldGroups(widget, 'alteracaoPeriodo', altPeriodoValue);
        self.changeReadOnlyOnPopupFieldGroups(widget, 'alteracaoControlesLancamento', altLancamentoValue);
    };
    
    self.colocaDefaultControleLancamento = function(widget, empresa){
        
        if(empresa){
            if(!widget.currentRow.CDEMPRESAORG){
                widget.fields.filter(function(field){
        			return (field.fieldGroup == "alteracaoControlesLancamento");
                }).forEach(function(field){	
        			field.value('N');
        		});
            }
            
        }else{
            if(!widget.currentRow.CDEMPRESAORG && widget.currentRow.IDALTERALANCAMENTO == 'N'){
                widget.fields.filter(function(field){
        			return (field.fieldGroup == "alteracaoControlesLancamento");
                }).forEach(function(field){
                    
                    if(field.name != 'IDUTCUSTESTCONT')
        			    field.value('N');
    			    else field.value('S');
        		});
            }
        }
    };
    
    self.openPopupConfigurarMascaraContabil = function(){
        var configurarMascaraContabilWidget = templateManager.container.getWidget("configurarMascaraContabil");
        ScreenService.openPopup(configurarMascaraContabilWidget);
        General.edit(configurarMascaraContabilWidget);
    };
    
    self.validaMascara = function(widget){
        if(widget.getField('CDPICTCCTB').value()){
            var mascara = widget.currentRow.CDPICTCCTB; 
            if(mascara.match(/[A-Zb-z0-8!@#$%^&*(),?":{}|<>]/g)){ 
                ScreenService.showMessage("Máscara inválida. Somente são aceitos caracteres (9), (.) e (a)." );
                return false; 
            } 
            
            if(mascara.indexOf('.') == -1){ 
                ScreenService.showMessage("Máscara informada deve ter no mínimo dois níveis." );
                return false; 
            } 
            
            if(mascara.indexOf('..') != -1){ 
                ScreenService.showMessage("Máscara informada não pode conter dois pontos juntos (..)." );
                return false; 
            } 
            
            if(!(mascara.charAt(0).match(/[9a]/g) && mascara.charAt(mascara.length-1).match(/[9a]/g))){ 
                ScreenService.showMessage("Máscara informada não pode começar ou terminar com ponto (.)." );
                return false; 
            }
            return true;
        }
        return false;
    };
    
    self.salvarMascara = function(widget){
        var widgetAcoes = templateManager.container.getWidget('actions_widget');
        var widgetPrincipal = templateManager.container.getWidget('ger09400_parametro_contabil_grid');
        
        if(widget.isValid() && self.validaMascara(widget)){
            General.callRestEngine('cadCtb#/crud/contctbl', 'FilterData', []).then(function (result) {
                result = result.dataset.contctbl;
                
                if(result.length == 0){
                    General.saveCrud(widget).then(function(sucess){
                        ScreenService.showMessage('Máscara Contábil salva com sucesso.');
                        ScreenService.closePopup(widget);
                        ScreenService.closePopup(widgetAcoes);
                        widgetPrincipal.activate();
                    }.bind(this),
                    
                    function(error){
                        ScreenService.showMessage('Ocorreu um erro. Não foi possível salvar a Máscara Contábil.');
                    });
                    
                }else {
                    ScreenService.showMessage('Operação bloqueada. Máscara Contábil não pode ser alterada caso já existam contas contábeis cadastradas.');
                }
            });
        }
    };
    
    /**
     * Confirmar Adição
     */
    self.confirmaAdicionar = function(){
        var widget = templateManager.container.getWidget('ger09400_parametro_contabil_grid');

        widget.getField('NMEMPRESA').focused = true;

    };

};

Configuration(function(ContextRegister){
    ContextRegister.register('Ger09400_ParametroContabil_Controller', Ger09400_ParametroContabil_Controller);
});

// FILE: ./assets/js/controllers/Ger17300_Informativo_Composicao_Custos.js
var Ger17300_Informativo_Composicao_Custos = function(ScreenService, General, templateManager, localStorageEngine) {
    
    var self = this;
    
    this.setContctblMask = function() {
        General.callRestEngine("cadCtb#/crud/paramgeral", "FilterData", []).then(function(response) {
            var paramgeral = response.dataset.paramgeral[0];
            localStorageEngine.setLocalVar(paramgeral.CDPICTCCTB);
        });
        
    };
    
    this.verificaTipo = function(widget) {
        
        var widgetFormulario = templateManager.container.getWidget('ger18200_registro_p200_apuracao_da_base_de_calculo');
        var visible = widget.currentRow.IDTIPOL210 == 'E';
        widgetFormulario.isVisible = visible;
        if(visible){
            widgetFormulario.reload();
        }
    };

    this.newContCtbl = function(widget) {
        var widgetGrid = templateManager.container.getWidget('ger17300_registro_p130_receitas_incentivadas');
        widget.newRow();
        widget.currentRow.__is_new = true;
        widget.currentRow.NRSEQREGL210 = widgetGrid.currentRow.NRSEQREGL210;
        
    };
    
    this.salvarFormulario = function(widget) {
        this.validarDisponibilidade(widget.getField('NMCONTCTBL'));
        //widget.paramsNewCode.__new_code_pk = "CONTL210ECF"+ widget.currentRow.NRSEQREGL210;
        if(widget.isValid()){ 
            General.saveCrud(widget).then(function(success) {
                widget.reload();
            }); 
        }
    };
    
	this.validarDisponibilidade = function(field){
		var parentWidgetData = field.widget.dataSource.data;
		var disponivel = parentWidgetData.filter(function(row){
			return row[field.valueField]==field.widget.currentRow[field.valueField];
		});
		if(disponivel.length > 1){
			field.setValue(null);
			ScreenService.showMessage('Conta Contábil já informada para o item selecionado.');
		}
	};
            
    self.abreImportacao = function() {
        
        var widgetImportacao = templateManager.container.getWidget('importacaoL210');
        
        widgetImportacao.currentRow = {};
        widgetImportacao.currentRow.__is_new = true;
        //widgetImportacao.isVisible
        ScreenService.openPopup(widgetImportacao);
    };
    
    /**  importaçao*/
    this.salvarImportacaoL210 = function (widget){
        if(widget.isValid()){
            General.callRestEngine("cadCtb#/crud/ger17300_contl210ecf", "FilterData", []).then(function(dataSource) {
                if(!!(dataSource && dataSource.dataset && dataSource.dataset.ger17300_contl210ecf.length)){
                    ScreenService.confirmMessage('CONFIRM_EXCLUSAO_LAN', "question", function () {
                        self._salvarImportacaoL210(widget);            
                    });   
                }
                else{
                    self._salvarImportacaoL210(widget);
                }
            });
        }
    }; 
     
     
    this._salvarImportacaoL210 = function (widget){       
        General.callRestEngine("/salvarImportacaoL210", "Row", widget.currentRow).then(function(sucess) {
  	        ScreenService.closePopup();
            ScreenService.successNotification('Registros importados com sucesso.');
            widget.reload();
  	    }, function(error){
  	        ScreenService.showMessage(error.dataset.error);
  	    });

    };        
            
};
        
Configuration(function(ContextRegister) {
    ContextRegister.register('Ger17300_Informativo_Composicao_Custos', Ger17300_Informativo_Composicao_Custos);
});

// FILE: ./assets/js/controllers/Ger17500_RegistroY600Socios_Controller.js
function Ger17500_RegistroY600Socios_Controller(General, ScreenService, templateManager, ZHPromise) {

	var self = this;
	
	self.verificaPais = function(widget){
		if(widget.getField('CDPAISREG').value() == '105'){
			widget.getField('CDREG').readOnly = false;
			widget.getField('NRCPFREPREG').readOnly = false; 
			widget.getField('QUALIREPREG').readOnly = false;
		}else{
			widget.getField('CDREG').readOnly = true;
			widget.getField('NRCPFREPREG').readOnly = true;
			widget.getField('QUALIREPREG').readOnly = true;
		}
	};

	self.alteraPais = function(widget){
		self.verificaPais(widget);
		
		widget.getField('CDREG').value('');
		widget.getField('NRCPFREPREG').value('');
		widget.getField('QUALIREPREG').value('00');
	};
	
	self.salvaRegY600 = function(widget){
		if(widget.isValid()){
			
			if(widget.currentRow.NRCPFREPREG && widget.currentRow.QUALIREPREG =='00'){
				ScreenService.showMessage("Qualificação do Representante deve ser informada.", "warning");
				return;
			}
			
			if(!widget.currentRow.NRCPFREPREG && widget.currentRow.QUALIREPREG !='00'){
				ScreenService.showMessage("CPF do Representante deve ser informado.", "warning");
				return;
			}
				
			var cdreggrid = widget.currentRow.CDREG;
			var cdreg = widget.currentRow.CDREG;
			if(cdreg)
				widget.currentRow.CDREG = cdreg.replace(/[-./]+/g, '');
			var nrcpfrepreg = widget.currentRow.NRCPFREPREG;
			if(nrcpfrepreg){
				widget.currentRow.NRCPFREPREG = nrcpfrepreg.replace(/[-.]+/g, '');
			}
			
            var filter = [
	            	{
	            		"name" : "CDREG",
	                    "operator" : "=",
	                    "value" : widget.currentRow.CDREG
	            	},
	            	{
	            		"name" : "NRORG",
	                    "operator" : "=",
	                    "value" : widget.currentRow.NRORG
	            	}
            ];
			General.callRestEngine("cadCtb#/regy600socio_cpf", "FilterData", filter).then(function(data) {
				var existCpf = data.dataset.regy600socio_cpf.length;
				if(existCpf == 0){
					General.widgetSave(widget).then(function(){
						if(cdreg)
							if((cdreg != cdreggrid.replace(/[-./]+/g, '')))
								widget.currentRow.CDREGGRID = cdreggrid;
						else widget.currentRow.CDREGGRID = cdreggrid;
						
						templateManager.updateTemplate();
						// widget.reload();
					});
				}else{
					ScreenService.showMessage("Já existe um sócio cadastrado para esse CPF/CNPJ.", "warning");
					return;
				}
			});
			
			// templateManager.updateTemplate();
		}
	};
	
	self.adicionaRegY600 = function(widget){
		widget.newRow();
		widget.getField('CDREG').readOnly = true;
		widget.getField('NRCPFREPREG').readOnly = true;
		widget.getField('QUALIREPREG').readOnly = true;
		self.verificaMascara(widget);
	};
	
	self.editaRegY600 = function(widget){
		General.widgetEdit(widget);
		self.verificaPais(widget);
		self.verificaMascara(widget);
	};
	
	self.alteraTipoReg = function(widget){
		self.verificaMascara(widget);
		widget.getField('CDREG').value('');
	};
	
	self.verificaMascara = function(widget){
		if(widget.getField('IDTIPOREG').value() == 'PF'){
			widget.getField('CDREG').mask.params.mask = "999.999.999-99";
		}else{
			widget.getField('CDREG').mask.params.mask = "99.999.999/9999-99";
		}
		widget.redraw();
	};
	
	self.configuraMascCnpjCpf = function(widget) {
	    var data = widget.dataSource.data;
	    var inscFormatada;
	    data.forEach(function(value){
            if(value.CDREG){
	            if(value.CDREG.length === 14)
	                 inscFormatada = value.CDREG.substr(0, 2) + '.' + value.CDREG.substr(2, 3) + '.' + value.CDREG.substr(5, 3) + '/' + value.CDREG.substr(8, 4) + '-' + value.CDREG.substr(12, 2);
	            else if(value.CDREG.length === 11)
	                 inscFormatada = value.CDREG.substr(0, 3) + '.' + value.CDREG.substr(3, 3) + '.' + value.CDREG.substr(6, 3) + '-' + value.CDREG.substr(9, 2);
	            else inscFormatada = null;
	            value.CDREGGRID = inscFormatada?inscFormatada:value.CDREG;
	            
            }
	    });
	};
	
	self.checkCpfCnpj = function(widget) {
		if(widget.currentRow.CDREG){
        	var inscricao = General.inscricaoFormat(widget.currentRow.CDREG);

	        if (!inscricao.valid) {
	            if (inscricao.tipo.cod == 'J') inscricao.tipo.msg = 'CNPJ' + " \"" + inscricao.value + "\" inválido!";
				else if (inscricao.tipo.cod == 'F') inscricao.tipo.msg = 'CPF' + " \"" + inscricao.value + "\" inválido!";
				else inscricao.tipo.msg = "CNPJ/CPF inválido!";
	            
	            if (inscricao.tipo.msg) ScreenService.showMessage(inscricao.tipo.msg, "warning");
	            widget.currentRow.CDREG = null;
	            
	        }
		}
    };
    
    
    self.checkCpf = function(widget) {
    	if(widget.currentRow.NRCPFREPREG){
	        var inscricao = General.inscricaoFormat(widget.currentRow.NRCPFREPREG);
	
	        if (!inscricao.valid) {
	            if (inscricao.tipo.cod == 'J') inscricao.tipo.msg = 'CNPJ' + " \"" + inscricao.value + "\" inválido!";
				else if (inscricao.tipo.cod == 'F') inscricao.tipo.msg = 'CPF' + " \"" + inscricao.value + "\" inválido!";
				else inscricao.tipo.msg = "CPF inválido!";
	            
	            if (inscricao.tipo.msg) ScreenService.showMessage(inscricao.tipo.msg, "warning");
	            widget.currentRow.NRCPFREPREG = null;
	        }
    	}else{
    		widget.currentRow.QUALIREPREG = '00';
    	}
    };
	
}

Configuration(function (ContextRegister) {
	ContextRegister.register('Ger17500_RegistroY600Socios_Controller', Ger17500_RegistroY600Socios_Controller);
});

// FILE: ./assets/js/controllers/Ger17600_RegistroY600SociosPorEmpresa_Controller.js
function Ger17600_RegistroY600SociosPorEmpresa_Controller(General, ScreenService, templateManager, ZHPromise) {

	var self = this;
	
	this.salvaSocio = function(widget){
		if(widget.isValid()){
			if((self.verificaPorcentagem(widget) == true) && (self.verificaData(widget) == true)){
				if(self.verificaQualificacao(widget) == true){
					if((widget.currentRow.__is_new == true)){
			            var filter = [
			            		{
				            		"name" : "CDEMPRESA", 
				                    "operator" : "=",
				                    "value" : widget.currentRow.CDEMPRESA
				            	},
				            	{
				            		"name" : "NRSEQREG",
				                    "operator" : "=",
				                    "value" : widget.currentRow.NRSEQREG
				            	},
				            	{
				            		"name" : "NRORG",
				                    "operator" : "=",
				                    "value" : getLocalVar('NRORG')
				            	}
			            ];
						General.callRestEngine("cadCtb#/crud/socio_quadro_societario", "FilterData", filter).then(function(data) {
							var existeSocio = data.dataset.socio_quadro_societario.length;
							if(existeSocio == 0){
								var widget = templateManager.container.getActiveWidget();
								General.saveCrud(widget);
								widget.reload();
							}else{
								ScreenService.showMessage("Sócio já cadastrado para a empresa informada", "warning");
								return;
							}
						}.bind(this));
					}else if(self.verificaQualificacaoPais(widget) == true){
						General.widgetSave(widget);
					}
				}
			}
		}
	};
	
	self.verificaQualificacaoPais = function(widget){
			if(widget.currentRow.CDPAISREG == 105){
				if(widget.currentRow.IDTIPOREG == 'PF'){
					if((widget.currentRow.IDQUALIY600 != '01') && (widget.currentRow.IDQUALIY600 != '02') && (widget.currentRow.IDQUALIY600 != '09') ){
						ScreenService.showMessage("Quando o Sócio reside no Brasil e é classificado como pessoa física, é possível que ele tenha apenas as seguintes classificações: <br/><br/>01 - Acionista Pessoa Física Domiciliado no Brasil <br/>02 - Sócio Pessoa Física Domiciliado no Brasil <br/>09 - Titular.", "warning");
						return false;
					}
				}
				if((widget.currentRow.IDTIPOREG == 'PJ')){
					if((widget.currentRow.IDQUALIY600 != '03') && (widget.currentRow.IDQUALIY600 != '04')){
						ScreenService.showMessage("Quando o Sócio reside no Brasil e é classificado como pessoa jurídica, é possível que ele tenha apenas as seguintes classificações: <br/><br/>03 - Acionista Pessoa Jurídica Domiciliado no Brasil <br/>04 - Sócio Pessoa Jurídica Domiciliado no Brasil.", "warning");
						return false;
					}
				}
			}
			
			if(widget.currentRow.CDPAISREG != 105){
				if(widget.currentRow.IDTIPOREG == 'PF'){
					if((widget.currentRow.IDQUALIY600 != '05') && (widget.currentRow.IDQUALIY600 != '06') && (widget.currentRow.IDQUALIY600 != '09') ){
						ScreenService.showMessage("Quando o Sócio reside fora do Brasil e é classificado como pessoa física, é possível que ele tenha apenas as seguintes qualificações: <br/><br/>05 - Acionista Pessoa Física Residente ou Domiciliado no Exterior <br/>06 - Sócio Pessoa Física Residente ou Domiciliado no Exterior.", "warning");
						return false;
					}
				}
				if((widget.currentRow.IDTIPOREG == 'PJ')){
					if((widget.currentRow.IDQUALIY600 != '07') && (widget.currentRow.IDQUALIY600 != '08')){
						ScreenService.showMessage("Quando o Sócio reside fora do Brasil e é classificado como pessoa jurídica, é possível que ele tenha apenas as seguintes qualificações: <br/><br/>07 - Acionista Pessoa Jurídica Residente ou Domiciliado no Exterior <br/>08 - Sócio Pessoa Jurídica Residente ou Domiciliado no Exterior.", "warning");
						return false;
					}
				}
			}
			return true;
	};
	
	self.verificaQualificacao = function(widget){
			if(widget.currentRow.NMPAIS == 'BRASIL'){
				if(widget.currentRow.IDTIPOREG == 'PF'){
					if((widget.currentRow.IDQUALIY600 != '01') && (widget.currentRow.IDQUALIY600 != '02') && (widget.currentRow.IDQUALIY600 != '09') ){
						ScreenService.showMessage("Quando o Sócio reside no Brasil e é classificado como pessoa física, é possível que ele tenha apenas as seguintes classificações: <br/><br/>01 - Acionista Pessoa Física Domiciliado no Brasil <br/>02 - Sócio Pessoa Física Domiciliado no Brasil <br/>09 - Titular.", "warning");
						return false;
					}
				}
				if((widget.currentRow.IDTIPOREG == 'PJ')){
					if((widget.currentRow.IDQUALIY600 != '03') && (widget.currentRow.IDQUALIY600 != '04')){
						ScreenService.showMessage("Quando o Sócio reside no Brasil e é classificado como pessoa jurídica, é possível que ele tenha apenas as seguintes classificações: <br/><br/>03 - Acionista Pessoa Jurídica Domiciliado no Brasil <br/>04 - Sócio Pessoa Jurídica Domiciliado no Brasil.", "warning");
						return false;
					}
				}
			}
			
			if(widget.currentRow.NMPAIS != 'BRASIL'){
				if(widget.currentRow.IDTIPOREG == 'PF'){
					if((widget.currentRow.IDQUALIY600 != '05') && (widget.currentRow.IDQUALIY600 != '06') && (widget.currentRow.IDQUALIY600 != '09') ){
						ScreenService.showMessage("Quando o Sócio reside fora do Brasil e é classificado como pessoa física, é possível que ele tenha apenas as seguintes qualificações: <br/><br/>05 - Acionista Pessoa Física Residente ou Domiciliado no Exterior <br/>06 - Sócio Pessoa Física Residente ou Domiciliado no Exterior.", "warning");
						return false;
					}
				}
				if((widget.currentRow.IDTIPOREG == 'PJ')){
					if((widget.currentRow.IDQUALIY600 != '07') && (widget.currentRow.IDQUALIY600 != '08')){
						ScreenService.showMessage("Quando o Sócio reside fora do Brasil e é classificado como pessoa jurídica, é possível que ele tenha apenas as seguintes qualificações: <br/><br/>07 - Acionista Pessoa Jurídica Residente ou Domiciliado no Exterior <br/>08 - Sócio Pessoa Jurídica Residente ou Domiciliado no Exterior.", "warning");
						return false;
					}
				}
			}
			return true;
	};
	
	self.verificaPorcentagem = function(widget){
		if((widget.currentRow.VRPERCAPTOT != '') && (widget.currentRow.VRPERCAPTOT != null)){
			if(typeof widget.getField('VRPERCAPTOT').value() != 'string'){
				widget.currentRow.VRPERCAPTOT = widget.currentRow.VRPERCAPTOT + '';
				if(widget.currentRow.VRPERCAPTOT.indexOf(".") != -1){
					widget.currentRow.VRPERCAPTOT = widget.currentRow.VRPERCAPTOT.replace(".", ",");
				}
			}
			var parteInteira = widget.currentRow.VRPERCAPTOT.slice(0 , widget.currentRow.VRPERCAPTOT.length -3);
			var parteDecimal = widget.currentRow.VRPERCAPTOT.slice(widget.currentRow.VRPERCAPTOT.length -2, widget.currentRow.VRPERCAPTOT.length); 
			if(parteInteira.indexOf(".") != -1){
				parteInteira = parteInteira.replace('.', '');
			}
			
			parteInteira = parseFloat(parteInteira);
			parteDecimal = parseFloat(parteDecimal);
			
			if(!((parteInteira >= 0) && (parteInteira <= 100)) ){
				ScreenService.showMessage("O valor da porcentagem sobre capital total deve estar entre 0 e 100.", "warning");
				return false;
			}
			if((parteInteira == 100) && (parteDecimal > 0)){
				ScreenService.showMessage("O valor da porcentagem sobre capital total deve estar entre 0 e 100.", "warning");
				return false;
			}
			widget.currentRow.VRPERCAPTOT = parteInteira + '.' + parteDecimal;
			widget.currentRow.VRPERCAPTOT = parseFloat(widget.currentRow.VRPERCAPTOT);
		}
		if((widget.currentRow.VRPERCAPVOT != '') && (widget.currentRow.VRPERCAPVOT != null)){
			if(typeof widget.getField('VRPERCAPVOT').value() != 'string'){
				widget.currentRow.VRPERCAPVOT = widget.currentRow.VRPERCAPVOT + '';
				if(widget.currentRow.VRPERCAPVOT.indexOf(".") != -1){
					widget.currentRow.VRPERCAPVOT = widget.currentRow.VRPERCAPVOT.replace(".", ",");
				}
			}
			var parteInteira2 = widget.currentRow.VRPERCAPVOT.slice(0 , widget.currentRow.VRPERCAPVOT.length -3);
			var parteDecimal2 = widget.currentRow.VRPERCAPVOT.slice(widget.currentRow.VRPERCAPVOT.length -2, widget.currentRow.VRPERCAPVOT.length); 
			if(parteInteira2.indexOf(".") != -1){
				parteInteira2 = parteInteira2.replace('.', '');
			}
			
			parteInteira2 = parseFloat(parteInteira2);
			parteDecimal2 = parseFloat(parteDecimal2);
			
			if(!((parteInteira2 >= 0) && (parteInteira2 <= 100)) ){
				ScreenService.showMessage("O valor da porcentagem sobre capital volante deve estar entre 0 e 100.", "warning");
				return false;
			}
			
			if((parteInteira2 == 100) && (parteDecimal2 > 0)){
				ScreenService.showMessage("O valor da porcentagem sobre capital volante deve estar entre 0 e 100.", "warning");
				return false;
			}
			widget.currentRow.VRPERCAPVOT = parteInteira2 + '.' + parteDecimal2;
			widget.currentRow.VRPERCAPVOT = parseFloat(widget.currentRow.VRPERCAPVOT);
		}
		return true;
	};
	
	self.verificaData = function(widget){
		if((moment(widget.currentRow.DTFIMSOC, 'DD/MM/YYYY')) > (moment(widget.currentRow.DTALTSOC, 'DD/MM/YYYY'))){
			ScreenService.showMessage("Data final de participação do quadro societário deve ser menor que a data de alteração do quadro societário.", "warning");
			return false;
		}
		return true;
	};
	
}

Configuration(function (ContextRegister) {
	ContextRegister.register('Ger17600_RegistroY600SociosPorEmpresa_Controller', Ger17600_RegistroY600SociosPorEmpresa_Controller);
});

// FILE: ./assets/js/controllers/Ger17700_Rendimentos_Socios_Controller.js
var Ger17700_Rendimentos_Socios_Controller = function(ScreenService, templateManager, General) {
    var self = this;

    this.habilitaCamposBrasil = function(widget) {
        var boVisible = widget.currentRow.CDPAISREG === 105;
        if (boVisible) {
            widget.fieldGroups[1].isVisible = boVisible;
            //Torna o campo obrigatÃ³rio
            widget.getField('CDREG').validations = {
                'required': true
            };
        } 
        widget.getField('CDREG').readOnly = !boVisible;
        if (widget.getField('CDREG').readOnly) {
            widget.currentRow.CDREG = "";
            // Campo deixa de ser obrigatÃ³rio
            delete widget.getField('CDREG').validations;

        }
    };

    this.tipoMascaraPessoa = function(widget) {
        var field = General.inscricaoFormat(widget.currentRow.CDREG);
        var msg = 'CNPJ / CPF inválido!';
        if (field.tipo.cod === 'F') {
            widget.currentRow.IDTIPOREG = 'PF';
            if (field.valid === false && !widget.getField('CDREG')) {
                ScreenService.showMessage(msg);
            } else {
                widget.currentRow.CDREG = field.value;
            }
        } else if (field.tipo.cod === 'J') {
            widget.currentRow.IDTIPOREG = 'PJ';
            if (field.valid === false && !widget.getField('CDREG')) {
                ScreenService.showMessage(msg);
            } else {
                widget.currentRow.CDREG = field.value;
            }
        }


    };

    this.formataCNPJCPF = function(widget) {
        var rows = widget.dataSource.data;
        rows.forEach(function(row) {
            var insc = General.inscricaoFormat(row.CDREG);
            row.CDREG = insc.value;
        });
    };

    this.tipoMascaraRepres = function(widget) {
        var field = General.inscricaoFormat(widget.currentRow.NRCPFREPREG);
        var msg = 'CPF do representante legal inválido!';
        if (field.tipo.cod === 'F') {
            if (field.valid === false) {
                ScreenService.showMessage(msg);
            } else {
                widget.currentRow.NRCPFREPREG = field.value;
            }
        } else {
            ScreenService.showMessage(msg);
        }
    };

    this.alteraCodigo = function(widget) {
        var codigo = widget.currentRow.CDREG;
        codigo = codigo.replace(".", "");
        codigo = codigo.replace(".", "");
        if (widget.currentRow.IDTIPOREG === 'PJ') {
            codigo = codigo.replace("/", "");
        } else {
            codigo = codigo.replace(".", "");
        }
        codigo = codigo.replace("-", "");
        widget.currentRow.CDREG = codigo;

        if (widget.currentRow.NRCPFREPREG) {
            codigo = widget.currentRow.NRCPFREPREG;
            codigo = codigo.replace(".", "");
            codigo = codigo.replace(".", "");
            codigo = codigo.replace(".", "");
            codigo = codigo.replace("-", "");
            widget.currentRow.NRCPFREPREG = codigo;
        }

        if (!widget.currentRow.QUALIREPREG) {
            widget.currentRow.QUALIREPREG = '00';
        }
        
    };

    this.iniciaInsercaoSocio = function(widget) {
        widget.currentRow.IDTIPOREG = 'PF';
        //widget.currentRow.__is_new = true;
       // General.changeWidgetAcessibility(widget.widgets, false);
        
        //deixa o campo CPF / CNPJ readOnly
        widget.getField('CDREG').readOnly = true;
        widget.currentRow.CDREG = "";
        // Campo deixa de ser obrigatÃ³rio
        delete widget.getField('CDREG').validations;
        
    };

    this.salvarSocio = function(widget) {
        //Verifica se CPF/CNPJ inserido Ã© válido
        if ((widget.currentRow.IDTIPOREG === 'PF' && General.validateCPF(widget.currentRow.CDREG) && !widget.getField('CDREG').readOnly) ||
            (widget.currentRow.IDTIPOREG === 'PJ' && General.validateCNPJ(widget.currentRow.CDREG) && !widget.getField('CDREG').readOnly) ||
            (widget.getField('CDREG').readOnly && widget.currentRow.CDREG === "")) {
                //Verifica se nome e país são NULL
                if (widget.currentRow.NMREG == "" || widget.currentRow.NMPAIS == "") {
                    ScreenService.showMessage('Campos obrigatórios vazios!');
                    widget.isValid();
                } else {
                    // Chama a rota para efetuar a rotina de recálculo.
                    General.callRestEngine("cadCtb#/salvarSocio", "Row", widget.currentRow)
                        .then(function() {
                            self.formataCNPJCPF(widget);
                            //widget.list();
                            ScreenService.closeSwipe();
                            widget.reload();
                            ScreenService.showMessage("Registro salvo com sucesso.");
                            
                        })
                        .catch(function(error) {
                            // Mensagem padrão em caso de timeout.
                            var errorMessage = 'Timeout';

                            // Verifica se houve alguma resposta da requisição.
                            if (error.data) {
                                //Verifica se nome e país são NULL
                                if (widget.currentRow.NMREG == "" || widget.currentRow.NMPAIS == "")
                                    ScreenService.showMessage('Campos obrigatórios vazios!');

                                // Caso haja alguma resposta, atribui a mensagem de erro.
                                errorMessage = error.data.error;
                            }

                            // Imprime a mensagem.
                            ScreenService.showMessage(errorMessage);
                        });
                }
        } else {
            ScreenService.showMessage('CPF/CNPJ inválido.');
        }
        widget.reload();

    };

    this.alterarSocio = function(widget) {
        General.changeWidgetAcessibility(widget.widgets, false);
        General.edit(widget);
        this.habilitaCamposBrasil(widget);
    };

    this.cancelActionSocio = function(args) {
        
        General.backOrCancel(args);
    };

    this.iniciaInsercaoEmpresa = function(widget) {
        widget.currentRow.NRSEQREG = widget.getParent().currentRow.NRSEQREG;
        /* CÃ³digo 09 (Titular) foi escolhido devido ser o Ãºnico que indifere se a pessoa reside ou nÃ£o no Brasil) */
        widget.currentRow.IDQUALIY600 = '09';
    };

    this.salvarQuadroSocietario = function(widget) {
        if(this.verificaRelacaoComEmpresa(widget)){
            if (widget.isValid()) {
                if( typeof widget.currentRow.VRPERCAPTOT == "string" )
                    widget.currentRow.VRPERCAPTOT = parseFloat( widget.currentRow.VRPERCAPTOT.replace(",", ".") );
                if( typeof widget.currentRow.VRPERCAPVOT == "string" )
                    widget.currentRow.VRPERCAPVOT = parseFloat( widget.currentRow.VRPERCAPVOT.replace(",", ".") );
                General.callRestEngine("cadCtb#/salvarQuadroSocietario", "Row", widget.currentRow)
                    .then(function() {
                        widget.view();
                        templateManager.updateTemplate();
                    })
                    .catch(function(error) {
                        // Mensagem padrÃ£o em caso de timeout.
                        var errorMessage = 'Timeout';
    
                        // Verifica se houve alguma resposta da requisiÃ§Ã£o.
                        if (error.data) {
                            // Caso haja alguma resposta, atribui a mensagem de erro.
                            errorMessage = error.data.error;
                        }
    
                        // Imprime a mensagem.
                        ScreenService.showMessage(errorMessage);
                    });
                templateManager.updateTemplate();
                widget.getParent().reload();
            } else {
                ScreenService.showMessage("Preencha todos os campos corretamente");
            }
        }
    };

    this.habilitaCamposEWidgets = function(widget) {
        self.formataCNPJCPF(widget);
        
    };

    this.salvarRendimento = function(widget) {
        // var widgetRendimentos = templateManager.container.getWidget('widgetRendimentos');
        if (widget.isValid() && self.verificaAno(widget)) {
            var dtreferencia = widget.currentRow.DTREFERENCIA;
            //Formata a data para inserÃ§Ã£o no banco de dados
            //if (typeof widget.currentRow.DTREFERENCIA === "number"){
                widget.currentRow.DTREFERENCIA = '31/12/' + widget.currentRow.DTREFERENCIA;
            /*}else{
                widget.currentRow.DTREFERENCIA = '31/12/' + widget.currentRow.DTREFERENCIA.substr(widget.currentRow.DTREFERENCIA.length - 4); //Código entigo
            }*/
            //Formata todos os valores monetÃ¡rios para floats vÃ¡lidos
            if (typeof widget.currentRow.VRREMTRAB === 'string')
                widget.currentRow.VRREMTRAB = parseFloat(widget.currentRow.VRREMTRAB.replace(/\./g, "").replace(",", "."));
            if (typeof widget.currentRow.VRLUCRODIV === 'string')
                widget.currentRow.VRLUCRODIV = parseFloat(widget.currentRow.VRLUCRODIV.replace(/\./g, "").replace(",", "."));
            if (typeof widget.currentRow.VRJURCAPPROP === 'string')
                widget.currentRow.VRJURCAPPROP = parseFloat(widget.currentRow.VRJURCAPPROP.replace(/\./g, "").replace(",", "."));
            if (typeof widget.currentRow.VRDEMAISREND === 'string')
                widget.currentRow.VRDEMAISREND = parseFloat(widget.currentRow.VRDEMAISREND.replace(/\./g, "").replace(",", "."));
            if (typeof widget.currentRow.VRIRRETIDO === 'string')
                widget.currentRow.VRIRRETIDO = parseFloat(widget.currentRow.VRIRRETIDO.replace(/\./g, "").replace(",", "."));

            widget.currentRow.NRSEQREG = widget.getParent().currentRow.NRSEQREG;

            //Flag para permitir a ediÃ§Ã£o de um rendimento sem alterar o ano no backend
            widget.currentRow.anoUnchanged = !widget.currentRow.__is_new && (widget.currentRow.DTREFERENCIA.substr(widget.currentRow.DTREFERENCIA.length - 4) == widget.backupRow.DTREFERENCIA);

            General.callRestEngine("cadCtb#/socio_rendimento/save", "Row", widget.currentRow)
                .then(function() {
                    ScreenService.closeSwipe();
                    widget.list();
                    widget.reload();
                })
                .catch(function(error) {
                    widget.currentRow.DTREFERENCIA = dtreferencia;
                    // Mensagem padrÃ£o em caso de timeout.
                    var errorMessage = 'Timeout';
                    // Verifica se houve alguma resposta da requisiÃ§Ã£o.
                    if (error.data) {
                        // Caso haja alguma resposta, atribui a mensagem de erro.
                        errorMessage = error.data.error;
                    }
                    // Imprime a mensagem.
                    ScreenService.showMessage(errorMessage);
                });
        } else {
            ScreenService.showMessage("Preencha todos os campos corretamente");
            
        }
    };
    
    this.salvaEmpresaPorSocio = function(widget){
	    var widgetEmpresa = templateManager.container.getWidget('titulos_por_empresa');
	    var widgetSocio = templateManager.container.getWidget('widgetSocio');
	    widgetEmpresa.currentRow.NRSEQREG = widgetSocio.currentRow.NRSEQREG;
		if(widget.isValid()){
			if((self.verificaData(widget) == true) && (self.verificaPorcentagem(widget) == true)){
				if(self.verificaQualificacao(widget) == true){
					if((widget.currentRow.__is_new == true)){
			            var filter = [
			            		{
				            		"name" : "CDEMPRESA",
				                    "operator" : "=",
				                    "value" : widget.currentRow.CDEMPRESA
				            	},
				            	{
				            		"name" : "NRSEQREG",
				                    "operator" : "=",
				                    "value" : widget.currentRow.NRSEQREG
				            	},
				            	{
				            		"name" : "NRORG",
				                    "operator" : "=",
				                    "value" : getLocalVar('NRORG')
				            	}
			            ];
						General.callRestEngine("cadCtb#/crud/empresa_por_socio", "FilterData", filter).then(function(data) {
							var existeEmpresa = data.dataset.empresa_por_socio.length;
							if(existeEmpresa == 0){
								// var widget = templateManager.container.getActiveWidget();
								General.saveCrud(widget);
								widget.reload();
							}else{
								ScreenService.showMessage("Empresa já cadastrada para o sócio informado", "warning");
								return;
							}
						}.bind(this));
					}else if(self.verificaQualificacaoPais(widget) == true){
						General.widgetSave(widget);
					}
				}
			}
		}
	};

    self.verificaData = function(widget){
		if((moment(widget.currentRow.DTFIMSOC, 'DD/MM/YYYY')) > (moment(widget.currentRow.DTALTSOC, 'DD/MM/YYYY'))){
			ScreenService.showMessage("Data final de participação do quadro societário deve ser menor que a data de alteração do quadro societário.", "warning");
			return false;
		}
		return true;
	};
	
	self.verificaPorcentagem = function(widget){
	    var vrpercaptot = widget.currentRow.VRPERCAPTOT;
	    var vrpercapvot = widget.currentRow.VRPERCAPVOT;
	    
	    if((vrpercaptot != '') && (vrpercaptot != null)){
	        if(typeof vrpercaptot == 'string'){
	            if(vrpercaptot.length > 6){
	                ScreenService.showMessage("O valor da porcentagem sobre capital total deve estar entre 0 e 100.", "warning");
                    widget.currentRow.VRPERCAPTOT = "";
                    return false;
	            }
	            if(vrpercaptot.indexOf(",") != -1){
	                vrpercaptot = vrpercaptot.replace(",", ".");
	            }
	            vrpercaptot = parseFloat(vrpercaptot);
	            widget.currentRow.VRPERCAPTOT = vrpercaptot;
	        }
            if(!(vrpercaptot >= 0 && vrpercaptot <= 100)){
                ScreenService.showMessage("O valor da porcentagem sobre capital total deve estar entre 0 e 100.", "warning");
                widget.currentRow.VRPERCAPTOT = "";
                return false;
            }
	    }
	    if((vrpercapvot != '') && (vrpercapvot != null)){
	        if(typeof vrpercapvot == 'string'){
	            if(vrpercapvot.length > 6){
	                ScreenService.showMessage("O valor da porcentagem sobre votante total deve estar entre 0 e 100.", "warning");
                    widget.currentRow.VRPERCAPVOT = "";
                    return false;
	            }
	            if(vrpercapvot.indexOf(",") != -1){
	                vrpercapvot = vrpercapvot.replace(",", ".");
	            }
	            vrpercapvot = parseFloat(vrpercapvot);
	            widget.currentRow.VRPERCAPVOT = vrpercapvot;
	        }
            if(!(vrpercapvot >= 0 && vrpercapvot <= 100)){
                ScreenService.showMessage("O valor da porcentagem sobre capital votante deve estar entre 0 e 100.", "warning");
                widget.currentRow.VRPERCAPVOT = "";
                return false;
            }
            return true;
	    }
	    
	    return this.verificaPorcentagem(widget);
	};
	
    this.verificaAno = function(widget) {
        if (widget.currentRow.DTREFERENCIA && widget.currentRow.DTREFERENCIA != "") {
            var tamanhoMax = 4;
            var tamanho = widget.currentRow.DTREFERENCIA.toString().length;
            if (tamanho > tamanhoMax) {
                widget.currentRow.DTREFERENCIA = "";
                return false;
            }else
                return true;
        }
    };
    
    self.verificaQualificacao = function(){
	    var widgetSocio = templateManager.container.getWidget('widgetSocio');
        var widgetEmpresa = templateManager.container.getWidget('titulos_por_empresa');
		if(widgetSocio.currentRow.NMPAIS == 'BRASIL'){
			if(widgetSocio.currentRow.IDTIPOREG == 'PF'){
				if((widgetEmpresa.currentRow.IDQUALIY600 != '01') && (widgetEmpresa.currentRow.IDQUALIY600 != '02') && (widgetEmpresa.currentRow.IDQUALIY600 != '09') ){
					ScreenService.showMessage("Quando o Sócio reside no Brasil e é classificado como pessoa física, é possível que ele tenha apenas as seguintes classificações: <br/><br/>01 - Acionista Pessoa Física Domiciliado no Brasil <br/>02 - Sócio Pessoa Física Domiciliado no Brasil <br/>09 - Titular.", "warning");
					return false;
				}
			}
			if((widgetSocio.currentRow.IDTIPOREG == 'PJ')){
				if((widgetEmpresa.currentRow.IDQUALIY600 != '03') && (widgetEmpresa.currentRow.IDQUALIY600 != '04')){
					ScreenService.showMessage("Quando o Sócio reside no Brasil e é classificado como pessoa jurídica, é possível que ele tenha apenas as seguintes classificações: <br/><br/>03 - Acionista Pessoa Jurídica Domiciliado no Brasil <br/>04 - Sócio Pessoa Jurídica Domiciliado no Brasil.", "warning");
					return false;
				}
			}
		}
		
		if(widgetSocio.currentRow.NMPAIS != 'BRASIL'){
			if(widgetSocio.currentRow.IDTIPOREG == 'PF'){
				if((widgetEmpresa.currentRow.IDQUALIY600 != '05') && (widgetEmpresa.currentRow.IDQUALIY600 != '06') && (widgetEmpresa.currentRow.IDQUALIY600 != '09') ){
					ScreenService.showMessage("Quando o Sócio reside fora do Brasil e é classificado como pessoa física, é possível que ele tenha apenas as seguintes qualificações: <br/><br/>05 - Acionista Pessoa Física Residente ou Domiciliado no Exterior <br/>06 - Sócio Pessoa Física Residente ou Domiciliado no Exterior.", "warning");
					return false;
				}
			}
			if((widgetSocio.currentRow.IDTIPOREG == 'PJ')){
				if((widgetEmpresa.currentRow.IDQUALIY600 != '07') && (widgetEmpresa.currentRow.IDQUALIY600 != '08')){
					ScreenService.showMessage("Quando o Sócio reside fora do Brasil e é classificado como pessoa jurídica, é possível que ele tenha apenas as seguintes qualificações: <br/><br/>07 - Acionista Pessoa Jurídica Residente ou Domiciliado no Exterior <br/>08 - Sócio Pessoa Jurídica Residente ou Domiciliado no Exterior.", "warning");
					return false;
				}
			}
		}
		return true;
	};
    
    self.verificaQualificacaoPais = function(){
        var widgetSocio = templateManager.container.getWidget('widgetSocio');
        var widgetEmpresa = templateManager.container.getWidget('titulos_por_empresa');
		if(widgetSocio.currentRow.CDPAISREG == 105){
			if(widgetSocio.currentRow.IDTIPOREG == 'PF'){
				if((widgetEmpresa.currentRow.IDQUALIY600 != '01') && (widgetEmpresa.currentRow.IDQUALIY600 != '02') && (widgetEmpresa.currentRow.IDQUALIY600 != '09') ){
					ScreenService.showMessage("Quando o Sócio reside no Brasil e é classificado como pessoa física, é possível que ele tenha apenas as seguintes classificações: <br/><br/>01 - Acionista Pessoa Física Domiciliado no Brasil <br/>02 - Sócio Pessoa Física Domiciliado no Brasil <br/>09 - Titular.", "warning");
					return false;
				}
			}
			if((widgetSocio.currentRow.IDTIPOREG == 'PJ')){
				if((widgetEmpresa.currentRow.IDQUALIY600 != '03') && (widgetEmpresa.currentRow.IDQUALIY600 != '04')){
					ScreenService.showMessage("Quando o Sócio reside no Brasil e é classificado como pessoa jurídica, é possível que ele tenha apenas as seguintes classificações: <br/><br/>03 - Acionista Pessoa Jurídica Domiciliado no Brasil <br/>04 - Sócio Pessoa Jurídica Domiciliado no Brasil.", "warning");
					return false;
				}
			}
		}
		
		if(widgetSocio.currentRow.CDPAISREG != 105){
			if(widgetSocio.currentRow.IDTIPOREG == 'PF'){
				if((widgetEmpresa.currentRow.IDQUALIY600 != '05') && (widgetEmpresa.currentRow.IDQUALIY600 != '06') && (widgetEmpresa.currentRow.IDQUALIY600 != '09') ){
					ScreenService.showMessage("Quando o Sócio reside fora do Brasil e é classificado como pessoa física, é possível que ele tenha apenas as seguintes qualificações: <br/><br/>05 - Acionista Pessoa Física Residente ou Domiciliado no Exterior <br/>06 - Sócio Pessoa Física Residente ou Domiciliado no Exterior.", "warning");
					return false;
				}
			}
			if((widgetSocio.currentRow.IDTIPOREG == 'PJ')){
				if((widgetEmpresa.currentRow.IDQUALIY600 != '07') && (widgetEmpresa.currentRow.IDQUALIY600 != '08')){
					ScreenService.showMessage("Quando o Sócio reside fora do Brasil e é classificado como pessoa jurídica, é possível que ele tenha apenas as seguintes qualificações: <br/><br/>07 - Acionista Pessoa Jurídica Residente ou Domiciliado no Exterior <br/>08 - Sócio Pessoa Jurídica Residente ou Domiciliado no Exterior.", "warning");
					return false;
				}
			}
		}
		return true;
	};
    
    this.verificaRelacaoComEmpresa = function(widget){
		if(widget.getParent().getField('NMPAIS').value() == 'BRASIL'){
			if(widget.getParent().getField('IDTIPOREG').value() == 'PF'){
				if((widget.getField('IDQUALIY600').value() != '01') && (widget.getField('IDQUALIY600').value() != '02') && (widget.getField('IDQUALIY600').value() != '09') ){
					ScreenService.showMessage("Quando o Sócio reside no Brasil e é classificado como pessoa física, é possível que ele tenha apenas as seguintes classificações: <br/><br/>01 - Acionista Pessoa Física Domiciliado no Brasil <br/>02 - Sócio Pessoa Física Domiciliado no Brasil <br/>09 - Titular.", "warning");
					return false;
				}
			}else if((widget.getParent().getField('IDTIPOREG').value() == 'PJ')){
				if((widget.currentRow.IDQUALIY600 != '03') && (widget.currentRow.IDQUALIY600 != '04')){
					ScreenService.showMessage("Quando o Sócio reside no Brasil e é classificado como pessoa jurídica, é possível que ele tenha apenas as seguintes classificações: <br/><br/>03 - Acionista Pessoa Jurídica Domiciliado no Brasil <br/>04 - Sócio Pessoa Jurídica Domiciliado no Brasil.", "warning");
					return false;
				}
			}
		}else if(widget.getParent().getField('NMPAIS').value() != 'BRASIL'){
			if(widget.getParent().getField('IDTIPOREG').value() == 'PF'){
				if((widget.getField('IDQUALIY600').value() != '05') && (widget.getField('IDQUALIY600').value() != '06') && (widget.getField('IDQUALIY600').value() != '09') ){
					ScreenService.showMessage("Quando o Sócio reside fora do Brasil e é classificado como pessoa física, é possível que ele tenha apenas as seguintes qualificações: <br/><br/>05 - Acionista Pessoa Física Residente ou Domiciliado no Exterior <br/>06 - Sócio Pessoa Física Residente ou Domiciliado no Exterior.", "warning");
					return false;
				}
			}else if((widget.getParent().getField('IDTIPOREG').value() == 'PJ')){
				if((widget.getField('IDQUALIY600').value() != '07') && (widget.getField('IDQUALIY600').value() != '08')){
					ScreenService.showMessage("Quando o Sócio reside fora do Brasil e é classificado como pessoa jurídica, é possível que ele tenha apenas as seguintes qualificações: <br/><br/>07 - Acionista Pessoa Jurídica Residente ou Domiciliado no Exterior <br/>08 - Sócio Pessoa Jurídica Residente ou Domiciliado no Exterior.", "warning");
					return false;
				}
			}
		}
		return true;
	};

        this.habilitarQuadro = function(widget){
            
        if(widget.getParent().currentRow.IDSOCIOREG == 'N'){
              widget.actions[0].isVisible =false;
              widget.actions[1].isVisible =false;
              widget.actions[2].isVisible =false;
              
        }else {
             widget.actions[0].isVisible =true;
             widget.actions[1].isVisible =true;
             widget.actions[2].isVisible =true;
        }
        widget.reload();
        };
             
        
        this.ativaRepLeg = function (widget) {  
            
              if(widget.currentRow.IDSOCIOREG == 'N'){
                widget.fieldGroups[1].isVisible = false;
              }else {
                widget.fieldGroups[1].isVisible = true;
              }
                        
        };
 
};


Configuration(function(ContextRegister) {
    ContextRegister.register('Ger17700_Rendimentos_Socios_Controller', Ger17700_Rendimentos_Socios_Controller);
});

// FILE: ./assets/js/controllers/Ger17800_Receita_Vendas_Cnae_Controller.js
var Ger17800_Receita_Vendas_Cnae_Controller = function(ScreenService, General) {


    var self = this;

    /*self.preparaFiltro = function(widget, args) {
        widget.dataSourceFilter = [];     
        args.e.preventDefault();
        var currentRow = args.e.preference.FILTER_ROW;
        if (currentRow.NMEMPRESA == ""){
            currentRow.CDEMPRESA = "";
        }
        widget.dataSourceFilter.push({name: "P_CDEMPRESA", operator: "=", value: currentRow.CDEMPRESA});
                
        widget.reload().then(function() {
            widget.activate();
        });
        ScreenService.closePopup();
            

    };*/


    self.saveCnaeRegy = function(widget) {
            var route = 'cadCtb#/crud/regy540ecf';
            var filter = [
                {
                    "name": "CDEMPRESA",
                    "operator": "=",
                    "value": widget.appliedFilter.FILTER_ROW.CDEMPRESA
                },
                {
                    "name": "CDCNAE",
                    "operator": "=",
                    "value": widget.currentRow.CDCNAE
                }
            ];
    
            General.callRestEngine(route, 'FilterData', filter).then(function(result) {
                result = result.dataset.regy540ecf;
    
                if ((result.length == 0) || (!widget.currentRow.__is_new)) {
                    General.changeWidgetAcessibility(widget.widgets, true);
                    self.saveRegy(widget);
                } else ScreenService.showMessage('Operação bloqueada. Registro já existente.');
            });
    };
    
    self.saveCnaeConty = function(widget) {
        var route = 'cadCtb#/crud/conty540ecf';
        var filter = [
        {
            "name": "NRSEQREGY540",
            "operator": "=",
            "value": widget.getParent().currentRow.NRSEQREGY540
        },
        {
            "name": "CDCONTCTBL",
            "operator": "=",
            "value": widget.currentRow.CDCONTCTBL
        }];

        General.callRestEngine(route, 'FilterData', filter).then(function(result) {
            result = result.dataset.conty540ecf;

            if ((result.length == 0) || (!widget.currentRow.__is_new)) {
                General.changeWidgetAcessibility(widget.widgets, true);
                self.saveConty(widget);
            } else ScreenService.showMessage('Operação bloqueada. Registro já existente.');
        });
    };

    self.preparaFiltro = function(widget, preference) {

        widget.dataSourceFilter.forEach(function(filtro) {
            switch (filtro.name) {
                case 'P_CDEMPRESA':
                    filtro.value = preference.FILTER_ROW.CDEMPRESA;
                    break;
            }
        });

    };

    self.saveRegy = function(widget) {
        widget.currentRow.CDEMPRESA = widget.appliedFilter.FILTER_ROW.CDEMPRESA;
        General.saveCrud(widget);
    };

    self.saveConty = function(widget) {
        widget.currentRow.NRSEQREGY540 = widget.getParent().currentRow.NRSEQREGY540;
        General.saveCrud(widget);
    };

};

Configuration(function(ContextRegister) {
    ContextRegister.register('Ger17800_Receita_Vendas_Cnae_Controller', Ger17800_Receita_Vendas_Cnae_Controller);
});

// FILE: ./assets/js/controllers/Ger17900_Lucro_Presumido_Controller.js
var Ger17900_Lucro_Presumido_Controller = function(ScreenService, General, templateManager) {

  var L_INDEX = 3;
  var O_INDEX = 4;
  var CD_REGIME_DE_APURACAO_DAS_RECEITAS = 20;
  var ID_LANCAMENTOS_CONTABEIS = 'A';
  var ID_SALDO_DE_CONTA_CONTABIL = 'C';
  var ID_NAO_UTILIZADO = 'N';
  var ID_VALOR = 'V';

  var contctblMask = "";

  var self = this;

  this.setContctblMask = function() {
    General.callRestEngine("cadCtb#/crud/paramgeral", "FilterData", []).then(function(response) {
      var paramgeral = response.dataset.paramgeral[0];
      contctblMask = paramgeral.CDPICTCCTB;
    });

  };

  this.editRegy672Empr = function(widget) {

    self.onTipoChange(widget);

    if (widget.currentRow.CDREGY672 == CD_REGIME_DE_APURACAO_DAS_RECEITAS) {
      updateTiposDisponiveis(true, widget);
    } else {
      updateTiposDisponiveis(false, widget);
    }

    General.widgetEdit(widget);

  };

  this.saveRegy672Empr = function(widget) {

    var CDEMPRESA = widget.filterApplied.filter(isCDEMPRESA)[0].value;
    var DTREFERENCIA = widget.filterApplied.filter(isDTREFERENCIA)[0].value;

    widget.currentRow.CDEMPRESA = CDEMPRESA;
    widget.currentRow.DTREFERENCIA = DTREFERENCIA;

    if (widget.currentRow.NRSEQUENCIAL === null) {
      widget.currentRow.__is_new = true;
    } else {
      widget.currentRow.__is_new = false;
    }

    widget.saveRow().then(function(response) {
      if (response.dataset !== undefined)
        widget.currentRow.NRSEQUENCIAL = response.dataset.lucropresumido_regy672_empr.NRSEQUENCIAL;
      if (widget.currentRow.IDTIPO == ID_NAO_UTILIZADO)
        widget.currentRow.NRSEQUENCIAL = null;
      widget.reload();
      widget.view();
      self.loadGridContaCtbl(widget);
    });

  };


  this.onTipoChange = function(widget) {

    if (widget.currentRow.IDTIPO === ID_VALOR) {
        widget.getField('VRREGY672EMPR').readOnly = false;
        widget.getField('VRREGY672EMPR').reload();
    } else {
        widget.getField('VRREGY672EMPR').readOnly = true;
        widget.currentRow.VRREGY672EMPR = null;
        widget.getField('VRREGY672EMPR').reload();
    }


  };

  this.formatFields = function(widget) {

    widget.dataSourceFilter.forEach(function(filter) {
      if (filter.name == "DTREFERENCIA")
        filter.value = "31/12/"+filter.value;
      filter.name = "P_"+filter.name;
    });

  };

  this.loadGridContaCtbl = function(widget) {

    var widgetContas = templateManager.container.getWidget('grid_contas_contabeis');

    if (widget.currentRow.IDTIPO == ID_SALDO_DE_CONTA_CONTABIL || widget.currentRow.IDTIPO == ID_LANCAMENTOS_CONTABEIS) {
      General.changeWidgetAcessibility(widget.widgets, true);
      widgetContas.dataSourceFilter = [{
        name: "P_NRSEQUENCIAL",
        operator: "=",
        value: widget.currentRow.NRSEQUENCIAL,
        static: true
      }];

    } else {
      General.changeWidgetAcessibility(widget.widgets, false);
    }
    widgetContas.reload();
  };

  this.newContCtbl = function(widget) {
    var widgetRegy672Empr = widget.parent;
    widget.newRow();
    widget.currentRow.__is_new = true;
    widget.currentRow.NRSEQY672EMPR = widgetRegy672Empr.currentRow.NRSEQUENCIAL;

  };

  this.saveContctbl = function(widget) {
    General.widgetSave(widget).then(function(success) {
      var NRSEQUENCIAL = success.dataset.lucropresumido_contctbl[0].NRSEQUENCIAL;
      var NRORG = success.dataset.lucropresumido_contctbl[0].NRORG;
      widget.currentRow.NRSEQUENCIAL = NRSEQUENCIAL;
      widget.currentRow.NRORG = NRORG;
    });
  };

  this.cancelContctbl = function(widget) {
    General.widgetCancelForm(widget);
  };

  var updateTiposDisponiveis = function(bool, widget) {

    if (bool && widget.getField('IDTIPO').dataSource.data.length <= O_INDEX) {
      widget.getField('IDTIPO').dataSource.data.splice(L_INDEX, 0,
        {IDTIPO: 'L', DSTIPO: 'Livro Caixa'});
      widget.getField('IDTIPO').dataSource.data.splice(O_INDEX, 0,
        {IDTIPO: 'O', DSTIPO: 'Competência'});
    } else if (!bool && widget.getField('IDTIPO').dataSource.data.length > O_INDEX){
      widget.getField('IDTIPO').dataSource.data.splice(O_INDEX, 1);
      widget.getField('IDTIPO').dataSource.data.splice(L_INDEX, 1);

    }

    widget.reload();

  };

  this.getContctblMask = function() {
    return contctblMask;
  };

  function isCDEMPRESA(obj) {
    return obj.name == "P_CDEMPRESA";
  }

  function isDTREFERENCIA(obj) {
    return obj.name == "P_DTREFERENCIA";
  }




};

Configuration(function(ContextRegister) {
     ContextRegister.register('Ger17900_Lucro_Presumido_Controller', Ger17900_Lucro_Presumido_Controller);
});

// FILE: ./assets/js/controllers/Ger18100_RegistroP130ReceitasIncentivadas_Controller.js
function Ger18100_RegistroP130ReceitasIncentivadas_Controller(General, ScreenService, templateManager) {

  	var self = this;
  	
  	self.verificaDataSource = function(){
  		var widgetFilha = templateManager.container.getWidget('ger18100_registro_p130_receitas_incentivadas');
  		if(widgetFilha.getField('CDREGP130').dataSource.data.length == 0 ){
  			ScreenService.showMessage("Não existem Receitas Incentivadas importadas para o sistema. Favor acessar a tela de importação e realizar a importação da tabela P130 da ECF.");
  			return;
  		}
  		return; 
  	};
  	
  	self.editar = function(){
		var widgetFilha = templateManager.container.getWidget('ger18100_registro_p130_receitas_incentivadas');
		if(widgetFilha.getField('IDTIPOP130').value() == 'E' || widgetFilha.getField('IDTIPOP130').value() == 'CA'){
			widgetFilha.getField('DTRECINCEMPR').readOnly = false;
	    	widgetFilha.getField('VRRECINCEMPR').readOnly = false;
	    	widgetFilha.getField('DTRECINCEMPR').validations = {
	    		"required": {
                    "message": "Campo obrigatório"
                }
	    	};
	    	widgetFilha.getField('VRRECINCEMPR').validations = {
	    		"required": {
                    "message": "Campo obrigatório"
                }
	    	};
	    	General.edit(widgetFilha);
		}else{
			widgetFilha.getField('DTRECINCEMPR').validations = {};
	    	widgetFilha.getField('VRRECINCEMPR').validations = {};
		    widgetFilha.getField('DTRECINCEMPR').readOnly = true;
	    	widgetFilha.getField('VRRECINCEMPR').readOnly = true;
	    	General.edit(widgetFilha);
		}
		
		
	};

	self.adicionar = function(){
		var widgetFilha = templateManager.container.getWidget('ger18100_registro_p130_receitas_incentivadas');
		widgetFilha.getField('DTRECINCEMPR').validations = {};
    	widgetFilha.getField('VRRECINCEMPR').validations = {};
	    widgetFilha.getField('DTRECINCEMPR').readOnly = true;
    	widgetFilha.getField('VRRECINCEMPR').readOnly = true;
		widgetFilha.newRow();
	};
  	
	self.habilitaDataEValor = function() {
		var widgetFilha = templateManager.container.getWidget('ger18100_registro_p130_receitas_incentivadas');
		
	    if(widgetFilha.getField('IDTIPOP130').value() == 'E' || widgetFilha.getField('IDTIPOP130').value() == 'CA'){
	    	widgetFilha.getField('DTRECINCEMPR').readOnly = false;
	    	widgetFilha.getField('VRRECINCEMPR').readOnly = false;
	    	widgetFilha.getField('DTRECINCEMPR').validations = {
	    		"required": {
                    "message": "Campo obrigatório"
                }
	    	};
	    	widgetFilha.getField('VRRECINCEMPR').validations = {
	    		"required": {
                    "message": "Campo obrigatório"
                }
	    	};
	    }else {
	    	widgetFilha.getField('DTRECINCEMPR').validations = {};
	    	widgetFilha.getField('VRRECINCEMPR').validations = {};
		    widgetFilha.getField('DTRECINCEMPR').readOnly = true;
	    	widgetFilha.getField('VRRECINCEMPR').readOnly = true;
	    }
	};
	
	self.verificaData = function(widget) {
		if(widget.currentRow.DTRECINCEMPR == ''){
			ScreenService.showMessage("Preencha o campo de data. Campo obrigatório.");
			return false;
		}
		var aux = widget.getField('DTRECINCEMPR').value(); 
		if(aux.substring(6,10) != '2019'){
			ScreenService.showMessage("Data informada deve estar no ano de referência informado. ");
			return false;
		}
		return true;
	};
	
	self.setDataReferencia = function(widget){
		var ano = widget.getParent().currentRow.DTANO;
		widget.currentRow.DTREFERENCIA = '31/12/'+ ano;
	};
	
	self.salvar = function() {
		var widgetFilha = templateManager.container.getWidget('ger18100_registro_p130_receitas_incentivadas');
		var widgetPai = templateManager.container.getWidget('blocoP');
		
		self.setDataReferencia(widgetFilha);
		widgetFilha.currentRow.CDEMPRESA = widgetFilha.getParent().currentRow.CDEMPRESA;
		if(widgetFilha.isValid()){
			General.callRestEngine('cadCtb#/crud/recincempr_max', 'FilterData', []).then(function (result) {
				result = result.dataset.recincempr_max[0];
				
				if(widgetFilha.currentRow.__is_new == true){
					if(result){
						widgetFilha.currentRow.NRRECINCEMPR = result.NRRECINCEMPR;
					}else{
						widgetFilha.currentRow.NRRECINCEMPR = 1;
					}
				}
					
				if((widgetFilha.getField('IDTIPOP130').value() == 'E') || (widgetFilha.getField('IDTIPOP130').value() == 'CA')){
					if((self.verificaData(widgetFilha) == true) && (self.verificaValor(widgetFilha) == true)){
						var filter = [
							{
								"name": "DTRECINCEMPR",
								"operator": "IN",
								"value": widgetFilha.currentRow.DTRECINCEMPR
							},
							{
								"name": "P_CDEMPRESA",
								"operator": "=",
								"value": widgetPai.currentRow.CDEMPRESA
							},
							{
								"name": "P_ANO",
								"operator": "=",
								"value": widgetPai.currentRow.DTANO
							},
							{
								"name": "VRRECINCEMPR",
								"operator": "IN",
								"value": widgetFilha.currentRow.VRRECINCEMPR
							}
						];
						General.callRestEngine('cadCtb#/crud/regp130ecf_recincempr', 'FilterData', filter).then(function (result) {
					        result = result.dataset.regp130ecf_recincempr;
					        
					        if(result.length == 0){
					        	General.saveCrud(widgetFilha);
					        	ScreenService.showMessage('Registro salvo com sucesso.');
					        }else{
					        	ScreenService.showMessage('Operação bloqueada. Registro já existente.');
					        }
						});
					}
				}
				if((widgetFilha.getField('IDTIPOP130').value() == 'R') || (widgetFilha.getField('IDTIPOP130').value() == 'CNA')){
					var filtro = [
						{
							"name": "CDREGP130",
							"operator": "IN",
							"value": widgetFilha.currentRow.CDREGP130
						},
						{
							"name": "P_CDEMPRESA",
							"operator": "=",
							"value": widgetPai.currentRow.CDEMPRESA
						},
						{
							"name": "P_ANO",
							"operator": "=",
							"value": widgetPai.currentRow.DTANO
						}
						
					];
					General.callRestEngine('cadCtb#/crud/regp130ecf_recincempr', 'FilterData', filtro).then(function (result) {
				        result = result.dataset.regp130ecf_recincempr;
				        
				        if(result.length == 0){
				        	General.saveCrud(widgetFilha);
				        	ScreenService.showMessage('Registro salvo com sucesso.');
				        }else{
				        	ScreenService.showMessage('Operação bloqueada. Registro já existente.');
				        }
					});
				}
			}.bind(this));
		}
	};
	
	self.verificaValor = function(widget) {
	    if ((widget.currentRow.VRRECINCEMPR != '') && (widget.currentRow.VRRECINCEMPR != null) ) {
	        if(typeof widget.getField('VRRECINCEMPR').value() == 'number'){
	        	if(widget.getField('VRRECINCEMPR').value() <= '0'){
					ScreenService.showMessage("Valor da receita deve ser maior que zero");
					return false;
				}
	        	return true;
	        }
	        if (typeof widget.getField('VRRECINCEMPR').value() != 'string') {
	            widget.currentRow.VRRECINCEMPR = widget.currentRow.VRRECINCEMPR + '';
	            if (widget.currentRow.VRRECINCEMPR.indexOf(".") != -1) {
	                widget.currentRow.VRRECINCEMPR = widget.currentRow.VRRECINCEMPR.replace(".", ",");
	            }
	        }
	        if (typeof widget.getField('VRRECINCEMPR').value() == 'string') {
		        var parteInteira = widget.currentRow.VRRECINCEMPR.slice(0, widget.currentRow.VRRECINCEMPR.length - 3);
		        var parteDecimal = widget.currentRow.VRRECINCEMPR.slice(widget.currentRow.VRRECINCEMPR.length - 2, widget.currentRow.VRRECINCEMPR.length);
		        if (parteInteira.indexOf(".") != -1) {
		            parteInteira = parteInteira.replace(/[\[\].]+/g, '');
		        }
		
		
		        widget.currentRow.VRRECINCEMPR = parteInteira + '.' + parteDecimal;
		        widget.currentRow.VRRECINCEMPR = parseFloat(widget.currentRow.VRRECINCEMPR);
		        if(widget.getField('VRRECINCEMPR').value() <= '0'){
					ScreenService.showMessage("Valor da receita deve ser maior que zero");
					return false;
				}
	    	}
	    }else {
	    	ScreenService.showMessage("Preencha o campo de valor. Campo obrigatório.");
	    	return false;
	    }
	
	    return true;
	};
	
	self.verificaReload = function(widget){
		var row = widget.getParent().currentRow;
		if(row.CDEMPRESA && row.DTANO)
			widget.reload();
		else
			widget.dataSource.data = [];
	};
	
	self.verificaTipo = function(widget){
		if(widget.currentRow.IDTIPOP130 == 'R' || widget.currentRow.IDTIPOP130 == 'CNA')
			widget.getAction('edit').readOnly = true;
		else
			widget.getAction('edit').readOnly = false;
	};

}

/* global Configuration */
Configuration(function (ContextRegister) {
	ContextRegister.register('Ger18100_RegistroP130ReceitasIncentivadas_Controller', Ger18100_RegistroP130ReceitasIncentivadas_Controller);
});


// FILE: ./assets/js/controllers/Ger18200_RegistroP200ApuracaoaBaseDeCalculo_Controller.js
function Ger18200_RegistroP200ApuracaoaBaseDeCalculo_Controller(General, ScreenService, templateManager) {

  	var self = this;

	self.verificaDataSource = function(){
  		var widgetFilha = templateManager.container.getWidget('ger18200_registro_p200_apuracao_da_base_de_calculo');
  		if(widgetFilha.getField('CDREGP200').dataSource.data.length == 0 ){
  			ScreenService.showMessage("Não existem Bases de Cálculo do Lucro Presumido importadas para o sistema. Favor acessar a tela de importação e realizar a importação da tabela P200 da ECF.");
  			return;
  		}
  		return; 
  	};

	self.editar = function(){
		var widgetFilha = templateManager.container.getWidget('ger18200_registro_p200_apuracao_da_base_de_calculo');
		if(widgetFilha.getField('IDTIPOP200').value() == 'E' || widgetFilha.getField('IDTIPOP200').value() == 'CA'){
			widgetFilha.getField('DTBASECALCPEMPR').readOnly = false;
	    	widgetFilha.getField('VRBASECALCPEMPR').readOnly = false;
	    	widgetFilha.getField('DTBASECALCPEMPR').validations = {
	    		"required": {
                    "message": "Campo obrigatório"
                }
	    	};
	    	widgetFilha.getField('VRBASECALCPEMPR').validations = {
	    		"required": {
                    "message": "Campo obrigatório"
                }
	    	};
	    	General.edit(widgetFilha);
		}else{
			widgetFilha.getField('DTBASECALCPEMPR').validations = {};
	    	widgetFilha.getField('VRBASECALCPEMPR').validations = {};
		    widgetFilha.getField('DTBASECALCPEMPR').readOnly = true;
	    	widgetFilha.getField('VRBASECALCPEMPR').readOnly = true;
			General.edit(widgetFilha);
		}	
		
	};

	self.adicionar = function(){
		var widgetFilha = templateManager.container.getWidget('ger18200_registro_p200_apuracao_da_base_de_calculo');
		widgetFilha.getField('DTBASECALCPEMPR').validations = {};
    	widgetFilha.getField('VRBASECALCPEMPR').validations = {};
	    widgetFilha.getField('DTBASECALCPEMPR').readOnly = true;
    	widgetFilha.getField('VRBASECALCPEMPR').readOnly = true;
		widgetFilha.newRow();
	};
  	
	self.habilitaDataEValor = function() {
		var widgetFilha = templateManager.container.getWidget('ger18200_registro_p200_apuracao_da_base_de_calculo');
		
	    if(widgetFilha.getField('IDTIPOP200').value() == 'E' || widgetFilha.getField('IDTIPOP200').value() == 'CA'){
	    	widgetFilha.getField('DTBASECALCPEMPR').readOnly = false;
	    	widgetFilha.getField('VRBASECALCPEMPR').readOnly = false;
	    	widgetFilha.getField('DTBASECALCPEMPR').validations = {
	    		"required": {
                    "message": "Campo obrigatório"
                }
	    	};
	    	widgetFilha.getField('VRBASECALCPEMPR').validations = {
	    		"required": {
                    "message": "Campo obrigatório"
                }
	    	};
	    }else {
	    	widgetFilha.getField('DTBASECALCPEMPR').validations = {};
	    	widgetFilha.getField('VRBASECALCPEMPR').validations = {};
		    widgetFilha.getField('DTBASECALCPEMPR').readOnly = true;
	    	widgetFilha.getField('VRBASECALCPEMPR').readOnly = true;
	    }
	};
	
	self.verificaData = function(widget) {
		if(!widget.currentRow.DTBASECALCPEMPR){
			ScreenService.showMessage("Preencha o campo de data. Campo Obrigatório.");
			return false;
		}
		var aux = widget.getField('DTBASECALCPEMPR').value(); 
		if(aux.substring(6,10) != '2019'){
			ScreenService.showMessage("Data informada deve estar no ano de referência informado.");
			return false;
		}
		return true;
	};

	self.verificaValor = function(widget) {
	    if ((widget.currentRow.VRBASECALCPEMPR != '') && (widget.currentRow.VRBASECALCPEMPR != null) ) {
	        if(typeof widget.getField('VRBASECALCPEMPR').value() == 'number'){
	        	if(widget.getField('VRBASECALCPEMPR').value() <= '0'){
					ScreenService.showMessage("Valor da receita deve ser maior que zero");
					return false;
				}
	        	return true;
	        }
	        if (typeof widget.getField('VRBASECALCPEMPR').value() != 'string') {
	            widget.currentRow.VRBASECALCPEMPR = widget.currentRow.VRBASECALCPEMPR + '';
	            if (widget.currentRow.VRBASECALCPEMPR.indexOf(".") != -1) {
	                widget.currentRow.VRBASECALCPEMPR = widget.currentRow.VRBASECALCPEMPR.replace(".", ",");
	            }
	        }
	        var parteInteira = widget.currentRow.VRBASECALCPEMPR.slice(0, widget.currentRow.VRBASECALCPEMPR.length - 3);
	        var parteDecimal = widget.currentRow.VRBASECALCPEMPR.slice(widget.currentRow.VRBASECALCPEMPR.length - 2, widget.currentRow.VRBASECALCPEMPR.length);
	        if (parteInteira.indexOf(".") != -1) {
	            parteInteira = parteInteira.replace(/[\[\].]+/g, '');
	        }
	
	
	        widget.currentRow.VRBASECALCPEMPR = parteInteira + '.' + parteDecimal;
	        widget.currentRow.VRBASECALCPEMPR = parseFloat(widget.currentRow.VRBASECALCPEMPR);
	        if(widget.getField('VRBASECALCPEMPR').value() <= '0'){
				ScreenService.showMessage("Valor da receita deve ser maior que zero");
				return false;
			}
	    }else {
	    	ScreenService.showMessage("Preencha o campo de valor. Campo obrigatório.");
	    	return false;
	    }
	
	    return true;
	};
	
	self.setDataReferencia = function(widget){
		var ano = widget.getParent().currentRow.DTANO;
		widget.currentRow.DTREFERENCIA = '31/12/'+ ano;
	};
	
	self.salvar = function() {
		var widgetFilha = templateManager.container.getWidget('ger18200_registro_p200_apuracao_da_base_de_calculo');
		var widgetPai = templateManager.container.getWidget('blocoP');
		
		self.setDataReferencia(widgetFilha);
		widgetFilha.currentRow.CDEMPRESA = widgetFilha.getParent().currentRow.CDEMPRESA;
		if(widgetFilha.isValid()){
			General.callRestEngine('cadCtb#/crud/basecalcpempr_max', 'FilterData', []).then(function (result) {
				result = result.dataset.basecalcpempr_max[0];
				
				if(widgetFilha.currentRow.__is_new == true){
					if(result){
						widgetFilha.currentRow.NRBASECALCPEMPR = result.NRBASECALCPEMPR;
					}else{
						widgetFilha.currentRow.NRBASECALCPEMPR = 1;
					}
					
				}
					
				if((widgetFilha.getField('IDTIPOP200').value() == 'E') || (widgetFilha.getField('IDTIPOP200').value() == 'CA')){
					if((self.verificaData(widgetFilha) == true) && (self.verificaValor(widgetFilha) == true)){
						var filter = [
							{
								"name": "DTBASECALCPEMPR",
								"operator": "IN",
								"value": widgetFilha.currentRow.DTBASECALCPEMPR
							},
							{
								"name": "P_CDEMPRESA",
								"operator": "=",
								"value": widgetPai.currentRow.CDEMPRESA
							},
							{
								"name": "P_ANO",
								"operator": "=",
								"value": widgetPai.currentRow.DTANO
							},
							{
								"name": "VRBASECALCPEMPR",
								"operator": "IN",
								"value": widgetFilha.currentRow.VRBASECALCPEMPR
							}
						];
						General.callRestEngine('cadCtb#/crud/regp200ecf_basecalcpempr', 'FilterData', filter).then(function (result) {
					        result = result.dataset.regp200ecf_basecalcpempr;
					        
					        if(result.length == 0){
					        	General.saveCrud(widgetFilha);
					        	ScreenService.showMessage('Registro salvo com sucesso.');
					        }else{
					        	ScreenService.showMessage('Operação bloqueada. Registro já existente.');
					        }
						});
					}
				}
				if((widgetFilha.getField('IDTIPOP200').value() == 'R') || (widgetFilha.getField('IDTIPOP200').value() == 'CNA')){
					var filtro = [
						{
							"name": "CDREGP200",
							"operator": "IN",
							"value": widgetFilha.currentRow.CDREGP200
						},
						{
							"name": "P_CDEMPRESA",
							"operator": "=",
							"value": widgetPai.currentRow.CDEMPRESA
						},
						{
							"name": "P_ANO",
							"operator": "=",
							"value": widgetPai.currentRow.DTANO
						}
						
					];
					General.callRestEngine('cadCtb#/crud/regp200ecf_basecalcpempr', 'FilterData', filtro).then(function (result) {
				        result = result.dataset.regp200ecf_basecalcpempr;
				        
				        if(result.length == 0){
				        	General.saveCrud(widgetFilha);
				        	ScreenService.showMessage('Registro salvo com sucesso.');
				        }else{
				        	ScreenService.showMessage('Operação bloqueada. Registro já existente.');
				        }
					});
				}
				
					
			}.bind(this));
		}
	};
	
	self.verificaReload = function(widget){
		var row = widget.getParent().currentRow;
		if(row.CDEMPRESA && row.DTANO)
			widget.reload();
		else
			widget.dataSource.data = [];
	};
	
	self.verificaTipo = function(widget){
		if(widget.currentRow.IDTIPOP200 == 'R' || widget.currentRow.IDTIPOP200 == 'CNA')
			widget.getAction('edit').readOnly = true;
		else
			widget.getAction('edit').readOnly = false;
	};

}

/* global Configuration */
Configuration(function (ContextRegister) {
	ContextRegister.register('Ger18200_RegistroP200ApuracaoaBaseDeCalculo_Controller', Ger18200_RegistroP200ApuracaoaBaseDeCalculo_Controller);
});


// FILE: ./assets/js/controllers/Ger18300_RegistroP230IsencoesEReducoes_Controller.js
function Ger18300_RegistroP230IsencoesEReducoes_Controller(General, ScreenService, templateManager) {

  	var self = this;

	self.verificaDataSource = function(){
  		var widgetFilha = templateManager.container.getWidget('ger18300_registro_p230_isencoes_e_reducoes');
  		if(widgetFilha.getField('CDREGP230').dataSource.data.length == 0 ){
  			ScreenService.showMessage("Não existem Isenções ou Reduções do Lucro Presumido importadas para o sistema. Favor acessar a tela de importação e realizar a importação da tabela P230 da ECF.");
  			return;
  		} 
  		return;
  	};

	self.editar = function(){
		var widgetFilha = templateManager.container.getWidget('ger18300_registro_p230_isencoes_e_reducoes');
		if(widgetFilha.getField('IDTIPOP230').value() == 'E' || widgetFilha.getField('IDTIPOP230').value() == 'CA'){
			widgetFilha.getField('DTCALCISEREDP').readOnly = false;
	    	widgetFilha.getField('VRCALCISEREDP').readOnly = false;
	    	widgetFilha.getField('DTCALCISEREDP').validations = {
	    		"required": {
                    "message": "Campo obrigatório"
                }
	    	};
	    	widgetFilha.getField('VRCALCISEREDP').validations = {
	    		"required": {
                    "message": "Campo obrigatório"
                }
	    	};
	    	General.edit(widgetFilha);
		}else{
			widgetFilha.getField('DTCALCISEREDP').validations = {};
	    	widgetFilha.getField('VRCALCISEREDP').validations = {};
		    widgetFilha.getField('DTCALCISEREDP').readOnly = true;
	    	widgetFilha.getField('VRCALCISEREDP').readOnly = true;
			General.edit(widgetFilha);
		}
		
	};

	self.adicionar = function(){
		var widgetFilha = templateManager.container.getWidget('ger18300_registro_p230_isencoes_e_reducoes');
		widgetFilha.getField('DTCALCISEREDP').validations = {};
    	widgetFilha.getField('VRCALCISEREDP').validations = {};
	    widgetFilha.getField('DTCALCISEREDP').readOnly = true;
    	widgetFilha.getField('VRCALCISEREDP').readOnly = true;
		widgetFilha.newRow();
	};
  	
	self.habilitaDataEValor = function() {
		var widgetFilha = templateManager.container.getWidget('ger18300_registro_p230_isencoes_e_reducoes');
		
	    if(widgetFilha.getField('IDTIPOP230').value() == 'E' || widgetFilha.getField('IDTIPOP230').value() == 'CA'){
	    	widgetFilha.getField('DTCALCISEREDP').readOnly = false;
	    	widgetFilha.getField('VRCALCISEREDP').readOnly = false;
	    	widgetFilha.getField('DTCALCISEREDP').validations = {
	    		"required": {
                    "message": "Campo obrigatório"
                }
	    	};
	    	widgetFilha.getField('VRCALCISEREDP').validations = {
	    		"required": {
                    "message": "Campo obrigatório"
                }
	    	};
	    }else {
	    	widgetFilha.getField('DTCALCISEREDP').validations = {};
	    	widgetFilha.getField('VRCALCISEREDP').validations = {};
		    widgetFilha.getField('DTCALCISEREDP').readOnly = true;
	    	widgetFilha.getField('VRCALCISEREDP').readOnly = true;
	    }
	};
	
	self.verificaData = function(widget) {
		if(!widget.currentRow.DTCALCISEREDP){
			ScreenService.showMessage("Preencha o campo de data. Campo obrigatório.");
			return false;
		}
		var aux = widget.getField('DTCALCISEREDP').value(); 
		if(aux.substring(6,10) != '2019'){
			ScreenService.showMessage("Data informada deve estar no ano de referência informado.");
			return false;
		}
		return true;
	};

	self.verificaValor = function(widget) {
	    if ((widget.currentRow.VRCALCISEREDP != '') && (widget.currentRow.VRCALCISEREDP != null) ) {
	        if(typeof widget.getField('VRCALCISEREDP').value() == 'number'){
	        	if(widget.getField('VRCALCISEREDP').value() <= '0'){
					ScreenService.showMessage("Valor da receita deve ser maior que zero");
					return false;
				}
	        	return true;
	        }
	        if (typeof widget.getField('VRCALCISEREDP').value() != 'string') {
	            widget.currentRow.VRCALCISEREDP = widget.currentRow.VRCALCISEREDP + '';
	            if (widget.currentRow.VRCALCISEREDP.indexOf(".") != -1) {
	                widget.currentRow.VRCALCISEREDP = widget.currentRow.VRCALCISEREDP.replace(".", ",");
	            }
	        }
	        var parteInteira = widget.currentRow.VRCALCISEREDP.slice(0, widget.currentRow.VRCALCISEREDP.length - 3);
	        var parteDecimal = widget.currentRow.VRCALCISEREDP.slice(widget.currentRow.VRCALCISEREDP.length - 2, widget.currentRow.VRCALCISEREDP.length);
	        if (parteInteira.indexOf(".") != -1) {
	            parteInteira = parteInteira.replace(/[\[\].]+/g, '');
	        }
	
	
	        widget.currentRow.VRCALCISEREDP = parteInteira + '.' + parteDecimal;
	        widget.currentRow.VRCALCISEREDP = parseFloat(widget.currentRow.VRCALCISEREDP);
	        if(widget.getField('VRCALCISEREDP').value() <= '0'){
				ScreenService.showMessage("Valor da receita deve ser maior que zero");
				return false;
			}
	    }else {
	    	ScreenService.showMessage("Preencha o campo de valor. Campo obrigatório.");
	    	return false;
	    }
	
	    return true;
	};
	
	self.setDataReferencia = function(widget){
		var ano = widget.getParent().currentRow.DTANO;
		widget.currentRow.DTREFERENCIA = '31/12/'+ ano;
	};
	
	self.salvar = function() {
		var widgetFilha = templateManager.container.getWidget('ger18300_registro_p230_isencoes_e_reducoes');
		var widgetPai = templateManager.container.getWidget('blocoP');
		
		self.setDataReferencia(widgetFilha);
		widgetFilha.currentRow.CDEMPRESA = widgetFilha.getParent().currentRow.CDEMPRESA;
		if(widgetFilha.isValid()){
			General.callRestEngine('cadCtb#/crud/calciseredp_max', 'FilterData', []).then(function (result) {
				result = result.dataset.calciseredp_max[0];
				
				if(widgetFilha.currentRow.__is_new == true){
					if(result){
						widgetFilha.currentRow.NRCALCISEREDP = result.NRCALCISEREDP;	
					}else{
						widgetFilha.currentRow.NRCALCISEREDP = 1;
					}
					
				}
					
				if((widgetFilha.getField('IDTIPOP230').value() == 'E') || (widgetFilha.getField('IDTIPOP230').value() == 'CA')){
					if((self.verificaData(widgetFilha) == true) && (self.verificaValor(widgetFilha) == true)){
						var filter = [
							{
								"name": "DTCALCISEREDP",
								"operator": "IN",
								"value": widgetFilha.currentRow.DTCALCISEREDP
							},
							{
								"name": "P_CDEMPRESA",
								"operator": "=",
								"value": widgetPai.currentRow.CDEMPRESA
							},
							{
								"name": "P_ANO",
								"operator": "=",
								"value": widgetPai.currentRow.DTANO
							},
							{
								"name": "VRCALCISEREDP",
								"operator": "IN",
								"value": widgetFilha.currentRow.VRCALCISEREDP
							}
						];
						General.callRestEngine('cadCtb#/crud/regp230ecf_calciseredp', 'FilterData', filter).then(function (result) {
					        result = result.dataset.regp230ecf_calciseredp;
					        
					        if(result.length == 0){
					        	General.saveCrud(widgetFilha);
					        	ScreenService.showMessage('Registro salvo com sucesso.');
					        }else{
					        	ScreenService.showMessage('Operação bloqueada. Registro já existente.');
					        }
						});
					}
				}
				if((widgetFilha.getField('IDTIPOP230').value() == 'R') || (widgetFilha.getField('IDTIPOP230').value() == 'CNA')){
					var filtro = [
						{
							"name": "CDREGP230",
							"operator": "IN",
							"value": widgetFilha.currentRow.CDREGP230
						},
						{
							"name": "P_CDEMPRESA",
							"operator": "=",
							"value": widgetPai.currentRow.CDEMPRESA
						},
						{
							"name": "P_ANO",
							"operator": "=",
							"value": widgetPai.currentRow.DTANO
						}
						
					];
					General.callRestEngine('cadCtb#/crud/regp230ecf_calciseredp', 'FilterData', filtro).then(function (result) {
				        result = result.dataset.regp230ecf_calciseredp;
				        
				        if(result.length == 0){
				        	General.saveCrud(widgetFilha);
				        	ScreenService.showMessage('Registro salvo com sucesso.');
				        }else{
				        	ScreenService.showMessage('Operação bloqueada. Registro já existente.');
				        }
					});
				}
				
					
			}.bind(this));
		}
	};
	
	self.verificaReload = function(widget){
		var row = widget.getParent().currentRow;
		if(row.CDEMPRESA && row.DTANO)
			widget.reload();
		else
			widget.dataSource.data = [];
	};
	
	self.verificaTipo = function(widget){
		if(widget.currentRow.IDTIPOP230 == 'R' || widget.currentRow.IDTIPOP230 == 'CNA')
			widget.getAction('edit').readOnly = true;
		else
			widget.getAction('edit').readOnly = false;
	};

}

/* global Configuration */
Configuration(function (ContextRegister) {
	ContextRegister.register('Ger18300_RegistroP230IsencoesEReducoes_Controller', Ger18300_RegistroP230IsencoesEReducoes_Controller);
});


// FILE: ./assets/js/controllers/Ger18400_RegistroP300CalculoDoIrpj_Controller.js
function Ger18400_RegistroP300CalculoDoIrpj_Controller(General, ScreenService, templateManager) {

  	var self = this;
  	
  	self.verificaDataSource = function(){
  		var widgetFilha = templateManager.container.getWidget('ger18400_registro_p300_calculo_do_irpj');
  		if(widgetFilha.getField('CDREGP300').dataSource.data.length == 0){
  			ScreenService.showMessage("Não existem Informações sobre Apuração do IRPJ do Lucro Presumido importadas para o sistema. Favor acessar a tela de importação e realizar a importação da tabela P300 da ECF.");
  			return;
  		}
  		return;
  	}; 
  	
	self.editar = function(){
		var widgetFilha = templateManager.container.getWidget('ger18400_registro_p300_calculo_do_irpj');
		if(widgetFilha.getField('IDTIPOP300').value() == 'E' || widgetFilha.getField('IDTIPOP300').value() == 'CA'){
			widgetFilha.getField('DTCALCIRPJP').readOnly = false;
	    	widgetFilha.getField('VRCALCIRPJP').readOnly = false;
	    	widgetFilha.getField('DTCALCIRPJP').validations = {
	    		"required": {
                    "message": "Campo obrigatório"
                }
	    	};
	    	widgetFilha.getField('VRCALCIRPJP').validations = {
				"required": {
                    "message": "Campo obrigatório"
                }
	    	};
	    	General.edit(widgetFilha);
		}else{
			widgetFilha.getField('DTCALCIRPJP').validations = {};
	    	widgetFilha.getField('VRCALCIRPJP').validations = {};
		    widgetFilha.getField('DTCALCIRPJP').readOnly = true;
	    	widgetFilha.getField('VRCALCIRPJP').readOnly = true;
			General.edit(widgetFilha);
		}
		
	};

	self.adicionar = function(){
		var widgetFilha = templateManager.container.getWidget('ger18400_registro_p300_calculo_do_irpj');
		widgetFilha.getField('DTCALCIRPJP').validations = {};
    	widgetFilha.getField('VRCALCIRPJP').validations = {};
	    widgetFilha.getField('DTCALCIRPJP').readOnly = true;
    	widgetFilha.getField('VRCALCIRPJP').readOnly = true;
		widgetFilha.newRow();
	};
  	
	self.habilitaDataEValor = function() {
		var widgetFilha = templateManager.container.getWidget('ger18400_registro_p300_calculo_do_irpj');
		
	    if(widgetFilha.getField('IDTIPOP300').value() == 'E' || widgetFilha.getField('IDTIPOP300').value() == 'CA'){
	    	widgetFilha.getField('DTCALCIRPJP').readOnly = false;
	    	widgetFilha.getField('VRCALCIRPJP').readOnly = false;
	    	widgetFilha.getField('DTCALCIRPJP').validations = {
	    		"required": {
                    "message": "Campo obrigatório"
                }
	    	};
	    	widgetFilha.getField('VRCALCIRPJP').validations = {
	    		"required": {
                    "message": "Campo obrigatório"
                }
	    	};
	    }else {
	    	widgetFilha.getField('DTCALCIRPJP').validations = {};
	    	widgetFilha.getField('VRCALCIRPJP').validations = {};
		    widgetFilha.getField('DTCALCIRPJP').readOnly = true;
	    	widgetFilha.getField('VRCALCIRPJP').readOnly = true;
	    }
	};
	
	self.verificaData = function(widget) {
		if(!widget.currentRow.DTCALCIRPJP){
			ScreenService.showMessage("Preencha o campo de data. Campo obrigatório.");
			return false;
		}
		var aux = widget.getField('DTCALCIRPJP').value(); 
		if(aux.substring(6,10) != '2019'){
			ScreenService.showMessage("Data informada deve estar no ano de referência informado.");
			return false;
		}
		return true;
	};

	self.verificaValor = function(widget) {
	    if ((widget.currentRow.VRCALCIRPJP != '') && (widget.currentRow.VRCALCIRPJP != null) ) {
	        if(typeof widget.getField('VRCALCIRPJP').value() == 'number'){
	        	if(widget.getField('VRCALCIRPJP').value() <= '0'){
					ScreenService.showMessage("Valor da receita deve ser maior que zero");
					return false;
				}
	        	return true;
	        }
	        if (typeof widget.getField('VRCALCIRPJP').value() != 'string') {
	            widget.currentRow.VRCALCIRPJP = widget.currentRow.VRCALCIRPJP + '';
	            if (widget.currentRow.VRCALCIRPJP.indexOf(".") != -1) {
	                widget.currentRow.VRCALCIRPJP = widget.currentRow.VRCALCIRPJP.replace(".", ",");
	            }
	        }
	        var parteInteira = widget.currentRow.VRCALCIRPJP.slice(0, widget.currentRow.VRCALCIRPJP.length - 3);
	        var parteDecimal = widget.currentRow.VRCALCIRPJP.slice(widget.currentRow.VRCALCIRPJP.length - 2, widget.currentRow.VRCALCIRPJP.length);
	        if (parteInteira.indexOf(".") != -1) {
	            parteInteira = parteInteira.replace(/[\[\].]+/g, '');
	        }
	
	
	        widget.currentRow.VRCALCIRPJP = parteInteira + '.' + parteDecimal;
	        widget.currentRow.VRCALCIRPJP = parseFloat(widget.currentRow.VRCALCIRPJP);
	        if(widget.getField('VRCALCIRPJP').value() <= '0'){
				ScreenService.showMessage("Valor da receita deve ser maior que zero");
				return false;
			}
	    }else {
	    	ScreenService.showMessage("Preencha o campo de valor. Campo obrigatório.");
	    	return false;
	    }
	
	    return true;
	};
	
	self.setDataReferencia = function(widget){
		var ano = widget.getParent().currentRow.DTANO;
		widget.currentRow.DTREFERENCIA = '31/12/'+ ano;
	};
	
	self.salvar = function() {
		var widgetFilha = templateManager.container.getWidget('ger18400_registro_p300_calculo_do_irpj');
		var widgetPai = templateManager.container.getWidget('blocoP');
		
		self.setDataReferencia(widgetFilha);
		widgetFilha.currentRow.CDEMPRESA = widgetFilha.getParent().currentRow.CDEMPRESA;
		if(widgetFilha.isValid()){
			General.callRestEngine('cadCtb#/crud/calcirpjp_max', 'FilterData', []).then(function (result) {
				result = result.dataset.calcirpjp_max[0];
				
				if(widgetFilha.currentRow.__is_new == true){
					if(result){
						widgetFilha.currentRow.NRCALCIRPJP = result.NRCALCIRPJP;	
					}else{
						widgetFilha.currentRow.NRCALCIRPJP = 1;
					}
					
				}
					
				if((widgetFilha.getField('IDTIPOP300').value() == 'E') || (widgetFilha.getField('IDTIPOP300').value() == 'CA')){
					if((self.verificaData(widgetFilha) == true) && (self.verificaValor(widgetFilha) == true)){
						var filter = [
							{
								"name": "DTCALCIRPJP",
								"operator": "IN",
								"value": widgetFilha.currentRow.DTCALCIRPJP
							},
							{
								"name": "P_CDEMPRESA",
								"operator": "=",
								"value": widgetPai.currentRow.CDEMPRESA
							},
							{
								"name": "P_ANO",
								"operator": "=",
								"value": widgetPai.currentRow.DTANO
							},
							{
								"name": "VRCALCIRPJP",
								"operator": "IN",
								"value": widgetFilha.currentRow.VRCALCIRPJP
							}
						];
						General.callRestEngine('cadCtb#/crud/regp300ecf_calcirpjp', 'FilterData', filter).then(function (result) {
					        result = result.dataset.regp300ecf_calcirpjp;
					        
					        if(result.length == 0){
					        	General.saveCrud(widgetFilha);
					        	ScreenService.showMessage('Registro salvo com sucesso.');
					        }else{
					        	ScreenService.showMessage('Operação bloqueada. Registro já existente.');
					        }
						});
					}
				}
				if((widgetFilha.getField('IDTIPOP300').value() == 'R') || (widgetFilha.getField('IDTIPOP300').value() == 'CNA')){
					var filtro = [
						{
							"name": "CDREGP300",
							"operator": "IN",
							"value": widgetFilha.currentRow.CDREGP300
						},
						{
							"name": "P_CDEMPRESA",
							"operator": "=",
							"value": widgetPai.currentRow.CDEMPRESA
						},
						{
							"name": "P_ANO",
							"operator": "=",
							"value": widgetPai.currentRow.DTANO
						}
						
					];
					General.callRestEngine('cadCtb#/crud/regp300ecf_calcirpjp', 'FilterData', filtro).then(function (result) {
				        result = result.dataset.regp300ecf_calcirpjp;
				        
				        if(result.length == 0){
				        	General.saveCrud(widgetFilha);
				        	ScreenService.showMessage('Registro salvo com sucesso.');
				        }else{
				        	ScreenService.showMessage('Operação bloqueada. Registro já existente.');
				        }
					});
				}
				
					
			}.bind(this));	
		}
	};
	
	self.verificaReload = function(widget){
		var row = widget.getParent().currentRow;
		if(row.CDEMPRESA && row.DTANO)
			widget.reload();
		else
			widget.dataSource.data = [];
	};
	
	self.verificaTipo = function(widget){
		if(widget.currentRow.IDTIPOP300 == 'R' || widget.currentRow.IDTIPOP300 == 'CNA')
			widget.getAction('edit').readOnly = true;
		else
			widget.getAction('edit').readOnly = false;
	};

}

/* global Configuration */
Configuration(function (ContextRegister) {
	ContextRegister.register('Ger18400_RegistroP300CalculoDoIrpj_Controller', Ger18400_RegistroP300CalculoDoIrpj_Controller);
});


// FILE: ./assets/js/controllers/Ger18500_RegistroP400BaseDeCalculoDaCsll_Controller.js
function Ger18500_RegistroP400BaseDeCalculoDaCsll_Controller(General, ScreenService, templateManager) {

  	var self = this;
  	
  	self.verificaDataSource = function(){
  		var widgetFilha = templateManager.container.getWidget('ger18500_registro_p400_base_de_calculo_da_csll');
  		if(widgetFilha.getField('CDREGP400').dataSource.data.length == 0){
  			ScreenService.showMessage("Não existem Informações sobre as Bases de Cálculo da CSLL do Lucro Presumido importadas para o sistema. Favor acessar a tela de importação e realizar a importação da tabela P400 da ECF.");
  			return;
  		} 
  		return;
  	};
  	
	self.editar = function(){
		var widgetFilha = templateManager.container.getWidget('ger18500_registro_p400_base_de_calculo_da_csll');
		if(widgetFilha.getField('IDTIPOP400').value() == 'E' || widgetFilha.getField('IDTIPOP400').value() == 'CA'){
			widgetFilha.getField('DTBASECSLLP').readOnly = false;
	    	widgetFilha.getField('VRBASECSLLP').readOnly = false;
	    	widgetFilha.getField('DTBASECSLLP').validations = {
	    		"required": {
                    "message": "Campo obrigatório"
                }
	    	};
	    	widgetFilha.getField('VRBASECSLLP').validations = {
	    		"required": {
                    "message": "Campo obrigatório"
                }
	    	};
	    	General.edit(widgetFilha);
		}else{
			widgetFilha.getField('DTBASECSLLP').validations = {};
	    	widgetFilha.getField('VRBASECSLLP').validations = {};
		    widgetFilha.getField('DTBASECSLLP').readOnly = true;
	    	widgetFilha.getField('VRBASECSLLP').readOnly = true;
			General.edit(widgetFilha);
		}
		
		
	};

	self.adicionar = function(){
		var widgetFilha = templateManager.container.getWidget('ger18500_registro_p400_base_de_calculo_da_csll');
		widgetFilha.getField('DTBASECSLLP').validations = {};
    	widgetFilha.getField('VRBASECSLLP').validations = {};
	    widgetFilha.getField('DTBASECSLLP').readOnly = true;
    	widgetFilha.getField('VRBASECSLLP').readOnly = true;
		widgetFilha.newRow();
	};
  	
	self.habilitaDataEValor = function() {
		var widgetFilha = templateManager.container.getWidget('ger18500_registro_p400_base_de_calculo_da_csll');
		
	    if(widgetFilha.getField('IDTIPOP400').value() == 'E' || widgetFilha.getField('IDTIPOP400').value() == 'CA'){
	    	widgetFilha.getField('DTBASECSLLP').readOnly = false;
	    	widgetFilha.getField('VRBASECSLLP').readOnly = false;
	    	widgetFilha.getField('DTBASECSLLP').validations = {
	    		"required": {
                    "message": "Campo obrigatório"
                }
	    	};
	    	widgetFilha.getField('VRBASECSLLP').validations = {
	    		"required": {
                    "message": "Campo obrigatório"
                }
	    	};
	    }else {
	    	widgetFilha.getField('DTBASECSLLP').validations = {};
	    	widgetFilha.getField('VRBASECSLLP').validations = {};
		    widgetFilha.getField('DTBASECSLLP').readOnly = true;
	    	widgetFilha.getField('VRBASECSLLP').readOnly = true;
	    }
	};
	
	self.verificaData = function(widget) {
		if(!widget.currentRow.DTBASECSLLP){
			ScreenService.showMessage("Preencha o campo de data. Campo obrigatório.");
			return false;
		}
		var aux = widget.getField('DTBASECSLLP').value(); 
		if(aux.substring(6,10) != '2019'){
			ScreenService.showMessage("Data informada deve estar no ano de referência informado.");
			return false;
		}
		return true;
	};

	self.verificaValor = function(widget) {
	    if ((widget.currentRow.VRBASECSLLP != '') && (widget.currentRow.VRBASECSLLP != null) ) {
	        if(typeof widget.getField('VRBASECSLLP').value() == 'number'){
	        	if(widget.getField('VRBASECSLLP').value() <= '0'){
					ScreenService.showMessage("Valor da receita deve ser maior que zero");
					return false;
				}
	        	return true;
	        }
	        if (typeof widget.getField('VRBASECSLLP').value() != 'string') {
	            widget.currentRow.VRBASECSLLP = widget.currentRow.VRBASECSLLP + '';
	            if (widget.currentRow.VRBASECSLLP.indexOf(".") != -1) {
	                widget.currentRow.VRBASECSLLP = widget.currentRow.VRBASECSLLP.replace(".", ",");
	            }
	        }
	        var parteInteira = widget.currentRow.VRBASECSLLP.slice(0, widget.currentRow.VRBASECSLLP.length - 3);
	        var parteDecimal = widget.currentRow.VRBASECSLLP.slice(widget.currentRow.VRBASECSLLP.length - 2, widget.currentRow.VRBASECSLLP.length);
	        if (parteInteira.indexOf(".") != -1) {
	            parteInteira = parteInteira.replace(/[\[\].]+/g, '');
	        }
	
	
	        widget.currentRow.VRBASECSLLP = parteInteira + '.' + parteDecimal;
	        widget.currentRow.VRBASECSLLP = parseFloat(widget.currentRow.VRBASECSLLP);
	        if(widget.getField('VRBASECSLLP').value() <= '0'){
				ScreenService.showMessage("Valor da receita deve ser maior que zero");
				return false;
			}
	    }else {
	    	ScreenService.showMessage("Preencha o campo de valor. Campo obrigatório.");
	    	return false;
	    }
	
	    return true;
	};
	
	self.setDataReferencia = function(widget){
		var ano = widget.getParent().currentRow.DTANO;
		widget.currentRow.DTREFERENCIA = '31/12/'+ ano;
	};
	
	self.salvar = function() {
		var widgetFilha = templateManager.container.getWidget('ger18500_registro_p400_base_de_calculo_da_csll');
		var widgetPai = templateManager.container.getWidget('blocoP');
		
		self.setDataReferencia(widgetFilha);
		widgetFilha.currentRow.CDEMPRESA = widgetFilha.getParent().currentRow.CDEMPRESA;
		if(widgetFilha.isValid()){
			General.callRestEngine('cadCtb#/crud/basecsllp_max', 'FilterData', []).then(function (result) {
				result = result.dataset.basecsllp_max[0];
				
				if(widgetFilha.currentRow.__is_new == true){
					if(result){
						widgetFilha.currentRow.NRBASECSLLP = result.NRBASECSLLP;	
					}else{
						widgetFilha.currentRow.NRBASECSLLP = 1;
					}
					
				}
					
				if((widgetFilha.getField('IDTIPOP400').value() == 'E') || (widgetFilha.getField('IDTIPOP400').value() == 'CA')){
					if((self.verificaData(widgetFilha) == true) && (self.verificaValor(widgetFilha) == true)){
						var filter = [
							{
								"name": "DTBASECSLLP",
								"operator": "IN",
								"value": widgetFilha.currentRow.DTBASECSLLP
							},
							{
								"name": "P_CDEMPRESA",
								"operator": "=",
								"value": widgetPai.currentRow.CDEMPRESA
							},
							{
								"name": "P_ANO",
								"operator": "=",
								"value": widgetPai.currentRow.DTANO
							},
							{
								"name": "VRBASECSLLP",
								"operator": "IN",
								"value": widgetFilha.currentRow.VRBASECSLLP
							}
						];
						General.callRestEngine('cadCtb#/crud/regp400ecf_basecsllp', 'FilterData', filter).then(function (result) {
					        result = result.dataset.regp400ecf_basecsllp;
					        
					        if(result.length == 0){
					        	General.saveCrud(widgetFilha);
					        	ScreenService.showMessage('Registro salvo com sucesso.');
					        }else{
					        	ScreenService.showMessage('Operação bloqueada. Registro já existente.');
					        }
						});
					}
				}
				if((widgetFilha.getField('IDTIPOP400').value() == 'R') || (widgetFilha.getField('IDTIPOP400').value() == 'CNA')){
					var filtro = [
						{
							"name": "CDREGP400",
							"operator": "IN",
							"value": widgetFilha.currentRow.CDREGP400
						},
						{
							"name": "P_CDEMPRESA",
							"operator": "=",
							"value": widgetPai.currentRow.CDEMPRESA
						},
						{
							"name": "P_ANO",
							"operator": "=",
							"value": widgetPai.currentRow.DTANO
						}
						
					];
					General.callRestEngine('cadCtb#/crud/regp400ecf_basecsllp', 'FilterData', filtro).then(function (result) {
				        result = result.dataset.regp400ecf_basecsllp;
				        
				        if(result.length == 0){
				        	General.saveCrud(widgetFilha);
				        	ScreenService.showMessage('Registro salvo com sucesso.');
				        }else{
				        	ScreenService.showMessage('Operação bloqueada. Registro já existente.');
				        }
					});
				}
				
					
			}.bind(this));
		}
	};
	
	self.verificaReload = function(widget){
		var row = widget.getParent().currentRow;
		if(row.CDEMPRESA && row.DTANO)
			widget.reload();
		else
			widget.dataSource.data = [];
	};
	
	self.verificaTipo = function(widget){
		if(widget.currentRow.IDTIPOP400 == 'R' || widget.currentRow.IDTIPOP400 == 'CNA')
			widget.getAction('edit').readOnly = true;
		else
			widget.getAction('edit').readOnly = false;
	};

}

/* global Configuration */
Configuration(function (ContextRegister) {
	ContextRegister.register('Ger18500_RegistroP400BaseDeCalculoDaCsll_Controller', Ger18500_RegistroP400BaseDeCalculoDaCsll_Controller);
});


// FILE: ./assets/js/controllers/Ger18600_RegistroP500CalculoDaCsll_Controller.js
function Ger18600_RegistroP500CalculoDaCsll_Controller(General, ScreenService, templateManager) {

  	var self = this;
  	
  	self.verificaDataSource = function(){
  		var widgetFilha = templateManager.container.getWidget('ger18600_registro_p500_calculo_da_csll');
  		if(widgetFilha.getField('CDREGP500').dataSource.data.length == 0){
  			ScreenService.showMessage("Não existem Informações sobre os Cálculos da CSLL do Lucro Presumido importadas para o sistema. Favor acessar a tela de importação e realizar a importação da tabela P500 da ECF.");
  			return;
  		}
  		return;
  	};

	self.editar = function(){
		var widgetFilha = templateManager.container.getWidget('ger18600_registro_p500_calculo_da_csll');
		if(widgetFilha.getField('IDTIPOP500').value() == 'E' || widgetFilha.getField('IDTIPOP500').value() == 'CA'){
			widgetFilha.getField('DTCALCCSLLP').readOnly = false;
	    	widgetFilha.getField('VRCALCCSLLP').readOnly = false;
	    	widgetFilha.getField('DTCALCCSLLP').validations = {
	    		"required": {
                    "message": "Campo obrigatório"
                }
	    	};
	    	widgetFilha.getField('VRCALCCSLLP').validations = {
	    		"required": {
                    "message": "Campo obrigatório"
                }
	    	};
	    	General.edit(widgetFilha);
		}else{
			widgetFilha.getField('DTCALCCSLLP').validations = {};
	    	widgetFilha.getField('VRCALCCSLLP').validations = {};
		    widgetFilha.getField('DTCALCCSLLP').readOnly = true;
	    	widgetFilha.getField('VRCALCCSLLP').readOnly = true;
			General.edit(widgetFilha);
		}
		
	};

	self.adicionar = function(){
		var widgetFilha = templateManager.container.getWidget('ger18600_registro_p500_calculo_da_csll');
		widgetFilha.getField('DTCALCCSLLP').validations = {};
    	widgetFilha.getField('VRCALCCSLLP').validations = {};
	    widgetFilha.getField('DTCALCCSLLP').readOnly = true;
    	widgetFilha.getField('VRCALCCSLLP').readOnly = true;
		widgetFilha.newRow();
	};
  	
	self.habilitaDataEValor = function() {
		var widgetFilha = templateManager.container.getWidget('ger18600_registro_p500_calculo_da_csll');
		
	    if(widgetFilha.getField('IDTIPOP500').value() == 'E' || widgetFilha.getField('IDTIPOP500').value() == 'CA'){
	    	widgetFilha.getField('DTCALCCSLLP').readOnly = false;
	    	widgetFilha.getField('VRCALCCSLLP').readOnly = false;
	    	widgetFilha.getField('DTCALCCSLLP').validations = {
	    		"required": {
                    "message": "Campo obrigatório"
                }
	    	};
	    	widgetFilha.getField('VRCALCCSLLP').validations = { 
	    		"required": {
                    "message": "Campo obrigatório"
                }
	    	};
	    }else {
	    	widgetFilha.getField('DTCALCCSLLP').validations = {};
	    	widgetFilha.getField('VRCALCCSLLP').validations = {};
		    widgetFilha.getField('DTCALCCSLLP').readOnly = true;
	    	widgetFilha.getField('VRCALCCSLLP').readOnly = true;
	    }
	};
	
	self.verificaData = function(widget) {
		if(!widget.currentRow.DTCALCCSLLP){
			ScreenService.showMessage("Preencha o campo de data. Campo obrigatório.");
			return false;
		}
		var aux = widget.getField('DTCALCCSLLP').value(); 
		if(aux.substring(6,10) != '2019'){
			ScreenService.showMessage("Data informada deve estar no ano de referência informado.");
			return false;
		}
		return true;
	};

	self.verificaValor = function(widget) {
	    if ((widget.currentRow.VRCALCCSLLP != '') && (widget.currentRow.VRCALCCSLLP != null) ) {
	        if(typeof widget.getField('VRCALCCSLLP').value() == 'number'){
	        	if(widget.getField('VRCALCCSLLP').value() <= '0'){
					ScreenService.showMessage("Valor da receita deve ser maior que zero");
					return false;
				}
	        	return true;
	        }
	        if (typeof widget.getField('VRCALCCSLLP').value() != 'string') {
	            widget.currentRow.VRCALCCSLLP = widget.currentRow.VRCALCCSLLP + '';
	            if (widget.currentRow.VRCALCCSLLP.indexOf(".") != -1) {
	                widget.currentRow.VRCALCCSLLP = widget.currentRow.VRCALCCSLLP.replace(".", ",");
	            }
	        }
	        var parteInteira = widget.currentRow.VRCALCCSLLP.slice(0, widget.currentRow.VRCALCCSLLP.length - 3);
	        var parteDecimal = widget.currentRow.VRCALCCSLLP.slice(widget.currentRow.VRCALCCSLLP.length - 2, widget.currentRow.VRCALCCSLLP.length);
	        if (parteInteira.indexOf(".") != -1) {
	            parteInteira = parteInteira.replace(/[\[\].]+/g, '');
	        }
	
	
	        widget.currentRow.VRCALCCSLLP = parteInteira + '.' + parteDecimal;
	        widget.currentRow.VRCALCCSLLP = parseFloat(widget.currentRow.VRCALCCSLLP);
	        if(widget.getField('VRCALCCSLLP').value() <= '0'){
				ScreenService.showMessage("Valor da receita deve ser maior que zero");
				return false;
			}
	    }else {
	    	ScreenService.showMessage("Preencha o campo de valor. Campo obrigatório.");
	    	return false;
	    }
	
	    return true;
	};
	
	self.setDataReferencia = function(widget){
		var ano = widget.getParent().currentRow.DTANO;
		widget.currentRow.DTREFERENCIA = '31/12/'+ ano;
	};
	
	self.salvar = function() {
		var widgetFilha = templateManager.container.getWidget('ger18600_registro_p500_calculo_da_csll');
		var widgetPai = templateManager.container.getWidget('blocoP');
		
		self.setDataReferencia(widgetFilha);
		widgetFilha.currentRow.CDEMPRESA = widgetFilha.getParent().currentRow.CDEMPRESA;
		if(widgetFilha.isValid()){
			General.callRestEngine('cadCtb#/crud/calccsllp_max', 'FilterData', []).then(function (result) {
				result = result.dataset.calccsllp_max[0];
				
				if(widgetFilha.currentRow.__is_new == true){
					if(result){
						widgetFilha.currentRow.NRCALCCSLLP = result.NRCALCCSLLP;	
					}else{
						widgetFilha.currentRow.NRCALCCSLLP = 1;
					}
					
				}
					
				if((widgetFilha.getField('IDTIPOP500').value() == 'E') || (widgetFilha.getField('IDTIPOP500').value() == 'CA')){
					if((self.verificaData(widgetFilha) == true) && (self.verificaValor(widgetFilha) == true)){
						var filter = [
							{
								"name": "DTCALCCSLLP",
								"operator": "IN",
								"value": widgetFilha.currentRow.DTCALCCSLLP
							},
							{
								"name": "P_CDEMPRESA",
								"operator": "=",
								"value": widgetPai.currentRow.CDEMPRESA
							},
							{
								"name": "P_ANO",
								"operator": "=",
								"value": widgetPai.currentRow.DTANO
							},
							{
								"name": "VRCALCCSLLP",
								"operator": "IN",
								"value": widgetFilha.currentRow.VRCALCCSLLP
							}
						];
						General.callRestEngine('cadCtb#/crud/regp500ecf_calccsllp', 'FilterData', filter).then(function (result) {
					        result = result.dataset.regp500ecf_calccsllp;
					        
					        if(result.length == 0){
					        	General.saveCrud(widgetFilha);
					        	ScreenService.showMessage('Registro salvo com sucesso.');
					        }else{
					        	ScreenService.showMessage('Operação bloqueada. Registro já existente.');
					        }
						});
					}
				}
				if((widgetFilha.getField('IDTIPOP500').value() == 'R') || (widgetFilha.getField('IDTIPOP500').value() == 'CNA')){
					var filtro = [
						{
							"name": "CDREGP500",
							"operator": "IN",
							"value": widgetFilha.currentRow.CDREGP500
						},
						{
							"name": "P_CDEMPRESA",
							"operator": "=",
							"value": widgetPai.currentRow.CDEMPRESA
						},
						{
							"name": "P_ANO",
							"operator": "=",
							"value": widgetPai.currentRow.DTANO
						}
						
					];
					General.callRestEngine('cadCtb#/crud/regp500ecf_calccsllp', 'FilterData', filtro).then(function (result) {
				        result = result.dataset.regp500ecf_calccsllp;
				        
				        if(result.length == 0){
				        	General.saveCrud(widgetFilha);
				        	ScreenService.showMessage('Registro salvo com sucesso.');
				        }else{
				        	ScreenService.showMessage('Operação bloqueada. Registro já existente.');
				        }
					});
				}
				
					
			}.bind(this));
		}
	};
	
	self.verificaReload = function(widget){
		var row = widget.getParent().currentRow;
		if(row.CDEMPRESA && row.DTANO)
			widget.reload();
		else
			widget.dataSource.data = [];
	};
	
	self.verificaTipo = function(widget){
		if(widget.currentRow.IDTIPOP500 == 'R' || widget.currentRow.IDTIPOP500 == 'CNA')
			widget.getAction('edit').readOnly = true;
		else
			widget.getAction('edit').readOnly = false;
	};

}

/* global Configuration */
Configuration(function (ContextRegister) {
	ContextRegister.register('Ger18600_RegistroP500CalculoDaCsll_Controller', Ger18600_RegistroP500CalculoDaCsll_Controller);
});


// FILE: ./assets/js/controllers/Ger79100_SociedadeContaParticipacao_Controller.js


function Ger79100_SociedadeContaParticipacao_Controller(General, ScreenService, templateManager) {

  	var self = this;
  	
	this.setDefaultEmpresa = function(childWidget) {
		var widget = childWidget.parent;
		childWidget.currentRow.CDEMPRESA = widget.currentRow.CDEMPRESA;
		childWidget.currentRow.NMEMPRESA = widget.currentRow.NMEMPRESA;
	};

	this.updateGridFilter = function(widget) {
		var childWidget = templateManager.container.getWidget("sociedadeParticipacao");
		childWidget.dataSourceFilter[0].value = widget.currentRow.CDEMPRESA;
		childWidget.reload();
	};
	
	self.checkInscricao = function(widget) {
        // var inscricao = General.inscricaoFormat(widget.currentRow.CODSCP);

        // if (inscricao.valid) {
        //     widget.currentRow.CODSCP = inscricao.value;
        // } else {
        //  if (inscricao.tipo.cod == 'J') inscricao.tipo.msg = 'CNPJ' + " \"" + inscricao.value + "\" inválido!";
        //     else if (inscricao.tipo.cod == 'F') inscricao.tipo.msg = 'CPF' + " \"" + inscricao.value + "\" inválido!";
        //     else if (inscricao.tipo.cod == 'I') inscricao.tipo.msg = inscricao.tipo.desc + " \"" + inscricao.value + "\" inválida!";

        //     if (inscricao.tipo.msg) ScreenService.showMessage(inscricao.tipo.msg, "warning");
        //     widget.currentRow.CODSCP = null;
        // }
        
        var cnpjFormantado = widget.currentRow.CODSCP;
		if (cnpjFormantado) {
			var cnpj = widget.currentRow.CODSCP.replace(/[^0-9]/g, '');
			if (!General.validateCNPJ(cnpj)) {
			    var texto = "CNPJ_PARAMETRO";
				ScreenService.showMessage(texto,{"PARAMETRO": cnpjFormantado});
				widget.currentRow.CODSCP = null;
			}
		}
    };
    
    self.justInteger = function(campos) {
        campos.forEach(function(campo) {
            General.justInteger(campo);
        });
    };
    
    
    self.adicionarSociedade = function(widget){
        var widgetPai = widget.getParent();
        
        // if(widgetPai.currentRow.CDEMPRESA != null){
        //     widget.newRow(widget);
        //     widgetPai.currentRow.CDEMPRESA = null;
        // }else ScreenService.showMessage('Operação bloqueada. Preencha o campo Empresa.');
        
        if(widgetPai.currentRow.CDEMPRESA == null || widgetPai.currentRow.CDEMPRESA == "" ){
            ScreenService.showMessage('Operação bloqueada. Preencha o campo Empresa.');
        }else widget.newRow(widget);
        
    };
    
    
    self.salvar = function(widget){
    	var codscp = widget.currentRow.CODSCP;
    	widget.currentRow.CODSCP = codscp.replace(/[-./]+/g, '');
    	
    	if(widget.currentRow.__is_new == true){
        	var widgetEmpresaTabbed = widget.getParent();
        	
        	var filter = [
                    {
                        "name": "CDEMPRESA",
                        "operator": "=",
                        "value": widgetEmpresaTabbed.currentRow.CDEMPRESA
                    },
                    {
                        "name": "CODSCP",
                        "operator": "=",
                        "value": widget.currentRow.CODSCP
                    }
            ];
    
            General.callRestEngine('cadCtb#/crud/scpempresa', 'FilterData', filter).then(function (result) {
                result = result.dataset.scpempresa;
                
                if(result.length == 0) 
                    General.saveCrud(widget);
                else ScreenService.showMessage('Operação bloqueada. CNPJ já cadastrado.');
            });
    	}else{
    	    General.saveCrud(widget);
    	}
    };
    
    
    
    

}

Configuration(function (ContextRegister) {
	ContextRegister.register('Ger79100_SociedadeContaParticipacao_Controller', Ger79100_SociedadeContaParticipacao_Controller);
});


// FILE: ./assets/js/controllers/Registro0000deAbertura_controller.js
function Registro0000deAbertura_controller(General, ScreenService, templateManager) {

  	var self = this;
  	 
  	self.ativaRegistro0000 = function() {
		var widgetReg0000 = templateManager.container.getWidget('registro_0000');
		widgetReg0000.activate();
		widgetReg0000.reload();
	};
	
	self.editarRegistro0000 = function(){
		var widgetReg0000 = templateManager.container.getWidget('registro_0000');
		var widgetReg0010 = templateManager.container.getWidget('registro_0010');
		var widgetReg0020 = templateManager.container.getWidget('registro_0020');
		
		widgetReg0010.isVisible = false;
		widgetReg0020.isVisible = false;
		General.edit(widgetReg0000);
	};
	
	self.cancelarRegistro0000 = function(){
		var widgetReg0000 = templateManager.container.getWidget('registro_0000');
		var widgetReg0010 = templateManager.container.getWidget('registro_0010');
		var widgetReg0020 = templateManager.container.getWidget('registro_0020');
		
		widgetReg0010.isVisible = true;
		widgetReg0020.isVisible = true;
		// General.backOrCancel(widgetReg0000);
	};
	
	self.salvarRegistro0000 = function(){
		var widgetReg0000 = templateManager.container.getWidget('registro_0000');
		var widgetReg0010 = templateManager.container.getWidget('registro_0010');
		var widgetReg0020 = templateManager.container.getWidget('registro_0020');
		
		widgetReg0000.currentRow.CDEMPRESA = widgetReg0000.getParent().currentRow.CDEMPRESA;
		
		if(!widgetReg0000.currentRow.hasOwnProperty('__is_new')) { //Se o registro não existir este deve ser sinalizado como novo
			widgetReg0000.currentRow.__is_new = true;
		}
		
		widgetReg0010.isVisible = true;
		widgetReg0020.isVisible = true;
		General.saveCrud(widgetReg0000);
	};
}

/* global Configuration */
Configuration(function (ContextRegister) {
	ContextRegister.register('Registro0000deAbertura_controller', Registro0000deAbertura_controller);
});


// FILE: ./assets/js/controllers/Registro0010deAbertura_controller.js
function Registro0010deAbertura_controller(General, ScreenService, templateManager) {

  	var self = this;
  	
  	self.ativaRegistro0010 = function() {
		var widgetReg0010 = templateManager.container.getWidget('registro_0010');
		templateManager.container.getWidget('registro_0010').reload();
		widgetReg0010.currentRow = widgetReg0010.dataSource.data[0]?widgetReg0010.dataSource.data[0]:{};
		var FORMATRIBPER = widgetReg0010.getField('FORMATRIBPER').value();
		widgetReg0010.activate();
		widgetReg0010.reload();
	};
	
	self.carregaVetores = function(widget){
		if(widget.dataSource.data.length != 0){
			if(widget.currentRow.FORMATRIBPER) {
				var FORMATRIBPER = widget.currentRow.FORMATRIBPER.split("");
				widget.currentRow.FORMATRIBPER1 = FORMATRIBPER[0];
				widget.currentRow.FORMATRIBPER2 = FORMATRIBPER[1];
				widget.currentRow.FORMATRIBPER3 = FORMATRIBPER[2];
				widget.currentRow.FORMATRIBPER4 = FORMATRIBPER[3];
			}
			if(widget.currentRow.MESBALRED) {
				var MESBALRED = widget.currentRow.MESBALRED.split("");
				widget.currentRow.MESBALREDJAN = MESBALRED[0];
				widget.currentRow.MESBALREDFEV = MESBALRED[1];
				widget.currentRow.MESBALREDMAR = MESBALRED[2];
				widget.currentRow.MESBALREDABR = MESBALRED[3];
				widget.currentRow.MESBALREDMAI = MESBALRED[4];
				widget.currentRow.MESBALREDJUN = MESBALRED[5];
				widget.currentRow.MESBALREDJUL = MESBALRED[6];
				widget.currentRow.MESBALREDAGO = MESBALRED[7];
				widget.currentRow.MESBALREDSET = MESBALRED[8];
				widget.currentRow.MESBALREDOUT = MESBALRED[9];
				widget.currentRow.MESBALREDNOV = MESBALRED[10];
				widget.currentRow.MESBALREDDEZ = MESBALRED[11];
			}
		}
	};
	
	self.ativaPeriodoApuracao = function(){
		var widget = templateManager.container.getWidget('registro_0010');
		var i;
		switch(widget.currentRow.FORMAAPUR)
		{
			case 'A':
				widget.fieldGroups[1].isVisible = true;
				widget.fieldGroups[1].collapsible = true;
				widget.fieldGroups[1].opened = true;
				for(i = 14; i <= 25; ++i) { //Campos MESBALREDJAN a MESBALREDDEZ
					widget.fields[ i ].validations = { "required": { "message": "Campo obrigatório" } };
				}
				break;
			case 'T':
				widget.fieldGroups[1].isVisible = false;
				widget.fieldGroups[1].collapsible = false;
				widget.fieldGroups[1].opened = false;
				for(i = 14; i <= 25; ++i) { //Campos MESBALREDJAN a MESBALREDDEZ
					widget.fields[ i ].validations = {};
				}
				break;
		}
	};
	
	self.ativaFormaTributacao = function(){
		var widget = templateManager.container.getWidget('registro_0010');
		var i;
		if(widget.currentRow.FORMATRIB == '8' || widget.currentRow.FORMATRIB == '9'){
			widget.fieldGroups[2].isVisible = true;
			widget.fieldGroups[2].collapsible = true;
			widget.fieldGroups[2].opened = true;
			for(i = 26; i <= 28; ++i) { //Campos TIPENT a APURCSLL
				widget.fields[ i ].validations = { "required": { "message": "Campo obrigatório" } };
			}
		}else{
			widget.fieldGroups[2].isVisible = false;
			widget.fieldGroups[2].collapsible = false;
			widget.fieldGroups[2].opened = false;
			for(i = 26; i <= 28; ++i) { //Campos TIPENT a APURCSLL
				widget.fields[ i ].validations = {};
			}
		}
	};
	
	self.editarRegistro0010 = function(){
		var widgetReg0000 = templateManager.container.getWidget('registro_0000');
		var widgetReg0010 = templateManager.container.getWidget('registro_0010');
		var widgetReg0020 = templateManager.container.getWidget('registro_0020');
		
		widgetReg0000.isVisible = false;
		widgetReg0020.isVisible = false;
		General.edit(widgetReg0010);
	};
	self.cancelarRegistro0010 = function(){
		var widgetReg0000 = templateManager.container.getWidget('registro_0000');
		var widgetReg0010 = templateManager.container.getWidget('registro_0010');
		var widgetReg0020 = templateManager.container.getWidget('registro_0020');
		
		widgetReg0000.isVisible = true;
		widgetReg0020.isVisible = true;
		// General.backOrCancel(widgetReg0010);
	};
	self.salvarRegistro0010 = function(){
		var widgetReg0000 = templateManager.container.getWidget('registro_0000');
		var widgetReg0010 = templateManager.container.getWidget('registro_0010');
		var widgetReg0020 = templateManager.container.getWidget('registro_0020');
		
		self.ativaPeriodoApuracao(); //Para ativar/desativar os campos required para salvar
		self.ativaFormaTributacao();
		
		widgetReg0010.currentRow.CDEMPRESA = widgetReg0010.getParent().currentRow.CDEMPRESA;
		widgetReg0010.currentRow.FORMATRIBPER = //cria o referido campo a partir da concatenação dos campos abaixo
			widgetReg0010.currentRow.FORMATRIBPER1 +
			widgetReg0010.currentRow.FORMATRIBPER2 +
			widgetReg0010.currentRow.FORMATRIBPER3 +
			widgetReg0010.currentRow.FORMATRIBPER4;
		widgetReg0010.currentRow.MESBALRED = //cria o referido campo a partir da concatenação dos campos abaixo
			widgetReg0010.currentRow.MESBALREDJAN +
			widgetReg0010.currentRow.MESBALREDFEV +
			widgetReg0010.currentRow.MESBALREDMAR +
			widgetReg0010.currentRow.MESBALREDABR +
			widgetReg0010.currentRow.MESBALREDMAI +
			widgetReg0010.currentRow.MESBALREDJUN +
			widgetReg0010.currentRow.MESBALREDJUL +
			widgetReg0010.currentRow.MESBALREDAGO +
			widgetReg0010.currentRow.MESBALREDSET +
			widgetReg0010.currentRow.MESBALREDOUT +
			widgetReg0010.currentRow.MESBALREDNOV +
			widgetReg0010.currentRow.MESBALREDDEZ;

		if(!widgetReg0010.currentRow.hasOwnProperty('__is_new')) { //Se o registro não existir este deve ser sinalizado como novo
			widgetReg0010.currentRow.__is_new = true;
		} 
		
		widgetReg0000.isVisible = true;
		widgetReg0020.isVisible = true;
		General.saveCrud(widgetReg0010);
	};
	
}

/* global Configuration */
Configuration(function (ContextRegister) {
	ContextRegister.register('Registro0010deAbertura_controller', Registro0010deAbertura_controller);
});


// FILE: ./assets/js/controllers/Registro0020deAbertura_controller.js
function Registro0020deAbertura_controller(General, ScreenService, templateManager) {

  	var self = this;
  	
  	self.ativaRegistro0020 = function() {
		var widgetReg0020 = templateManager.container.getWidget('registro_0020');
		widgetReg0020.activate();
		widgetReg0020.reload();
	};
	
	
	self.editarRegistro0020 = function(){
		var widgetReg0000 = templateManager.container.getWidget('registro_0000');
		var widgetReg0010 = templateManager.container.getWidget('registro_0010');
		var widgetReg0020 = templateManager.container.getWidget('registro_0020');
		
		widgetReg0000.isVisible = false;
		widgetReg0010.isVisible = false;
		General.edit(widgetReg0020);
	};
	self.cancelarRegistro0020 = function(){
		var widgetReg0000 = templateManager.container.getWidget('registro_0000');
		var widgetReg0010 = templateManager.container.getWidget('registro_0010');
		var widgetReg0020 = templateManager.container.getWidget('registro_0020');
		
		widgetReg0000.isVisible = true;
		widgetReg0010.isVisible = true;
		// General.backOrCancel(widgetReg0020);
	};
	self.salvarRegistro0020 = function(){
		var widgetReg0000 = templateManager.container.getWidget('registro_0000');
		var widgetReg0010 = templateManager.container.getWidget('registro_0010');
		var widgetReg0020 = templateManager.container.getWidget('registro_0020');
		
		widgetReg0020.currentRow.CDEMPRESA = widgetReg0020.getParent().currentRow.CDEMPRESA;
		if(!widgetReg0020.currentRow.hasOwnProperty('__is_new')) { //Se o registro não existir este deve ser sinalizado como novo
			widgetReg0020.currentRow.__is_new = true;
		}
		
		widgetReg0000.isVisible = true;
		widgetReg0010.isVisible = true;
		General.saveCrud(widgetReg0020); 
	};
}

/* global Configuration */
Configuration(function (ContextRegister) {
	ContextRegister.register('Registro0020deAbertura_controller', Registro0020deAbertura_controller);
});


// FILE: ./assets/js/controllers/Sap03200_periodo_fechamento_contabil_gerencialController.js
var Sap03200_periodo_fechamento_contabil_gerencialController  = function(templateManager, ScreenService, General, localStorageEngine){
    
    var self = this;
    
    this.saveContctblGrid = function(widget){
        widget.dataSource.name = "cadCtb#/crud/cctblgerfil";
        General.saveCrud(widget).then(function(){
            widget.dataSource.name = "cadCtb#/crud/cctblgerfil_nome";
            widget.reload();
        },
        function(error){
            ScreenService.showMessage(error.data.error);
            widget.dataSource.name = "cadCtb#/crud/cctblgerfil_nome";
        });
	};
	
	
    this.abreAlteraLanc = function(widget){
        var contabilizaSelecao = templateManager.container.getWidget('contabilizaSelecao');
	    var dataRefGrid =templateManager.container.getWidget('dataRefGrid');
	    contabilizaSelecao.currentRow = dataRefGrid.appliedFilter.FILTER_ROW;
	    
	    contabilizaSelecao.isVisible = true;
	    contabilizaSelecao.edit();
	    ScreenService.openPopup(contabilizaSelecao);
    };
	
    this.confimaAlteraLanc = function(widget){
	    var contabilizaSelecao = templateManager.container.getWidget('contabilizaSelecao');
	    if(contabilizaSelecao.isValid()){
	        var rowParametro = {
    	        "DTINICIAL":contabilizaSelecao.currentRow.DTINICIAL,
     	        "DTFINAL":contabilizaSelecao.currentRow.DTFINAL
    	    };
    	    
    	    rowParametro.CDFILIAL = contabilizaSelecao.currentRow.CDFILIAL == '' ? 'T' : contabilizaSelecao.currentRow.CDFILIAL;
    	    
    	    General.callRestEngine("cadCtb#/contabilizaSelecao", "Row", rowParametro).then(function(sucess) {
    	       ScreenService.closePopup();
               contabilizaSelecao.isVisible = false;
               ScreenService.showMessage('Operação realizada com sucesso.');
            }, function(error){
            	ScreenService.showMessage(error.data.error);
            });    
	    }
	};
};
Configuration(function(ContextRegister){
    ContextRegister.register('Sap03200_periodo_fechamento_contabil_gerencialController', Sap03200_periodo_fechamento_contabil_gerencialController);
});

// FILE: ./assets/js/controllers/zhFavorites.js
var ZeedhiFields = angular.module("ZeedhiFields");

ZeedhiFields.directive('zhNavbarDefaultHeader', function(templateManager, ScreenService, eventAggregator, $compile, ApplicationContext) {
	return {
		restrict: 'C',
		link: function($scope, element) {
		    $scope.favoritesList = [];
		    $scope.lastDeletedItem = undefined;
		    
		    var favoritesText = 'Favoritos';
		    var favoritesAddText = 'Adicionar aos Favoritos';
		    var favoritesRemoveText = 'Remover dos Favoritos';
		    var favoritesUndoText = 'DESFAZER';

			// TRANSLATE - Adicionar essas variaveis a lista da aplicação (words.jon)
		    // var favoritesText = ScreenService.i18n('FAVORITES');
		    // var favoritesAddText = ScreenService.i18n('ADD_TO_FAVORITES');
		    // var favoritesRemoveText = ScreenService.i18n('REMOVE_FROM_FAVORITES');
		    // var favoritesUndoText = ScreenService.i18n('UNDO');
		    
		    var favoritesContainer;
		    
		    var startHollowCode = '<svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" viewBox="0 0 30 30" style="enable-background:new 0 0 30 30;" xml:space="preserve">'+
				'	<style type="text/css">'+
				'		.st0{fill:#FFFFFF;}'+
				'	</style>'+
				'	<g>'+
				'		<path class="st0" d="M15,4.21l3.51,7.1l7.84,1.14l-5.67,5.53l1.34,7.81L15,22.1l-7.01,3.69l1.34-7.81l-5.67-5.53l7.84-1.14L15,4.21'+
				'			 M15,2.21c-0.76,0-1.46,0.43-1.79,1.11l-3.04,6.16l-6.8,0.99c-0.75,0.11-1.38,0.64-1.61,1.36c-0.24,0.72-0.04,1.52,0.51,2.05'+
				'			l4.92,4.8l-1.16,6.77c-0.13,0.75,0.18,1.51,0.8,1.96c0.35,0.25,0.76,0.38,1.18,0.38c0.32,0,0.64-0.08,0.93-0.23l6.08-3.2l6.08,3.2'+
				'			c0.29,0.15,0.61,0.23,0.93,0.23c0.41,0,0.83-0.13,1.18-0.38c0.62-0.45,0.92-1.21,0.8-1.96l-1.16-6.77l4.92-4.8'+
				'			c0.55-0.53,0.74-1.33,0.51-2.05c-0.24-0.72-0.86-1.25-1.61-1.36l-6.8-0.99l-3.04-6.16C16.46,2.64,15.76,2.21,15,2.21L15,2.21z"/>'+
				'	</g>'+
				'</svg>';
		    var startFilledCode = '<svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" viewBox="0 0 30 30" style="enable-background:new 0 0 30 30;" xml:space="preserve">'+
				'	<style type="text/css">'+
				'		.st0{fill:#FFFFFF;}'+
				'	</style>'+
				'	<g>'+
				'		<path class="st0" d="M28.25,11.83c-0.24-0.72-0.86-1.25-1.61-1.36l-6.8-0.99l-3.04-6.16C16.46,2.64,15.76,2.21,15,2.21'+
				'			s-1.46,0.43-1.79,1.11l-3.04,6.16l-6.8,0.99c-0.75,0.11-1.38,0.64-1.61,1.36c-0.24,0.72-0.04,1.52,0.51,2.05l4.92,4.8l-1.16,6.77'+
				'			c-0.13,0.75,0.18,1.51,0.8,1.96c0.35,0.25,0.76,0.38,1.18,0.38c0.32,0,0.64-0.08,0.93-0.23l6.08-3.2l6.08,3.2'+
				'			c0.29,0.15,0.61,0.23,0.93,0.23c0.41,0,0.83-0.13,1.18-0.38c0.62-0.45,0.92-1.21,0.8-1.96l-1.16-6.77l4.92-4.8'+
				'			C28.29,13.35,28.48,12.56,28.25,11.83z"/>'+
				'	</g>'+
				'</svg>';
		    
		    function createVisualElements() {
    			var headerContainer = $(element).children()[0];
    			headerContainer.style.width = 'calc(100% - 50px)';
    			
    			favoritesContainer = $('<div class="zh-favorites"></div>').appendTo(element);
    			
    			var favoritesButtonElement = $compile(
    				'<div class="zh-favorites-button" ng-click="toggleList()">'+
    				'  <div class="zh-favorites-button-star" ng-if="!isFavorited">'+
    				'    '+startHollowCode+
    				'  </div>'+
    				'  <div class="zh-favorites-button-star" ng-if="isFavorited">'+
    				'    '+startFilledCode+
    				'  </div>'+
    				'  <div class="zh-favorites-button-text">'+favoritesText+'</div>'+
    				'</div>'
    			)($scope);
    			var favoritesButton = $(favoritesButtonElement).appendTo(favoritesContainer);
    			
    			var favoritesListElement = $compile(
    				'<div class="zh-favorites-list" ng-class="{\'opened\': opened}">'+
    				'  <div class="zh-favorites-list-button" ng-if="!isFavorited" ng-click="addToFavorites()">'+favoritesAddText+'</div>'+
    				'  <div class="zh-favorites-list-button" ng-if="isFavorited" ng-click="removeFromFavorites()">'+favoritesRemoveText+'</div>'+
    				'  <div class="zh-favorites-list-undo" ng-show="lastDeletedItem" ng-click="undo()">'+favoritesUndoText+'</div>'+
    				'  <div class="zh-favorites-list-items" ng-show="favoritesList.length > 0">'+
    				'	 <div class="zh-favorites-list-item" ng-repeat="item in favoritesList track by item.id" ng-click="openItem(item)">'+
    				'      {{ item.label }}'+
    				'      <span class="zh-favorites-list-item-delete" data-zh-icon="trash icon-white no-border" ng-click="deleteItem(item, $index, $event)"></span>'+
    				'    </div>'+
    				'  </div>'+
    				'</div>'
    			)($scope);
    			var favoritesList = $(favoritesListElement).appendTo(favoritesContainer);
		    }
		    
		    function checkIsFavorited(containerId) {
		    	var oldIsFavorited = $scope.isFavorited;
			    $scope.isFavorited = $scope.favoritesList.findIndex((item) => item.id === containerId) !== -1;
			    if (oldIsFavorited !== $scope.isFavorited) {
			    	templateManager.updateTemplate();
			    }
		    }
		    
		    $scope.addToFavorites = function() {
		    	var item = {
		    		id: templateManager.container.id,
		    		name: templateManager.container.fileName.split('.json')[0],
		    		label: templateManager.container.label,
		    	};
		    	$scope.favoritesList.push(item);
		    	$scope.isFavorited = true;
		    	eventAggregator.publish('ZhFavoritesOnChange', { fullList: $scope.favoritesList, changed: { item, status: 'add' }});
		    };
		    
		    $scope.removeFromFavorites = function() {
		    	var index = $scope.favoritesList.findIndex((item) => item.id === templateManager.container.id);
		    	if (index > -1) {
			    	var item = $scope.favoritesList.splice(index, 1);
			    	$scope.isFavorited = false;
			    	eventAggregator.publish('ZhFavoritesOnChange', { fullList: $scope.favoritesList, changed: { item, status: 'delete' }});
		    	}
		    };
		    
		    $scope.openItem = function(item) {
		    	ApplicationContext.LibUtilities.openWindow(item.name);
	    		$scope.opened = false;
		    };
		    
		    var undoTimeout;
		    
		    $scope.deleteItem = function(item, index, event) {
		    	$scope.favoritesList.splice(index, 1);
		    	$scope.lastDeletedItem = { item, index };

		    	clearTimeout(undoTimeout);
		    	undoTimeout = setTimeout(() => {
		    		$scope.lastDeletedItem = undefined;
		    		templateManager.updateTemplate();
		    	}, 10000);

			    eventAggregator.publish('ZhFavoritesOnChange', { fullList: $scope.favoritesList, changed: { item, status: 'delete' }});

		    	if (item.id === templateManager.container.id) {
		    		$scope.isFavorited = false;
		    	}

		    	event.stopImmediatePropagation();
		    };
		    
		    $scope.undo = function() {
		    	if ($scope.lastDeletedItem) {
		    		$scope.favoritesList.splice($scope.lastDeletedItem.index, 0, $scope.lastDeletedItem.item);
		    	}
		    	$scope.lastDeletedItem = undefined;
		    };

		    $scope.toggleList = function() {
		    	$scope.opened = !$scope.opened;
		    };
		    
		    document.addEventListener('mousedown', (evt) => {
		    	if ($(favoritesContainer).find(evt.target).length === 0 && $scope.opened) {
		    		$scope.opened = false;
			    	templateManager.updateTemplate();
		    	}	
		    });
		    
		    eventAggregator.subscribe(eventAggregator.ON_CONTAINER_OPEN, (args) => {
		    	checkIsFavorited(args.container.id);
		    });
		    
		    eventAggregator.subscribe('ZhFavoritesOnLoad', (favorites) => {
		    	
		    	$scope.favoritesList = favorites;
			    if (templateManager.container) {
			    	checkIsFavorited(templateManager.container.id);
			    }
		    });

		    createVisualElements();
		}
	};
});
